/*****************************************************************************
 *  Rohde&Schwarz MXO Instrument Driver
 *  LabWindows/CVI Instrument Driver
 *  Original Release: 2022-10-03
 *  By: Tereza Zavodna
 *
 *  Modification History:
 *
 *       See ChangeLog
 *
 *****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <time.h>
#include "rsmxo.h"
#include "rsmxo_internal.h"

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
#include <sys/timeb.h>
#include <sys/types.h>
#include <unistd.h>
#define Sleep sleep
#else                       /* ANSI compatible */
#include <windows.h>
#endif

#if defined (_CVI_)
#include <utility.h>
#endif

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/


/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function:
 rsmxo_init
 * Purpose:  VXIplug&play required function. Calls the
 *           rsmxo_InitWithOptions function.
 *****************************************************************************/
ViStatus _VI_FUNC rsmxo_init(ViRsrc resourceName, ViBoolean IDQuery,
                             ViBoolean resetDevice, ViSession* newInstrSession)
{
    ViStatus error = VI_SUCCESS;

    if (newInstrSession == 0)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                                  VI_ERROR_PARAMETER4, "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    checkErr(rsmxo_InitWithOptions(resourceName, IDQuery, resetDevice,
        "", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rsmxo_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rsmxo_InitWithOptions(
    ViRsrc resourceName,
    ViBoolean IDQuery,
    ViBoolean resetDevice,
    ViString optionString,
    ViSession* newInstrSession
)
{
    ViStatus error = VI_SUCCESS;
    // ReSharper disable once CppInitializedValueIsAlwaysRewritten
    // ReSharper disable once CppEntityAssignedButNoRead
    RsCoreAttributePtr* attrList = NULL;
    ViSession instrSession = 0;
    RsCoreSessionPtr sessionProperties = NULL;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
                                  "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    attrList = (RsCoreAttributePtr*)rsmxo_RsCoreAttributeList;

    *newInstrSession = 0;

    checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rsmxo", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        rsmxo_RsCoreAttributeList, // List of all attributes from the rsxxx_AttrPropertiesList
        rsmxo_RsCoreAttributeListLength, // Length of the attributes list
        VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "RTO2000", VI_FALSE: "RTPO" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        1000000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSMXO_OPC_TIMEOUT, // OPC timeout
        10000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

    // Minimal allowed rscore version is 4.6.0
    checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 6, 0));

    checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

    // No SCPI command has been sent yet.
    // Call viClear before sending any SCPI command
    checkErr(RsCore_ViClear(instrSession));

    /* --- Here perform settings that are default for this driver,
    but can be overwritten by the optionsString settings */
    sessionProperties->opcSyncQueriesMechanism = RS_OPCSYNCQUERIES_ONLYCHECKMAVERRQUEUE;
    sessionProperties->autoSystErrQuery = VI_FALSE;
    sessionProperties->fastSweepInstrument = 1;

    // Parse option string and optionally sets the initial state of the following session attributes
    checkErr(RsCore_ApplyOptionString(instrSession, optionString));
    checkErr(RsCore_BuildRepCapTable(instrSession, rsmxo_RsCoreRepCapTable, rsmxo_RsCoreRepCapTableCount));

    // Query *IDN? string, parse it and set the following attributes:
    // -RS_ATTR_INSTRUMENT_MANUFACTURER
    // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "NRP33SN", false : "NRP"
    // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
    checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSMXO_SIMULATION_ID_QUERY, NULL));

    // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
    checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSMXO_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

    // Default Instrument Setup + optional *RST
    if (resetDevice == VI_TRUE)
    {
        checkErr(rsmxo_reset(instrSession));
    }
    else
    {
        checkErr(rsmxo_DefaultInstrSetup(instrSession));
    }

    if (IDQuery == VI_TRUE)
    {
        checkErr(RsCore_FitsIDNpattern(instrSession, RSMXO_VALID_ID_RESPONSE_STRING, NULL));
    }

    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    RsCore_AfterErrorInInit(instrSession, sessionProperties, error, newInstrSession);
    return error;
}


/// HIFN  Switches the selected channel signal on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR showChannel/Switches the selected channel signal on or off.
ViStatus _VI_FUNC rsmxo_ShowChannel(ViSession instrSession,
                                    ViInt32   channel,
                                    ViBoolean showChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_SHOW_CHANNEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_VERTICAL_SHOW_CHANNEL, showChannel),
            3, "Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical scale in Volts per division. The vertical scale
/// HIFN  defines the displayed amplitude of the selected waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR verticalScale/Sets the vertical scale in Volts per division. The vertical scale
/// HIPAR verticalScale/defines the displayed amplitude of the selected waveform.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalScale(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  verticalScale)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_SCALE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_VERTICAL_SCALE, verticalScale),
            3, "Vertical Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the voltage range across the 10 vertical divisions of the
/// HIFN  diagram. Alternative to RSMXO_ATTR_VERTICAL_SCALE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR range/Sets the voltage range across the 10 vertical divisions of the
/// HIPAR range/diagram. Alternative to RSMXO_ATTR_VERTICAL_SCALE.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalRange(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_RANGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_VERTICAL_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the offset voltage, which corrects an offset-affected signal. The
/// HIFN  vertical center of the selected channel is shifted by the offset value
/// HIFN  and the signal is repositioned within the diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR offset/Sets the offset voltage, which corrects an offset-affected signal. The
/// HIPAR offset/vertical center of the selected channel is shifted by the offset value
/// HIPAR offset/and the signal is repositioned within the diagram.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalOffset(ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_OFFSET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_VERTICAL_OFFSET, offset),
            3, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Moves the selected signal up or down in the diagram. While the offset
/// HIFN  sets a voltage, position is a graphical setting given in divisions. The
/// HIFN  visual effect is the same as for offset.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR position/Moves the selected signal up or down in the diagram. While the offset
/// HIPAR position/sets a voltage, position is a graphical setting given in divisions. The
/// HIPAR position/visual effect is the same as for offset.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalPosition(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_POSITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_VERTICAL_POSITION, position),
            3, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a skew value to compensate for the delay of the measurement setup
/// HIFN  or from the circuit specifics that the instrument cannot compensate
/// HIFN  automatically. It affects only the selected input channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR skew/Sets a skew value to compensate for the delay of the measurement setup
/// HIPAR skew/or from the circuit specifics that the instrument cannot compensate
/// HIPAR skew/automatically. It affects only the selected input channel.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalSkew(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  skew)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_SKEW,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_VERTICAL_SKEW, skew),
            3, "Skew");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the connection of the channel signal, i.e. the input impedance
/// HIFN  (coupling) and a filter (termination). It determines what part of the
/// HIFN  signal is used for waveform analysis and triggering.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR coupling/Sets the connection of the channel signal, i.e. the input impedance
/// HIPAR coupling/(coupling) and a filter (termination). It determines what part of the
/// HIPAR coupling/signal is used for waveform analysis and triggering.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalCoupling(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   coupling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_COUPLING,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_VERTICAL_COUPLING, coupling),
            3, "Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Turns the inversion of the signal amplitude on or off. To invert means
/// HIFN  to reflect the voltage values of all signal components against the
/// HIFN  ground level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR invertChannel/Turns the inversion of the signal amplitude on or off. To invert means
/// HIPAR invertChannel/to reflect the voltage values of all signal components against the
/// HIPAR invertChannel/ground level.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalInvertChannel(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean invertChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_INVERT_CHANNEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_VERTICAL_INVERT_CHANNEL, invertChannel),
            3, "Invert Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the bandwidth limit. The specified bandwidth indicates the range
/// HIFN  of frequencies that the instrument can acquire and display accurately
/// HIFN  with less than 3dB attenuation. Frequencies above the limit are removed
/// HIFN  from the signal, and noise is reduced.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bandwidth/Sets the bandwidth limit. The specified bandwidth indicates the range
/// HIPAR bandwidth/of frequencies that the instrument can acquire and display accurately
/// HIPAR bandwidth/with less than 3dB attenuation. Frequencies above the limit are removed
/// HIPAR bandwidth/from the signal, and noise is reduced.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalBandwidth(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_BANDWIDTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_VERTICAL_BANDWIDTH, bandwidth),
            3, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the attenuation scale and value for an external divider.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR scale/Sets the attenuation scale for an external divider: linear or
/// HIPAR scale/logarithmic.
/// HIPAR externalAttenuation/Consider a voltage divider that is part of the DUT before the
/// HIPAR externalAttenuation/measuring point. The external attenuation is included in the
/// HIPAR externalAttenuation/measurement, and the instrument shows the results that would be
/// HIPAR externalAttenuation/measured before the divider. External attenuation can be used with all
/// HIPAR externalAttenuation/probes.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalExternalAttenuation(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   scale,
                                                             ViReal64  externalAttenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_EXTERNAL_ATTENUATION_SCALE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_VERTICAL_EXTERNAL_ATTENUATION_SCALE, scale),
            3, "Scale");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_VERTICAL_EXTERNAL_ATTENUATION, externalAttenuation),
            4, "External Attenuation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the impedance of the connected probe for power calculations and
/// HIFN  measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR impedance/Sets the impedance of the connected probe for power calculations and
/// HIPAR impedance/measurements.
ViStatus _VI_FUNC rsmxo_ConfigureVerticalPowerCalculationImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  impedance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_VERTICAL_POWER_CALCULATION_IMPEDANCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_VERTICAL_POWER_CALCULATION_IMPEDANCE, impedance),
            3, "Impedance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries if the probe at the specified input channel is active
/// HIFN  (detected) or not active (not detected). To switch the probe on, use
/// HIFN  RSMXO_ATTR_VERTICAL_SHOW_CHANNEL.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR state/Queries if the probe at the specified input channel is active
/// HIPAR state/(detected) or not active (not detected). To switch the probe on, use
/// HIPAR state/RSMXO_ATTR_VERTICAL_SHOW_CHANNEL.
ViStatus _VI_FUNC rsmxo_QueryProbeState(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROBE_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the name of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bufferSize/Size of output array.
/// HIPAR probeName/Queries the name of the probe.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProbeName(ViSession instrSession,
                                       ViInt32   channel,
                                       ViInt32   bufferSize,
                                       ViChar    probeName[],
                                       ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_NAME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROBE_NAME, bufferSize, probeName, bytesRead),
                3, "Probe Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the type of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bufferSize/Size of output array.
/// HIPAR probeType/Queries the type of the probe.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProbeType(ViSession instrSession,
                                       ViInt32   channel,
                                       ViInt32   bufferSize,
                                       ViChar    probeType[],
                                       ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROBE_TYPE, bufferSize, probeType, bytesRead),
                3, "Probe Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the type of the predefined probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR type/Defines the type of the predefined probe.
ViStatus _VI_FUNC rsmxo_ConfigureProbePredefinedType(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_PREDEFINED_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROBE_PREDEFINED_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the bandwidth of the connected probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR probeBandwidth/Returns the bandwidth of the connected probe.
ViStatus _VI_FUNC rsmxo_QueryProbeBandwidth(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64* probeBandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_BANDWIDTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_BANDWIDTH, probeBandwidth),
            3, "Probe Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the unit of the connected probe if the probe is detected or
/// HIFN  predefined. For unknown probes, you can select the required unit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR verticalUnit/Returns the unit of the connected probe if the probe is detected or
/// HIPAR verticalUnit/predefined. For unknown probes, you can select the required unit.
ViStatus _VI_FUNC rsmxo_ConfigureProbeVerticalUnit(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   verticalUnit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_VERTICAL_UNIT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROBE_VERTICAL_UNIT, verticalUnit),
            3, "Vertical Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the attenuation for an unknown probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR manualAttenuation/Sets the attenuation for an unknown probe.
ViStatus _VI_FUNC rsmxo_ConfigureProbeManualAttenuation(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViReal64  manualAttenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_MANUAL_ATTENUATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_MANUAL_ATTENUATION, manualAttenuation),
            3, "Manual Attenuation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the attenuation on a detected or predefined probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR autoAttenuation/Returns the attenuation on a detected or predefined probe.
ViStatus _VI_FUNC rsmxo_QueryProbeAutoAttenuation(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* autoAttenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_AUTO_ATTENUATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_AUTO_ATTENUATION, autoAttenuation),
            3, "Auto Attenuation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Performs an automatic compensation for a DC component of the input
/// HIFN  signal using the result of a background mean measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
ViStatus _VI_FUNC rsmxo_SetProbeOffsetToMean(ViSession instrSession,
                                             ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_SET_OFFSET_TO_MEAN,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROBE_SET_OFFSET_TO_MEAN, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Measures the zero error. Short the signal pin and the ground pin
/// HIFN  together and connect them to the ground of the DUT before sending the
/// HIFN  command.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
ViStatus _VI_FUNC rsmxo_ProbeAutoZero(ViSession instrSession,
                                      ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_AUTO_ZERO,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROBE_AUTO_ZERO, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Includes the AutoZero offset in measurement results. The auto zero
/// HIFN  error is detected
/// HIFN     with RSMXO_ATTR_PROBE_AUTO_ZERO.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR useAutoZero/Includes the AutoZero offset in measurement results. The auto zero
/// HIPAR useAutoZero/error is detected
ViStatus _VI_FUNC rsmxo_UseProbeAutoZero(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean useAutoZero)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_USE_AUTO_ZERO,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROBE_USE_AUTO_ZERO, useAutoZero),
            3, "Use Auto Zero");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  The micro button is located on the probe head. Pressing this button,
/// HIFN  you can perform an action on the instrument directly from the probe.
/// HIFN  During internal automatic processes the button is disabled, for
/// HIFN  example, during self alignment, autoset, and level detection.Select the
/// HIFN  action that you want to start from the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR microButton/The micro button is located on the probe head. Pressing this button,
/// HIPAR microButton/you can perform an action on the instrument directly from the probe.
/// HIPAR microButton/During internal automatic processes the button is disabled, for
/// HIPAR microButton/example, during self alignment, autoset, and level detection.Select the
/// HIPAR microButton/action that you want to start from the probe.
ViStatus _VI_FUNC rsmxo_ConfigureProbeMicroButton(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   microButton)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_MICRO_BUTTON,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROBE_MICRO_BUTTON, microButton),
            3, "Micro Button");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the termination of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR impedance/Queries the termination of the probe.
ViStatus _VI_FUNC rsmxo_QueryProbeImpedance(ViSession instrSession,
                                            ViInt32   channel,
                                            ViReal64* impedance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_IMPEDANCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_IMPEDANCE, impedance),
            3, "Impedance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the input capacitance of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR capacitance/Queries the input capacitance of the probe.
ViStatus _VI_FUNC rsmxo_QueryProbeCapacitance(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64* capacitance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_CAPACITANCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_CAPACITANCE, capacitance),
            3, "Capacitance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the Rohde&Schwarz part number of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bufferSize/Size of output array.
/// HIPAR partNumber/Queries the Rohde&Schwarz part number of the probe.
ViStatus _VI_FUNC rsmxo_QueryProbePartNumber(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   bufferSize,
                                             ViChar    partNumber[],
                                             ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_PART_NUMBER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROBE_PART_NUMBER, bufferSize, partNumber, bytesRead),
                4, "Part Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the production date of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bufferSize/Size of output array.
/// HIPAR productionDate/Queries the production date of the probe.
ViStatus _VI_FUNC rsmxo_QueryProbeProductionDate(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   bufferSize,
                                                 ViChar    productionDate[],
                                                 ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_PRODUCTION_DATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROBE_PRODUCTION_DATE, bufferSize, productionDate, bytesRead),
                4, "Production Date");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the serial number of the probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bufferSize/Size of output array.
/// HIPAR serialNumber/Queries the serial number of the probe.
ViStatus _VI_FUNC rsmxo_QueryProbeSerialNumber(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   bufferSize,
                                               ViChar    serialNumber[],
                                               ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_SERIAL_NUMBER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROBE_SERIAL_NUMBER, bufferSize, serialNumber, bytesRead),
                4, "Serial Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the version of the probe firmware.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bufferSize/Size of output array.
/// HIPAR softwareVersion/Queries the version of the probe firmware.
ViStatus _VI_FUNC rsmxo_QueryProbeSoftwareVersion(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   bufferSize,
                                                  ViChar    softwareVersion[],
                                                  ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_SOFTWARE_VERSION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROBE_SOFTWARE_VERSION, bufferSize, softwareVersion, bytesRead),
                4, "Software Version");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the common-mode offset to compensate for a common DC voltage that
/// HIFN  is applied to both input sockets (referenced to the ground socket). The
/// HIFN  setting is available for  Rohde&Schwarz differential probes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR cmOffset/Sets the common-mode offset to compensate for a common DC voltage that
/// HIPAR cmOffset/is applied to both input sockets (referenced to the ground socket). The
/// HIPAR cmOffset/setting is available for  Rohde&Schwarz differential probes.
ViStatus _VI_FUNC rsmxo_ConfigureProbeCMOffset(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  cmOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_CM_OFFSET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_CM_OFFSET, cmOffset),
            3, "CM Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If you use the external attenuator R&SRT-ZA15 together with one of the
/// HIFN  differential active probes R&SRT-ZD10/20/30, enable RT-ZA15 attenuator
/// HIFN  to include the external attenuation in the measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR attenuator/If you use the external attenuator R&SRT-ZA15 together with one of the
/// HIPAR attenuator/differential active probes R&SRT-ZD10/20/30, enable RT-ZA15 attenuator
/// HIPAR attenuator/to include the external attenuation in the measurements.
ViStatus _VI_FUNC rsmxo_ConfigureProbeRTZA15AttenuatorEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean attenuator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_RTZA15_ATTENUATOR_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROBE_RTZA15_ATTENUATOR_ENABLED, attenuator),
            3, "Attenuator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the voltage to be measured by the ProbeMeter of differential
/// HIFN  active probes:
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR display/Selects the voltage to be measured by the ProbeMeter of differential
/// HIPAR display/active probes:
ViStatus _VI_FUNC rsmxo_ConfigureProbeDisplay(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   display)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_DISPLAY,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROBE_DISPLAY, display),
            3, "Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the acoustic overrange warning in the probe control box.
/// HIFN  Relevant for R&SRT-ZHD probes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR sound/Activates the acoustic overrange warning in the probe control box.
/// HIPAR sound/Relevant for R&SRT-ZHD probes.
ViStatus _VI_FUNC rsmxo_ConfigureProbeSoundEnabled(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean sound)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_SOUND_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROBE_SOUND_ENABLED, sound),
            3, "Sound");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the lowpass filter in the probe control box. The filter
/// HIFN  frequency depends on the probe type and is indicated on the probe
/// HIFN  control box.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR bandwidthLimit/Activates the lowpass filter in the probe control box. The filter
/// HIPAR bandwidthLimit/frequency depends on the probe type and is indicated on the probe
/// HIPAR bandwidthLimit/control box.
ViStatus _VI_FUNC rsmxo_ConfigureProbeBandwidthLimitEnabled(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean bandwidthLimit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_BANDWIDTH_LIMIT_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROBE_BANDWIDTH_LIMIT_ENABLED, bandwidthLimit),
            3, "Bandwidth Limit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the voltage range of an R&SRT-ZHD probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR voltageRange/Sets the voltage range of an R&SRT-ZHD probe.
ViStatus _VI_FUNC rsmxo_ConfigureProbeVoltageRange(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   voltageRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_VOLTAGE_RANGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROBE_VOLTAGE_RANGE, voltageRange),
            3, "Voltage Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the integrated R&S ProbeMeter on probes with Rohde&Schwarz
/// HIFN  probe interface.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR probeMeter/Activates the integrated R&S ProbeMeter on probes with Rohde&Schwarz
/// HIPAR probeMeter/probe interface.
ViStatus _VI_FUNC rsmxo_ConfigureProbeMeterEnabled(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean probeMeter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_METER_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROBE_METER_ENABLED, probeMeter),
            3, "Probe Meter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the measured ProbeMeter value as offset. Thus, the value is
/// HIFN  considered in measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
ViStatus _VI_FUNC rsmxo_ProbeMeterSetToOffset(ViSession instrSession,
                                              ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_METER_SET_TO_OFFSET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROBE_METER_SET_TO_OFFSET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables AC coupling in  R&SRTZPR power rail probes, which removes DC
/// HIFN  and very low-frequency components. The R&SRTZPR probe requires 50
/// HIFN  input termination, for which the channel AC coupling is not available.
/// HIFN  The probe setting allows AC coupling also at 50  inputs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR acCoupling/Enables AC coupling in  R&SRTZPR power rail probes, which removes DC
/// HIPAR acCoupling/and very low-frequency components. The R&SRTZPR probe requires 50
/// HIPAR acCoupling/input termination, for which the channel AC coupling is not available.
/// HIPAR acCoupling/The probe setting allows AC coupling also at 50  inputs.
ViStatus _VI_FUNC rsmxo_ConfigureProbeACCouplingEnabled(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViBoolean acCoupling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_AC_COUPLING_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROBE_AC_COUPLING_ENABLED, acCoupling),
            3, "AC Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the gain for an unknown current probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR gain/Sets the gain for an unknown current probe.
ViStatus _VI_FUNC rsmxo_ConfigureProbeManualGain(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  gain)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_MANUAL_GAIN,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_MANUAL_GAIN, gain),
            3, "Gain");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the gain of a detected or predefined current probe.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR gain/Returns the gain of a detected or predefined current probe.
ViStatus _VI_FUNC rsmxo_QueryProbePredefinedGain(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* gain)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_PREDEFINED_GAIN,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_PREDEFINED_GAIN, gain),
            3, "Gain");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Set the waveform to zero position. It corrects the effect of a voltage
/// HIFN  offset or temperature drift. To set the value by the instrument, use
/// HIFN  RSMXO_ATTR_PROBE_AUTO_ZERO.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR zeroAdjust/Set the waveform to zero position. It corrects the effect of a voltage
/// HIPAR zeroAdjust/offset or temperature drift. To set the value by the instrument, use
/// HIPAR zeroAdjust/RSMXO_ATTR_PROBE_AUTO_ZERO.
ViStatus _VI_FUNC rsmxo_ConfigureProbeZeroAdjust(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  zeroAdjust)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_ZERO_ADJUST,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_ZERO_ADJUST, zeroAdjust),
            3, "Zero Adjust");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Demagnetizes the core if it has been magnetized by switching the power
/// HIFN  on and off, or by an excessive input. Always carry out demagnetizing
/// HIFN  before measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
ViStatus _VI_FUNC rsmxo_ProbeDeGauss(ViSession instrSession,
                                     ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_DEGAUSS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROBE_DEGAUSS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the zero adjust  value in the probe box. If you connect the
/// HIFN  probe to another
/// HIFN     channel or to another Rohde&Schwarz oscilloscope, the value is read
/// HIFN  out again, and you can use the probe without further adjustment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
ViStatus _VI_FUNC rsmxo_ProbeSaveToProbe(ViSession instrSession,
                                         ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_SAVE_TO_PROBE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROBE_SAVE_TO_PROBE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the ProbeMeter measurement result of differential active R&S
/// HIFN  probes: the voltage that is measured between the positive signal socket
/// HIFN  and the ground.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR positive/Returns the ProbeMeter measurement result of differential active R&S
/// HIPAR positive/probes: the voltage that is measured between the positive signal socket
/// HIPAR positive/and the ground.
ViStatus _VI_FUNC rsmxo_QueryProbeResultsPositive(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_RESULTS_POSITIVE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_RESULTS_POSITIVE, positive),
            3, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the ProbeMeter measurement result of differential active R&S
/// HIFN  probes, the voltage that is measured between the negative signal socket
/// HIFN  and the ground.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negative/Returns the ProbeMeter measurement result of differential active R&S
/// HIPAR negative/probes, the voltage that is measured between the negative signal socket
/// HIPAR negative/and the ground.
ViStatus _VI_FUNC rsmxo_QueryProbeResultsNegative(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViReal64* negative)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_RESULTS_NEGATIVE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_RESULTS_NEGATIVE, negative),
            3, "Negative");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the ProbeMeter measurement result.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR singleEnded/Returns the ProbeMeter measurement result of single-ended active
/// HIPAR singleEnded/Rohde&Schwarz probes, the
/// HIPAR common/Returns the ProbeMeter measurement result of differential active R&S
/// HIPAR common/probes: the common mode voltage, which is the mean voltage between the
/// HIPAR common/signal sockets and the ground socket.
/// HIPAR differential/Returns the ProbeMeter measurement result of differential active
/// HIPAR differential/Rohde&Schwarz probes, the differential
ViStatus _VI_FUNC rsmxo_QueryProbeMeterResults(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64* singleEnded,
                                               ViReal64* common,
                                               ViReal64* differential)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROBE_RESULTS_SINGLE_ENDED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_RESULTS_SINGLE_ENDED, singleEnded),
            3, "Single Ended");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_RESULTS_COMMON, common),
            4, "Common");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROBE_RESULTS_DIFFERENTIAL, differential),
            5, "Differential");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the horizontal scale, the time per division, for all channel and
/// HIFN  math waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeScale/Sets the horizontal scale, the time per division, for all channel and
/// HIPAR timeScale/math waveforms.
ViStatus _VI_FUNC rsmxo_ConfigureHorizontalTimeScale(ViSession instrSession,
                                                     ViReal64  timeScale)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_TIME_SCALE, timeScale),
            2, "Time Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the time of one acquisition, that is the time across the 10
/// HIFN  divisions of the diagram: Acquisition time = Time scale * 10 divisions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timebaseRange/Sets the time of one acquisition, that is the time across the 10
/// HIPAR timebaseRange/divisions of the diagram: Acquisition time = Time scale * 10 divisions.
ViStatus _VI_FUNC rsmxo_ConfigureHorizontalTimebaseRange(ViSession instrSession,
                                                         ViReal64  timebaseRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_TIMEBASE_RANGE, timebaseRange),
            2, "Time Base Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the time distance between the reference point and the trigger
/// HIFN  point, which is the zero point of the diagram. The horizontal position
/// HIFN  is also known as trigger offset.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR position/Defines the time distance between the reference point and the trigger
/// HIPAR position/point, which is the zero point of the diagram. The horizontal position
/// HIPAR position/is also known as trigger offset.
ViStatus _VI_FUNC rsmxo_ConfigureHorizontalPosition(ViSession instrSession,
                                                    ViReal64  position)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_POSITION, position),
            2, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the position of the reference point in % of the screen. It
/// HIFN  defines which part of the waveform is shown.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referencePoint/Sets the position of the reference point in % of the screen. It
/// HIPAR referencePoint/defines which part of the waveform is shown.
ViStatus _VI_FUNC rsmxo_ConfigureHorizontalReferencePoint(ViSession instrSession,
                                                          ViReal64  referencePoint)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_REFERENCE_POINT, referencePoint),
            2, "Reference Point");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of horizontal divisions on the screen. The number
/// HIFN  cannot be changed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR divisions/Returns the number of horizontal divisions on the screen. The number
/// HIPAR divisions/cannot be changed.
ViStatus _VI_FUNC rsmxo_QueryHorizontalDivisions(ViSession instrSession,
                                                 ViReal64* divisions)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_DIVISIONS, divisions),
            2, "Divisions");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures settings for the reference clock.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects reference clock source - internal or external.
ViStatus _VI_FUNC rsmxo_ConfigureHorizontalReferenceClockSource(
                            ViSession instrSession,
                            ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_REFERENCE_CLOCK_SOURCE, source),
            2, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures settings for the reference clock.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR output10MHz/Enables the use of an external 10MHz reference signal instead of the
/// HIPAR output10MHz/internal reference clock.
ViStatus _VI_FUNC rsmxo_EnableHorizontalReferenceClock10MHzOutput(
                            ViSession instrSession,
                            ViBoolean output10MHz)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_REFERENCE_CLOCK_OUTPUT_10_MHZ_ENABLED, output10MHz),
            2, "Output 10 MHz");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures horizontal roll.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Selects, if the roll mode is set automatically by the instrument or if
/// HIPAR enabled/it is turned off.
/// HIPAR acquisitionTime/Sets the minimum acquisition time for automatic start of the roll
/// HIPAR acquisitionTime/mode.
ViStatus _VI_FUNC rsmxo_ConfigureHorizontalRoll(ViSession instrSession,
                                                ViInt32   enabled,
                                                ViReal64  acquisitionTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_ROLL_ENABLED, enabled),
            2, "Enabled");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_ROLL_ACQUISITION_TIME, acquisitionTime),
            3, "Acquisition Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the status of the roll mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR status/Returns the status of the roll mode.
ViStatus _VI_FUNC rsmxo_QueryHorizontalRollStatus(ViSession  instrSession,
                                                  ViBoolean* status)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_HORIZONTAL_ROLL_STATUS, status),
            2, "Status");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables the zoom.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layoutset/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR zoomState/Enables the zoom.
ViStatus _VI_FUNC rsmxo_EnableZoom(ViSession instrSession,
                                   ViInt32   layout,
                                   ViInt32   zoom,
                                   ViBoolean zoomState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_ZOOM_STATE, zoomState),
            4, "Zoom State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the max number of available zooms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoomCount/Returns the max number of available zooms.
ViStatus _VI_FUNC rsmxo_QueryZoomCount(ViSession instrSession,
                                       ViInt32   layout,
                                       ViInt32*  zoomCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_COUNT,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_ZOOM_COUNT, zoomCount),
            3, "Zoom Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines if absolute or relative values are used to specify the x-axis
/// HIFN  values. Since the zoom area refers to the active signal, relative
/// HIFN  values ensure that the zoom area remains the same.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR mode/Defines if absolute or relative values are used to specify the x-axis
/// HIPAR mode/values. Since the zoom area refers to the active signal, relative
/// HIPAR mode/values ensure that the zoom area remains the same.
ViStatus _VI_FUNC rsmxo_ConfigureZoomModeHorizontal(ViSession instrSession,
                                                    ViInt32   layout,
                                                    ViInt32   zoom,
                                                    ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_ZOOM_MODE_HORIZONTAL, mode),
            4, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the lower and upper limits of the zoom area on the x-axis in
/// HIFN  absolute values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR start/Defines the lower limit of the zoom area on the x-axis in absolute
/// HIPAR start/values.
/// HIPAR stop/Defines the upper limit of the zoom area on the x-axis in absolute
/// HIPAR stop/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomXAbsoluteStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_ABSOLUTE_START, start),
            4, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_ABSOLUTE_STOP, stop),
            5, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the width and position of the zoom area in absolute values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR range/Defines the width of the zoom area in absolute values.
/// HIPAR position/Defines the x-value of the centerpoint of the zoom area in absolute
/// HIPAR position/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomXAbsolutePositionRange(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_ABSOLUTE_WIDTH, range),
            4, "Range");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_ABSOLUTE_POSITION, position),
            5, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the upper and lower limits of the zoom area on the x-axis in
/// HIFN  relative values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR start/Defines the lower limit of the zoom area on the x-axis in relaive
/// HIPAR start/values.
/// HIPAR stop/Defines the upper limit of the zoom area on the x-axis in relative
/// HIPAR stop/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomXRelativeStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_RELATIVE_START, start),
            4, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_RELATIVE_STOP, stop),
            5, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the width and position of the zoom area in relative values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR range/Defines the width of the zoom area in relative values.
/// HIPAR position/Defines the x-value of the centerpoint of the zoom area in relative
/// HIPAR position/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomXRelativePositionRange(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_RELATIVE_WIDTH, range),
            4, "Range");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_X_RELATIVE_POSITION, position),
            5, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines if absolute or relative values are used to specify the y-axis
/// HIFN  values. Since the zoom area refers to the active signal, relative
/// HIFN  values ensure that the zoom area remains the same.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR mode/Defines if absolute or relative values are used to specify the y-axis
/// HIPAR mode/values. Since the zoom area refers to the active signal, relative
/// HIPAR mode/values ensure that the zoom area remains the same.
ViStatus _VI_FUNC rsmxo_ConfigureZoomModeVertical(ViSession instrSession,
                                                  ViInt32   layout,
                                                  ViInt32   zoom,
                                                  ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_ZOOM_MODE_VERTICAL, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the lower and upper limits of the zoom area on the y-axis in
/// HIFN  absolute values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR start/Defines the lower limit of the zoom area on the y-axis in absolute
/// HIPAR start/values.
/// HIPAR stop/Defines the upper limit of the zoom area on the y-axis in absolute
/// HIPAR stop/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomYAbsoluteStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_ABSOLUTE_START, start),
            4, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_ABSOLUTE_STOP, stop),
            5, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the height and position of the zoom area in absolute values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR range/Defines the height of the zoom area in absolute values.
/// HIPAR position/Defines the y-value of the centerpoint of the zoom area in absolute
/// HIPAR position/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomYAbsolutePositionRange(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_ABSOLUTE_RANGE, range),
            4, "Range");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_ABSOLUTE_POSITION, position),
            5, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the lower and upper limits of the zoom area on the y-axis in
/// HIFN  relative values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR start/Defines the lower limit of the zoom area on the y-axis in relative
/// HIPAR start/values.
/// HIPAR stop/Defines the upper limit of the zoom area on the y-axis, in relative
/// HIPAR stop/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomYRelativeStartStop(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   zoom,
                                                        ViReal64  start,
                                                        ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_RELATIVE_START, start),
            4, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_RELATIVE_STOP, stop),
            5, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the range and y-value of the centerpoint of the zoom area in
/// HIFN  relative values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR zoom/Selects repeated capability Zoom.
/// HIPAR range/Defines the height of the zoom area in relative values.
/// HIPAR position/Defines the y-value of the centerpoint of the zoom area in relative
/// HIPAR position/values.
ViStatus _VI_FUNC rsmxo_ConfigureZoomYRelativeRangePosition(ViSession instrSession,
                                                            ViInt32   layout,
                                                            ViInt32   zoom,
                                                            ViReal64  range,
                                                            ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViChar   repCapZoom[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  zoomCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Zoom", &zoomCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, zoom, 1, zoomCount),
            3, "Zoom");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_ZOOM_STATE, "Zoom", zoom - 1, RS_REPCAP_BUF_SIZE, repCapZoom),
                3, "Zoom");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapZoom, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_RELATIVE_WIDTH, range),
            4, "Range");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_ZOOM_Y_RELATIVE_POSITION, position),
            5, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerOn/Selects the trigger mode.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerOn(ViSession instrSession,
                                           ViInt32   triggerOn)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_ON, triggerOn),
            2, "Trigger On");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger mode which determines the behaviour of the instrument
/// HIFN  with and without a trigger event.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerMode/Sets the trigger mode which determines the behaviour of the instrument
/// HIPAR triggerMode/with and without a trigger event.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerMode(ViSession instrSession,
                                             ViInt32   triggerMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_MODE, triggerMode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Forces trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_TriggerForce(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_TRIGGER_FORCE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the source of the trigger signal for the selected trigger
/// HIFN  event. The trigger source works even if it is not displayed in a
/// HIFN  diagram.
/// HIFN
/// HIFN     Available sources depend on the trigger sequence setting. If you
/// HIFN  trigger on a single event, all inputs can be used as trigger source. If
/// HIFN  you trigger on a sequence, only analog channels can be set as trigger
/// HIFN  source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR source/Selects the source of the trigger signal for the selected trigger
/// HIPAR source/event. The trigger source works even if it is not displayed in a
/// HIPAR source/diagram.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSource(ViSession instrSession,
                                               ViInt32   trigger,
                                               ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SOURCE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger type specific for each condition in a trigger
/// HIFN  sequence. The current trigger type is shown on the button.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR type/Selects the trigger type specific for each condition in a trigger
/// HIPAR type/sequence. The current trigger type is shown on the button.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerType(ViSession instrSession,
                                             ViInt32   trigger,
                                             ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_TYPE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger level for the specified event and source (channel).
/// HIFN
/// HIFN     If the trigger source is serial bus, the trigger level is set by the
/// HIFN  thresholds in the protocol configuration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR level/Sets the trigger level for the specified event and source (channel).
ViStatus _VI_FUNC rsmxo_ConfigureTriggerLevel(ViSession instrSession,
                                              ViInt32   trigger,
                                              ViInt32   channel,
                                              ViReal64  level)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_EVENT_LEVEL,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            3, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_EVENT_LEVEL, "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_EVENT_LEVEL, level),
            4, "Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger level automatically to 0.5 * (MaxPeak - MinPeak).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
ViStatus _VI_FUNC rsmxo_FindTriggerLevel(ViSession instrSession,
                                         ViInt32   trigger)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_TYPE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_TRIGGER_FIND_LEVEL, NULL),
            3, "Trigger");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the type of the trigger sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the type of the trigger sequence.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceType(ViSession instrSession,
                                                     ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_SEQUENCE_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the time that the instrument waits after an A-trigger until it
/// HIFN  recognizes B-triggers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR delay/Sets the time that the instrument waits after an A-trigger until it
/// HIPAR delay/recognizes B-triggers.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceDelay(ViSession instrSession,
                                                      ViReal64  delay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_SEQUENCE_DELAY, delay),
            2, "Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of B-trigger conditions to be fulfilled after an
/// HIFN  A-trigger. The last B-trigger causes the trigger event. The waiting
/// HIFN  time for B-triggers can be restricted with a reset condition: timeout
/// HIFN  or reset event.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR count/Sets the number of B-trigger conditions to be fulfilled after an
/// HIPAR count/A-trigger. The last B-trigger causes the trigger event. The waiting
/// HIPAR count/time for B-triggers can be restricted with a reset condition: timeout
/// HIPAR count/or reset event.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceBEventCount(ViSession instrSession,
                                                            ViInt32   count)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_SEQUENCE_B_EVENT_COUNT, count),
            2, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures trigger reset settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR resetEvent/If enabled, the trigger sequence is restarted by the R-trigger
/// HIPAR resetEvent/condition if the specified number of B-triggers does not occur before
/// HIPAR resetEvent/the R-trigger conditions are fulfilled.
/// HIPAR resetTime/If set to ON, the instrument waits for the time defined using
/// HIPAR resetTime/RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_TIMEOUT for the specified number of
/// HIPAR resetTime/B-events. If no trigger occurs during that time, the sequence is
/// HIPAR resetTime/restarted with the A-event.
/// HIPAR resetTimeout/The time the instrument waits for the number of B-events specified
/// HIPAR resetTimeout/using RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_TIME_ENABLED, before the
/// HIPAR resetTimeout/sequence is restarted with the A-trigger.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSequenceResetSettings(
                            ViSession instrSession,
                            ViBoolean resetEvent,
                            ViBoolean resetTime,
                            ViReal64  resetTimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_EVENT_ENABLED, resetEvent),
            2, "Reset Event");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_TIME_ENABLED, resetTime),
            3, "Reset Time");

    if (resetTime)
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_SEQUENCE_RESET_TIMEOUT, resetTimeout),
                4, "Reset Timeout");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the edge direction for the trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR slope/Sets the edge direction for the trigger.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeSlope(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_EDGE_SLOPE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_EDGE_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the polarity of a pulse, that is the direction of the first pulse
/// HIFN  slope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR polarity/Sets the polarity of a pulse, that is the direction of the first pulse
/// HIPAR polarity/slope.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerGlitchPolarity(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   polarity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_GLITCH_POLARITY,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_GLITCH_POLARITY, polarity),
            3, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects which glitches are identified: shorter or longer than the
/// HIFN  width specified using RSMXO_ATTR_TRIGGER_GLITCH_WIDTH.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR range/Selects which glitches are identified: shorter or longer than the
/// HIPAR range/width specified using RSMXO_ATTR_TRIGGER_GLITCH_WIDTH.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerGlitchRange(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViInt32   range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_GLITCH_RANGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_GLITCH_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the length of a glitch. The instrument triggers on pulses shorter
/// HIFN  or longer than this value, depending on the value set with
/// HIFN  RSMXO_ATTR_TRIGGER_GLITCH_RANGE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR width/Sets the length of a glitch. The instrument triggers on pulses shorter
/// HIPAR width/or longer than this value, depending on the value set with
/// HIPAR width/RSMXO_ATTR_TRIGGER_GLITCH_RANGE.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerGlitchWidth(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  width)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_GLITCH_WIDTH,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_GLITCH_WIDTH, width),
            3, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the polarity of a pulse, that is the direction of the first pulse
/// HIFN  slope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR polarity/Sets the polarity of a pulse, that is the direction of the first pulse
/// HIPAR polarity/slope.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthPolarity(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   polarity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WIDTH_POLARITY,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_WIDTH_POLARITY, polarity),
            3, "Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects how the range of a pulse width is defined.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR range/Selects how the range of a pulse width is defined.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthRange(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WIDTH_RANGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_WIDTH_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Depending on the values of RSMXO_ATTR_TRIGGER_WIDTH_RANGE the width
/// HIFN  sets:
/// HIFN
/// HIFN     For the ranges Within and Outside the width defines the center of a
/// HIFN  time range which is defined by the limits Delta (see
/// HIFN  RSMXO_ATTR_TRIGGER_WIDTH_DELTA).For the ranges Shorter and Longer, it
/// HIFN  defines the maximum and minimum time lapse, respectively.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR width/Depending on the values of RSMXO_ATTR_TRIGGER_WIDTH_RANGE the width
/// HIPAR width/sets:
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthWidth(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViReal64  width)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WIDTH_WIDTH,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_WIDTH_WIDTH, width),
            3, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a range around the width value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR delta/Defines a range around the width value.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWidthDelta(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViReal64  delta)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WIDTH_DELTA,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_WIDTH_DELTA, delta),
            3, "Delta");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the polarity of a pulse, that is the direction of the first pulse
/// HIFN  slope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR polarity/Sets the polarity of a pulse, that is the direction of the first pulse
/// HIPAR polarity/slope.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntPolarity(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   polarity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_RUNT_POLARITY,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_RUNT_POLARITY, polarity),
            3, "Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the time limit of the runt pulse in relation to the
/// HIFN  RSMXO_ATTR_TRIGGER_RUNT_WIDTH and RSMXO_ATTR_TRIGGER_RUNT_DELTA
/// HIFN  settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR range/Defines the time limit of the runt pulse in relation to the
/// HIPAR range/RSMXO_ATTR_TRIGGER_RUNT_WIDTH and RSMXO_ATTR_TRIGGER_RUNT_DELTA
/// HIPAR range/settings.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntRange(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViInt32   range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_RUNT_RANGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_RUNT_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the upper or lower voltage threshold.
/// HIFN
/// HIFN     It is not available if RSMXO_ATTR_TRIGGER_RUNT_RANGE is set to ANY.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR width/Defines the upper or lower voltage threshold.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntWidth(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViReal64  width)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_RUNT_WIDTH,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_RUNT_WIDTH, width),
            3, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a range around the runt width specified using
/// HIFN  RSMXO_ATTR_TRIGGER_RUNT_WIDTH.
/// HIFN
/// HIFN     Available if RSMXO_ATTR_TRIGGER_RUNT_RANGE is set to WITHin or
/// HIFN  OUTSide.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR delta/Defines a range around the runt width specified using
/// HIPAR delta/RSMXO_ATTR_TRIGGER_RUNT_WIDTH.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntDelta(ViSession instrSession,
                                                  ViInt32   trigger,
                                                  ViReal64  delta)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_RUNT_DELTA,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_RUNT_DELTA, delta),
            3, "Delta");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the lower and upper voltage limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR lowerLevel/Sets the lower voltage limit.
/// HIPAR upperLevel/Sets the upper voltage limit.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerRuntLimits(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   channel,
                                                   ViReal64  lowerLevel,
                                                   ViReal64  upperLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_RUNT_LOWER_LIMIT,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            3, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_RUNT_LOWER_LIMIT, "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_RUNT_LOWER_LIMIT, lowerLevel),
            4, "Lower Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_RUNT_UPPER_LIMIT, upperLevel),
            5, "Upper Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects how the signal run is compared with the window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR verticalCondition/Selects how the signal run is compared with the window.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowVerticalCondition(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   verticalCondition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION, verticalCondition),
            3, "Vertical Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the lower and upper voltage limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR lowerLevel/Sets the lower voltage limit.
/// HIPAR upperLevel/Sets the upper voltage limit.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowLimits(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   channel,
                                                     ViReal64  lowerLevel,
                                                     ViReal64  upperLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WINDOW_LOWER_LIMIT,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            3, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WINDOW_LOWER_LIMIT, "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_WINDOW_LOWER_LIMIT, lowerLevel),
            4, "Lower Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_WINDOW_UPPER_LIMIT, upperLevel),
            5, "Upper Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Available for RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION set to
/// HIFN  Within and Outside.
/// HIFN
/// HIFN     Selects how the time limit of the window is defined.
/// HIFN
/// HIFN     You can specify the width with RSMXO_ATTR_TRIGGER_WINDOW_WIDTH and the
/// HIFN  delta with RSMXO_ATTR_TRIGGER_WINDOW_DELTA.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR timeCondition/Available for RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION set to
/// HIPAR timeCondition/Within and Outside.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowTimeCondition(ViSession instrSession,
                                                            ViInt32   trigger,
                                                            ViInt32   timeCondition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WINDOW_TIME_CONDITION,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_WINDOW_TIME_CONDITION, timeCondition),
            3, "Time Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Depending on the values of
/// HIFN  RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION the width sets:
/// HIFN
/// HIFN     For the ranges Within and Outside the width defines the center of a
/// HIFN  time range which is defined by the limits Delta (see
/// HIFN  RSMXO_ATTR_TRIGGER_WINDOW_DELTA).
/// HIFN
/// HIFN     For the ranges Shorter and Longer, it defines the maximum and minimum
/// HIFN  time lapse respectively.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR width/Depending on the values of
/// HIPAR width/RSMXO_ATTR_TRIGGER_WINDOW_VERTICAL_CONDITION the width sets:
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowWidth(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  width)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WINDOW_WIDTH,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_WINDOW_WIDTH, width),
            3, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a range around the width value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR delta/Defines a range around the width value.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerWindowDelta(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  delta)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_WINDOW_DELTA,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_WINDOW_DELTA, delta),
            3, "Delta");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the time limit for the timeout at which the instrument triggers.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR time/Sets the time limit for the timeout at which the instrument triggers.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerTimeoutTime(ViSession instrSession,
                                                    ViInt32   trigger,
                                                    ViReal64  time)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_TIMEOUT_TIME,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_TIMEOUT_TIME, time),
            3, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the relation of the signal level to the trigger level for the
/// HIFN  timeout trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR range/Sets the relation of the signal level to the trigger level for the
/// HIPAR range/timeout trigger.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerTimeoutRange(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViInt32   range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_TIMEOUT_RANGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_TIMEOUT_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge for the trigger. You can analyze the interval between
/// HIFN  positive edges or between negative edges.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR slope/Sets the edge for the trigger. You can analyze the interval between
/// HIPAR slope/positive edges or between negative edges.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalSlope(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_INTERVAL_SLOPE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_INTERVAL_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the range of an interval in relation to the interval width
/// HIFN  specified using RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH and
/// HIFN  RSMXO_ATTR_TRIGGER_INTERVAL_DELTA.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR range/Defines the range of an interval in relation to the interval width
/// HIPAR range/specified using RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH and
/// HIPAR range/RSMXO_ATTR_TRIGGER_INTERVAL_DELTA.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalRange(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_INTERVAL_RANGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_INTERVAL_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects how the range of an interval is defined.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR width/Selects how the range of an interval is defined.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalWidth(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViReal64  width)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH, width),
            3, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a range around the interval width value specified with
/// HIFN  RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR delta/Sets a range around the interval width value specified with
/// HIPAR delta/RSMXO_ATTR_TRIGGER_INTERVAL_WIDTH.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerIntervalDelta(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViReal64  delta)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_INTERVAL_DELTA,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_INTERVAL_DELTA, delta),
            3, "Delta");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge direction for the trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR slope/Sets the edge direction for the trigger.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateSlope(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SLEW_RATE_SLOPE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_SLEW_RATE_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects how the time limit for the slew rate is defined. The time
/// HIFN  measurement starts when the signal crosses the first trigger level -
/// HIFN  the upper or lower limit depending on the selected slope. The
/// HIFN  measurement stops when the signal crosses the second level.
/// HIFN
/// HIFN     You can slect the rate with RSMXO_ATTR_TRIGGER_SLEW_RATE_TIME and set
/// HIFN  the delta with RSMXO_ATTR_TRIGGER_SLEW_RATE_DELTA
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR range/Selects how the time limit for the slew rate is defined. The time
/// HIPAR range/measurement starts when the signal crosses the first trigger level -
/// HIPAR range/the upper or lower limit depending on the selected slope. The
/// HIPAR range/measurement stops when the signal crosses the second level.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateRange(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   range)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SLEW_RATE_RANGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_SLEW_RATE_RANGE, range),
            3, "Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  For RSMXO_ATTR_TRIGGER_SLEW_RATE_RANGE INSRange and OUTRange, the slew
/// HIFN  rate defines the center of a range which is defined by the limits
/// HIFN  Delta.
/// HIFN
/// HIFN     For RSMXO_ATTR_TRIGGER_SLEW_RATE_RANGE = LTHan and GTHan, the slew
/// HIFN  rate defines the maximum and minimum slew rate limits, respectively.
/// HIFN  When the signal crosses this level, the slew rate measurement starts or
/// HIFN  stops depending on the selected slope (see
/// HIFN  RSMXO_ATTR_TRIGGER_SLEW_RATE_SLOPE).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR time/For RSMXO_ATTR_TRIGGER_SLEW_RATE_RANGE INSRange and OUTRange, the slew
/// HIPAR time/rate defines the center of a range which is defined by the limits
/// HIPAR time/Delta.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateTime(ViSession instrSession,
                                                     ViInt32   trigger,
                                                     ViReal64  time)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SLEW_RATE_TIME,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SLEW_RATE_TIME, time),
            3, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a time range around the given slew rate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR delta/Defines a time range around the given slew rate.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateDelta(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViReal64  delta)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SLEW_RATE_DELTA,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SLEW_RATE_DELTA, delta),
            3, "Delta");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the lower and upper voltage threshold. When the signal crosses
/// HIFN  this level, the slew rate measurement starts or stops depending on the
/// HIFN  selected slope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR lowerLevel/Sets the lower voltage threshold. When the signal crosses this level,
/// HIPAR lowerLevel/the slew rate measurement starts or stops depending on the selected
/// HIPAR lowerLevel/slope.
/// HIPAR upperLevel/Sets the upper voltage threshold. When the signal crosses this level,
/// HIPAR upperLevel/the slew rate measurement starts or stops depending on the selected
/// HIPAR upperLevel/slope.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSlewRateLimits(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   channel,
                                                       ViReal64  lowerLevel,
                                                       ViReal64  upperLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SLEW_RATE_LOWER_LIMIT,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            3, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SLEW_RATE_LOWER_LIMIT, "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SLEW_RATE_LOWER_LIMIT, lowerLevel),
            4, "Lower Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SLEW_RATE_UPPER_LIMIT, upperLevel),
            5, "Upper Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge direction for the trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR slope/Sets the edge direction for the trigger.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateSlope(ViSession instrSession,
                                                   ViInt32   trigger,
                                                   ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_SLOPE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_STATE_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the logic combination of the channels and their states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR logicOperator/Defines the logic combination of the channels and their states.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateOperator(ViSession instrSession,
                                                      ViInt32   trigger,
                                                      ViInt32   logicOperator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_OPERATOR,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_STATE_OPERATOR, logicOperator),
            3, "Logic Operator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Set the state for each channel. For the state trigger, the clock
/// HIFN  source is indicated and does not get a state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR state/Set the state for each channel. For the state trigger, the clock
/// HIPAR state/source is indicated and does not get a state.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateChannel(ViSession instrSession,
                                                     ViInt32   triggerEvent,
                                                     ViInt32   channel,
                                                     ViInt32   triggerStateChannel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, triggerEvent, 1, triggerCount),
            2, "TriggerEvent");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_CHANNEL,
            "TriggerEvent", triggerEvent - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            3, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_CHANNEL, "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_STATE_CHANNEL, triggerStateChannel),
            4, "TriggerStateChannel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the logic combination of the channels and their states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR operatorType/Defines the logic combination of the channels and their states.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateDigitalStateOperator(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   operatorType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, repCapCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_DIGITAL_STATE_OPERATOR,
            "Trigger", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_STATE_DIGITAL_STATE_OPERATOR, operatorType),
            3, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the required state for each digital channel that is used for
/// HIFN  triggering.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR state/Sets the required state for each digital channel that is used for
/// HIPAR state/triggering.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerStateDigitalChannelState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   digitalChannel,
                            ViInt32   state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_DIGITAL_CHANNEL_STATE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 1, channelCount),
            3, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_STATE_DIGITAL_CHANNEL_STATE, "DigitalChannel", digitalChannel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_STATE_DIGITAL_CHANNEL_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the logic combination of the channels and their states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR operator/Defines the logic combination of the channels and their states.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternOperator(ViSession instrSession,
                                                        ViInt32   trigger,
                                                        ViInt32   logicOperator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_OPERATOR,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_PATTERN_OPERATOR, logicOperator),
            3, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Set the state for each channel. For the state trigger, the clock
/// HIFN  source is indicated and does not get a state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR state/Set the state for each channel. For the state trigger, the clock
/// HIPAR state/source is indicated and does not get a state.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternChannel(ViSession instrSession,
                                                       ViInt32   trigger,
                                                       ViInt32   channel,
                                                       ViInt32   state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_CHANNEL,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            3, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_CHANNEL, "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_PATTERN_CHANNEL, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects if the source of the trigger for the pattern type is an analog
/// HIFN  or digital channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR source/Selects if the source of the trigger for the pattern type is an analog
/// HIPAR source/or digital channel.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternStateSource(ViSession instrSession,
                                                           ViInt32   trigger,
                                                           ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, repCapCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_STATE_SOURCES,
            "Trigger", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "TriggerEvent");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_PATTERN_STATE_SOURCES, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the logic combination of the channels and their states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR operatorType/Defines the logic combination of the channels and their states.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternDigitalStateOperator(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   operatorType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Trigger", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, repCapCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_STATE_OPERATOR,
            "Trigger", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_STATE_OPERATOR, operatorType),
            3, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the required state for each digital channel that is used for
/// HIFN  triggering.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR state/Sets the required state for each digital channel that is used for
/// HIPAR state/triggering.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerPatternDigitalChannelState(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   digitalChannel,
                            ViInt32   state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_CHANNEL_STATE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 1, channelCount),
            3, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_CHANNEL_STATE, "DigitalChannel", digitalChannel - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_PATTERN_DIGITAL_CHANNEL_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets setup and hold trigger edge.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR edge/Sets setup and hold trigger edge.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldEdge(ViSession instrSession,
                                                         ViInt32   trigger,
                                                         ViInt32   edge)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_EDGE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_EDGE, edge),
            3, "Edge");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger clock level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR level/Sets the trigger clock level.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldClockLevel(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViReal64  level)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_CLOCK_LEVEL,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_CLOCK_LEVEL, level),
            3, "Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the clock source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR source/Sets the clock source.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldClockSource(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_CLOCK_SOURCE,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_CLOCK_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger hold time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR time/Sets the trigger hold time.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldHoldTime(ViSession instrSession,
                                                             ViInt32   trigger,
                                                             ViReal64  time)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_HOLD_TIME,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_HOLD_TIME, time),
            3, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger setup  time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trigger/Selects repeated capability TriggerEvent.
/// HIPAR time/Sets the trigger setup  time.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerSetupAndHoldSetupTime(
                            ViSession instrSession,
                            ViInt32   trigger,
                            ViReal64  time)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  triggerCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "TriggerEvent", &triggerCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, trigger, 1, triggerCount),
            2, "Trigger");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_SETUPTIME,
            "TriggerEvent", trigger - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Trigger");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_SETUP_AND_HOLD_SETUPTIME, time),
            3, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures edge trigger coupling.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR coupling/Configures edge trigger coupling.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeCoupling(ViSession instrSession,
                                                     ViInt32   coupling)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_EDGE_COUPLING, coupling),
            2, "Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the trigger level for the external trigger source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR level/Sets the trigger level for the external trigger source.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeLevel(ViSession instrSession,
                                                  ViReal64  level)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_EDGE_LEVEL, level),
            2, "Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge trigger filter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR filter/Sets the edge trigger filter.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerEdgeFilter(ViSession instrSession,
                                                   ViInt32   filter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_EDGE_FILTER, filter),
            2, "Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the low pass cut off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lowPass/Sets the low pass cut off.
ViStatus _VI_FUNC rsmxo_QueryTriggerEdgeLowPass(ViSession instrSession,
                                                ViInt32*  lowPass)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_EDGE_LOW_PASS, lowPass),
            2, "Low Pass");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the high pass cutt off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR highPass/Sets the high pass cutt off.
ViStatus _VI_FUNC rsmxo_QueryTriggerEdgeHighPass(ViSession instrSession,
                                                 ViInt32*  highPass)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_EDGE_HIGH_PASS, highPass),
            2, "High Pass");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables noise reject for edge trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerNoiseReject/Enables or disables noise reject for edge trigger.
ViStatus _VI_FUNC rsmxo_EnableTriggerNoiseReject(ViSession instrSession,
                                                 ViBoolean triggerNoiseReject)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_TRIGGER_EDGE_NOISE_REJECT_ENABLED, triggerNoiseReject),
            2, "Trigger Noise Reject");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the method to define the holdoff condition.
/// HIFN
/// HIFN     The trigger holdoff defines when the next trigger after the current
/// HIFN  will be recognized. Thus, it affects the next trigger to occur after
/// HIFN  the current one. Holdoff helps to obtain stable triggering when the
/// HIFN  oscilloscope is triggering on undesired events.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerMode/Selects the method to define the holdoff condition.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffMode(ViSession instrSession,
                                                    ViInt32   triggerMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_MODE, triggerMode),
            2, "Trigger Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the holdoff time period, if RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is
/// HIFN  set to TIME. The next trigger occurs only after this time has passed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR holdoffTime/Defines the holdoff time period, if RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is
/// HIPAR holdoffTime/set to TIME. The next trigger occurs only after this time has passed.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffTime(ViSession instrSession,
                                                    ViReal64  holdoffTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_TIME, holdoffTime),
            2, "Hold Off Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the number of triggers to be skipped, if
/// HIFN  RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is set to EVENts. The next trigger only
/// HIFN  occurs when this number of events is reached.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR holdoffEvents/Defines the number of triggers to be skipped, if
/// HIPAR holdoffEvents/RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is set to EVENts. The next trigger only
/// HIPAR holdoffEvents/occurs when this number of events is reached.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffEvents(ViSession instrSession,
                                                      ViInt32   holdoffEvents)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_EVENTS, holdoffEvents),
            2, "Hold Off Events");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the lower and upper limit for the random time holdoff, if
/// HIFN  RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is set to RANDom.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR minimumTime/Defines the lower limit for the random time holdoff, if
/// HIPAR minimumTime/RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is set to RANDom.
/// HIPAR maximumTime/Defines the upper limit for the random time holdoff, if
/// HIPAR maximumTime/RSMXO_ATTR_TRIGGER_HOLDOFF_MODE is set to RANDom.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffRandom(ViSession instrSession,
                                                      ViReal64  minimumTime,
                                                      ViReal64  maximumTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_MINIMUM_TIME, minimumTime),
            2, "Minimum Time");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_MAXIMUM_TIME, maximumTime),
            3, "Maximum Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the auto time scaling factor that the horizontal scale is
/// HIFN  multipied with, if RSMXO_ATTR_TRIGGER_HOLDOFF_MODE E is set to AUTO.
/// HIFN  Auto time = Auto time scaling * Horizontal scale
/// HIFN
/// HIFN     The next trigger occurs only after this time has passed.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoTimeScaling/Sets the auto time scaling factor that the horizontal scale is
/// HIPAR autoTimeScaling/multipied with, if RSMXO_ATTR_TRIGGER_HOLDOFF_MODE E is set to AUTO.
/// HIPAR autoTimeScaling/Auto time = Auto time scaling * Horizontal scale
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHoldoffAutoTimeScaling(
                            ViSession instrSession,
                            ViReal64  autoTimeScaling)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_AUTO_TIME_SCALING, autoTimeScaling),
            2, "Auto Time Scaling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the resulting holdoff time, if RSMXO_ATTR_TRIGGER_HOLDOFF_MODE
/// HIFN  is set to  AUTO: Auto time = Auto time scaling * Horizontal scale. The
/// HIFN  auto time scaling factor is defined with
/// HIFN  RSMXO_ATTR_TRIGGER_HOLDOFF_AUTO_TIME_SCALING
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoTime/Returns the resulting holdoff time, if RSMXO_ATTR_TRIGGER_HOLDOFF_MODE
/// HIPAR autoTime/is set to  AUTO: Auto time = Auto time scaling * Horizontal scale. The
/// HIPAR autoTime/auto time scaling factor is defined with
/// HIPAR autoTime/RSMXO_ATTR_TRIGGER_HOLDOFF_AUTO_TIME_SCALING
ViStatus _VI_FUNC rsmxo_QueryTriggerHoldoffAutoTime(ViSession instrSession,
                                                    ViReal64* autoTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_HOLDOFF_AUTO_TIME, autoTime),
            2, "Auto Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects how the hysteresis is set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR hysteresisMode/Selects how the hysteresis is set.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisMode(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   hysteresisMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_HYSTERESIS_MODE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_HYSTERESIS_MODE, hysteresisMode),
            3, "Hysteresis Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects whether the hysteresis is defined in absolute or relative
/// HIFN  values. The setting is available only in manual hysteresis mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR sizeMode/Selects whether the hysteresis is defined in absolute or relative
/// HIPAR sizeMode/values. The setting is available only in manual hysteresis mode.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisSizeMode(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   sizeMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_HYSTERESIS_SIZE_MODE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_TRIGGER_HYSTERESIS_SIZE_MODE, sizeMode),
            3, "Size Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a range in absolute values around the trigger level. If the
/// HIFN  signal jitters inside this range and crosses the trigger level thereby,
/// HIFN  no trigger event occurs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR absoluteHysteresis/Defines a range in absolute values around the trigger level. If the
/// HIPAR absoluteHysteresis/signal jitters inside this range and crosses the trigger level thereby,
/// HIPAR absoluteHysteresis/no trigger event occurs.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisAbsolute(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViReal64  absoluteHysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_HYSTERESIS_ABSOLUTE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_HYSTERESIS_ABSOLUTE, absoluteHysteresis),
            3, "Absolute Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a range in divisions around the trigger level in division
/// HIFN  units. If the signal oscillates inside this range and crosses the
/// HIFN  trigger level thereby, no trigger event occurs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR relativeHysteresisDivs/Defines a range in divisions around the trigger level in division
/// HIPAR relativeHysteresisDivs/units. If the signal oscillates inside this range and crosses the
/// HIPAR relativeHysteresisDivs/trigger level thereby, no trigger event occurs.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisRelativeDivs(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  relativeHysteresisDivs)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_HYSTERESIS_RELATIVE_DIVS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_HYSTERESIS_RELATIVE_DIVS, relativeHysteresisDivs),
            3, "Relative Hysteresis Divs");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a range in divisions around the trigger level in percents. If
/// HIFN  the signal oscillates inside this range and crosses the trigger level
/// HIFN  thereby, no trigger event occurs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR relativeHysteresis/Defines a range in divisions around the trigger level in percents. If
/// HIPAR relativeHysteresis/the signal oscillates inside this range and crosses the trigger level
/// HIPAR relativeHysteresis/thereby, no trigger event occurs.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerHysteresisRelativePercentage(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  relativeHysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_HYSTERESIS_RELATIVE_PERCENTAGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_HYSTERESIS_RELATIVE_PERCENTAGE, relativeHysteresis),
            3, "Relative Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the hardware hysteresis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR hwHysteresis/Returns the hardware hysteresis.
ViStatus _VI_FUNC rsmxo_QueryTriggerHWHysteresis(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* hwHysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_TRIGGER_HW_HYSTERESIS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_TRIGGER_HW_HYSTERESIS, hwHysteresis),
            3, "HW Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the filter mode for the trigger channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR filterMode/Selects the filter mode for the trigger channel.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerFilterMode(ViSession instrSession,
                                                   ViInt32   filterMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_FILTER_MODE, filterMode),
            2, "Filter Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the limit frequency that is applied to the trigger channel and to
/// HIFN  the input channels enabled for filtering.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lfRejectBW/Sets the limit frequency that is applied to the trigger channel and to
/// HIPAR lfRejectBW/the input channels enabled for filtering.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerFilterLFRejectBW(ViSession instrSession,
                                                         ViReal64  lfRejectBW)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_FILTER_LF_REJECT_BW, lfRejectBW),
            2, "LF Reject BW");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the limit frequency that is applied to the trigger channel and to
/// HIFN  the input channels enabled for filtering.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR rfRejectBW/Sets the limit frequency that is applied to the trigger channel and to
/// HIPAR rfRejectBW/the input channels enabled for filtering.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerFilterRFRejectBW(ViSession instrSession,
                                                         ViReal64  rfRejectBW)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_FILTER_RF_REJECT_BW, rfRejectBW),
            2, "RF Reject Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures trigger out settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerOut/Activates the outgoing pulse on the AuxOut connector on the rear
/// HIPAR triggerOut/panel.
/// HIPAR polarity/Sets the polarity of the trigger out pulse, which is the direction of
/// HIPAR polarity/the first pulse edge.
/// HIPAR delay/Defines the delay of the first pulse edge to the trigger point. The
/// HIPAR delay/minimum delay is 600ns.
/// HIPAR pulseLength/Sets the length of the trigger out pulse.
ViStatus _VI_FUNC rsmxo_ConfigureTriggerOut(ViSession instrSession,
                                            ViBoolean triggerOut,
                                            ViInt32   polarity,
                                            ViReal64  delay,
                                            ViReal64  pulseLength)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_TRIGGER_ACTION_TRIGGER_OUT_ENABLED, triggerOut),
            2, "Trigger Out");

    if (triggerOut)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_TRIGGER_ACTION_POLARITY, polarity),
                3, "Polarity");

        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_ACTION_DELAY, delay),
                4, "Delay");

        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_TRIGGER_ACTION_PULSE_LENGTH, pulseLength),
                5, "Pulse Length");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts the continuous acquisition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_RunContinuousAcquisition(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RUN_CONTINUOUS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Stops the running acquistion.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_StopAcquisition(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_ACQUISITION_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts a defined number of acquisition cycles. The number of cycles is
/// HIFN  set with RSMXO_ATTR_ACQUISITION_N_SINGLE_AVERAGE_COUNT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR maximumTimeMs/Specifies the maximum time in milliseconds for this method to complete.
/// HIPAR maximumTimeMs/Value 0 means current OPC timeout (rsmxo_SetOPCTimeout).
/// HIPAR maximumTimeMs/After that, the function ends with timeout error.
ViStatus _VI_FUNC rsmxo_RunSingleAcquisition(ViSession instrSession,
                                             ViInt32   maximumTimeMs)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  oldTimeout = -1;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_GetOPCTimeout(instrSession, &oldTimeout));

    if (maximumTimeMs > 0)
    {
        checkErr(rsmxo_SetOPCTimeout(instrSession, maximumTimeMs));
    }

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RUN_SINGLE, NULL));

Error:
    if (oldTimeout > 0)
        rsmxo_SetOPCTimeout(instrSession, oldTimeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts a defined number of acquisition cycleswithout waiting for OPC.
/// HIFN  The number of cycles is set with
/// HIFN  RSMXO_ATTR_ACQUISITION_N_SINGLE_AVERAGE_COUNT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_RunSingleAcquisitionNoWait(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RUN_SINGLE_NO_WAIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Performs an autoset process: analyzes the enabled channel signals, and
/// HIFN  obtains appropriate horizontal, vertical, and trigger settings to
/// HIFN  display stable waveforms
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_AutoscaleAcquisition(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_ACQUISITION_AUTOSCALE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how the sample rate is set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Defines how the sample rate is set.
/// HIPAR sampleRate/Sets the number of waveform points per second. It considers the
/// HIPAR sampleRate/samples of the ADC, and the processing of the captured samples
/// HIPAR sampleRate/including interpolation.
/// HIPAR minimumSampleRate/Sets the minimum sample rate, if
/// HIPAR minimumSampleRate/RSMXO_ATTR_ACQUISITION_SAMPLE_RATE_MODE is set to AUTO.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionSampleRateSettings(
                            ViSession instrSession,
                            ViInt32   mode,
                            ViReal64  sampleRate,
                            ViReal64  minimumSampleRate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_SAMPLE_RATE_MODE, mode),
            2, "Mode");

    switch (mode)
    {
    case RSMXO_VAL_ACQUISITION_SAMPLE_RATE_MODE_MANUAL:
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_SAMPLE_RATE, sampleRate),
                3, "Sample Name");
        break;

    case RSMXO_VAL_ACQUISITION_SAMPLE_RATE_MODE_AUTO:
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_MINIMUM_SAMPLE_RATE, minimumSampleRate),
                4, "Minimum Sample Rate");
        break;

    default:
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the record length settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects the mode of the waveform record length adjustment.
/// HIPAR recordLength/Sets the record length, the number of waveform samples that are stored
/// HIPAR recordLength/in one waveform record after processing, including interpolation.
/// HIPAR recordLengthLimit/Sets the maximum record length, if
/// HIPAR recordLengthLimit/RSMXO_ATTR_ACQUISITION_RECORD_LENGTH_MODE is set to AUTO.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionRecordLengthSettings(
                            ViSession instrSession,
                            ViInt32   mode,
                            ViInt32   recordLength,
                            ViReal64  recordLengthLimit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RECORD_LENGTH_MODE, mode),
            2, "Mode");

    switch (mode)
    {
    case RSMXO_VAL_ACQUISITION_RECORD_LENGTH_MODE_MANUAL:
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RECORD_LENGTH, recordLength),
                3, "Record Length");
        break;

    case RSMXO_VAL_ACQUISITION_RECORD_LENGTH_MODE_AUTO:
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RECORD_LENGTH_LIMIT, recordLengthLimit),
                4, "Record Length Limit");
        break;

    default:
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the acquisition and average count, which has a double effect:It
/// HIFN  sets the number of waveforms acquired with Single Run. It defines the
/// HIFN  number of waveforms used to calculate the average waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR nSingleAverageCount/Sets the acquisition and average count, which has a double effect:It
/// HIPAR nSingleAverageCount/sets the number of waveforms acquired with Single Run. It defines the
/// HIPAR nSingleAverageCount/number of waveforms used to calculate the average waveform.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionNSingleAverageCount(
                            ViSession instrSession,
                            ViInt32   nSingleAverageCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_N_SINGLE_AVERAGE_COUNT, nSingleAverageCount),
            2, "N-Single Average Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the time between two waveform samples in the waveform record.
/// HIFN  It consideres the processing of the captured samples including
/// HIFN  interpolation.. A fine resolution with low values produces a more
/// HIFN  precise waveform record.
/// HIFN
/// HIFN     The resolution is the reciprocal value of
/// HIFN  RSMXO_ATTR_ACQUISITION_SAMPLE_RATE
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR resolution/Defines the time between two waveform samples in the waveform record.
/// HIPAR resolution/It consideres the processing of the captured samples including
/// HIPAR resolution/interpolation.. A fine resolution with low values produces a more
/// HIPAR resolution/precise waveform record.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionResolution(ViSession instrSession,
                                                       ViReal64  resolution)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_RESOLUTION, resolution),
            2, "Resolution");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets how the waveform is built from the captured samples.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Sets how the waveform is built from the captured samples.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionMode(ViSession instrSession,
                                                 ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the interpolation method.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR interpolation/Selects the interpolation method.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionInterpolation(ViSession instrSession,
                                                          ViInt32   interpolation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_INTERPOLATION, interpolation),
            2, "Interpolation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Number of acquisitions that is saved in the memory and available for
/// HIFN  history viewing. It is also the number of acquisitions in a fast
/// HIFN  segmentation acquisition series.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR availableAquisitions/Number of acquisitions that is saved in the memory and available for
/// HIPAR availableAquisitions/history viewing. It is also the number of acquisitions in a fast
/// HIPAR availableAquisitions/segmentation acquisition series.
ViStatus _VI_FUNC rsmxo_QueryAvailableAcquisitions(ViSession instrSession,
                                                   ViInt32*  availableAcquisitions)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_AVAILABLE_ACQUISITIONS, availableAcquisitions),
            2, "Available Acquisitions");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the sample rate of the ADC, before waveform processing. The
/// HIFN  result is the interleaved sample rate or the non-interleaved one,
/// HIFN  depending on the channel usage.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR adcRate/Returns the sample rate of the ADC, before waveform processing. The
/// HIPAR adcRate/result is the interleaved sample rate or the non-interleaved one,
/// HIPAR adcRate/depending on the channel usage.
ViStatus _VI_FUNC rsmxo_QueryADCRate(ViSession instrSession,
                                     ViReal64* adcRate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_ADC_RATE, adcRate),
            2, "ADC Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the sample rate of the waveform after HW processing.
/// HIFN  Interpolation is not considered.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR realSampleRate/Returns the sample rate of the waveform after HW processing.
/// HIPAR realSampleRate/Interpolation is not considered.
ViStatus _VI_FUNC rsmxo_QueryRealSampleRate(ViSession instrSession,
                                            ViReal64* realSampleRate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_REAL_SAMPLE_RATE, realSampleRate),
            2, "Real Sample Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the current number of acquisitions that have been acquired.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR current/Returns the current number of acquisitions that have been acquired.
ViStatus _VI_FUNC rsmxo_QueryAcquisitionCurrent(ViSession instrSession,
                                                ViInt32*  current)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_CURRENT, current),
            2, "Current");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the current number of acquired waveforms that contribute to
/// HIFN  the average.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR average/Returns the current number of acquired waveforms that contribute to
/// HIPAR average/the average.
ViStatus _VI_FUNC rsmxo_QueryAcquisitionAverage(ViSession instrSession,
                                                ViInt32*  average)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_AVERAGE, average),
            2, "Average");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures settings for segmented acquistion.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR acquireMaximum/If ON, the instrument acquires the maximum number of segments that can
/// HIPAR acquireMaximum/be stored in the memory. The maximum number depends on the current
/// HIPAR acquireMaximum/sample rate and record length settings.
/// HIPAR fastSegmentation/If fast segmentation is enabled, the acquisitions are performed as
/// HIPAR fastSegmentation/fast as possible, without processing and displaying the waveforms. When
/// HIPAR fastSegmentation/acquisition has been stopped, the data is processed and the latest
/// HIPAR fastSegmentation/waveform is displayed. Older waveforms are stored in segments. You can
/// HIPAR fastSegmentation/display and analyze the segments using the history.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionSegmented(ViSession instrSession,
                                                      ViBoolean acquireMaximum,
                                                      ViBoolean fastSegmentation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_ACQUISITION_SEGMENTED_ACQUIRE_MAXIMUM_ENABLED, acquireMaximum),
            2, "Acquire Maximum");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_ACQUISITION_SEGMENTED_FAST_SEGMENTATION_ENABLED, fastSegmentation),
            3, "Fast Segmentation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the high definition mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hdEnabled/Enables high definition mode, which increases the numeric resolution
/// HIPAR hdEnabled/of the waveform signal.
/// HIPAR bandwidth/Sets the filter bandwidth for the high definition mode.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionHighDefinition(ViSession instrSession,
                                                           ViBoolean hdEnabled,
                                                           ViReal64  bandwidth)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HIGH_DEFINITION_ENABLED, hdEnabled),
            2, "HD Enabled");

    if (hdEnabled)
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HIGH_DEFINITION_BANDWIDTH, bandwidth),
                3, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Displays the resulting vertical resolution in high definition mode.
/// HIFN  The higher the filter bandwidth, the lower the resolution.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hdResolution/Displays the resulting vertical resolution in high definition mode.
/// HIPAR hdResolution/The higher the filter bandwidth, the lower the resolution.
ViStatus _VI_FUNC rsmxo_QueryHighDefinitionResolution(ViSession instrSession,
                                                      ViReal64* hdResolution)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HIGH_DEFINITION_RESOLUTION, hdResolution),
            2, "HD Resolution");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If enabled, the analyzable waveform in roll mode is extended. Samples
/// HIFN  that arrive the left edge of the display are kept, they are moved to
/// HIFN  the unvisible area on the left.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR offScreenCapture/If enabled, the analyzable waveform in roll mode is extended. Samples
/// HIPAR offScreenCapture/that arrive the left edge of the display are kept, they are moved to
/// HIPAR offScreenCapture/the unvisible area on the left.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionRollModeOffScreenCapture(
                            ViSession instrSession,
                            ViBoolean offScreenCapture)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_ACQUISITION_ROLL_MODE_OFF_SCREEN_CAPTURE, offScreenCapture),
            2, "Off Screen Capture");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the record length of the roll mode. In roll mode, the complete
/// HIFN  record is always captured, independently of the displayed waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR points/Returns the record length of the roll mode. In roll mode, the complete
/// HIPAR points/record is always captured, independently of the displayed waveform.
ViStatus _VI_FUNC rsmxo_QueryAcquisitionRollModePoints(ViSession instrSession,
                                                       ViReal64* points)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_ROLL_MODE_POINTS, points),
            2, "Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the history mode and allows you to save history waveforms to
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR showHistory/Enables the history mode and allows you to save history waveforms to
/// HIPAR showHistory/file.
ViStatus _VI_FUNC rsmxo_ShowAcquisitionHistory(ViSession instrSession,
                                               ViBoolean showHistory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_ACQUISITION_SHOW_HISTORY, showHistory),
            2, "Show History");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts and stops the replay of the history waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_PlayAcquisitionHistory(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_PLAY, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the replay of the history waveform sequence repeats
/// HIFN  automatically.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR replay/If enabled, the replay of the history waveform sequence repeats
/// HIPAR replay/automatically.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionHistoryReplay(ViSession instrSession,
                                                          ViBoolean replay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_REPLAY, replay),
            2, "Replay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures settings for viewing acquisition history.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR start/Sets the index of the first (oldest) acquisition to be displayed or
/// HIPAR start/exported. The index is always negative.
/// HIPAR stop/Sets the index of the last (newest) acquisition to be displayed or
/// HIPAR stop/exported. The newest acquisition of the complete acquisition series
/// HIPAR stop/always has the index '0'.
/// HIPAR displayTime/Sets the display time for one acquisition. The shorter the time, the
/// HIPAR displayTime/faster the replay is.
ViStatus _VI_FUNC rsmxo_ConfigureAcquisitionHistoryPlayer(ViSession instrSession,
                                                          ViInt32   start,
                                                          ViInt32   stop,
                                                          ViReal64  displayTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_START, start),
            2, "Start");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_STOP, stop),
            3, "Stop");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_DISPLAY_TIME, displayTime),
            3, "Display Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Accesses a particular acquisition in the memory to display it, or to
/// HIFN  save it. The newest acquisition always has the index '0'. Older
/// HIFN  acquisition have a negative index.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR current/Accesses a particular acquisition in the memory to display it, or to
/// HIPAR current/save it. The newest acquisition always has the index '0'. Older
/// HIPAR current/acquisition have a negative index.
ViStatus _VI_FUNC rsmxo_SelectCurrentAcquisition(ViSession instrSession,
                                                 ViInt32   current)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_SELECT_CURRENT, current),
            2, "Current");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the absolute daytime of the current acquisition
/// HIFN  (RSMXO_ATTR_ACQUISITION_HISTORY_SELECT_CURRENT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR time/Returns the absolute daytime of the current acquisition
/// HIPAR time/(RSMXO_ATTR_ACQUISITION_HISTORY_SELECT_CURRENT).
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionAbsoluteTime(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    time[],
                                                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_ABSOLUTE_TIME, bufferSize, time, bytesRead),
                3, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the date of the current acquisition
/// HIFN  (RSMXO_ATTR_ACQUISITION_HISTORY_SELECT_CURRENT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR date/Returns the date of the current acquisition
/// HIPAR date/(RSMXO_ATTR_ACQUISITION_HISTORY_SELECT_CURRENT).
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionAbsoluteDate(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    date[],
                                                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_ABSOLUTE_DATE, bufferSize, date, bytesRead),
                3, "Date");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the relative time of the current acquisition - the time
/// HIFN  difference to the newest acquisition (index = 0).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR relativeTime/Returns the relative time of the current acquisition - the time
/// HIPAR relativeTime/difference to the newest acquisition (index = 0).
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionRelativeTime(ViSession instrSession,
                                                            ViInt32   bufferSize,
                                                            ViChar    relativeTime[],
                                                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_RELATIVE_TIME, bufferSize, relativeTime, bytesRead),
                3, "Relative Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the relative time of the currently selected acquisition and
/// HIFN  the internal reference time ( horizontal alignment) in history view
/// HIFN  with respect to the acquisition with index 0.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR relativeTime/Returns the relative time of the currently selected acquisition and
/// HIPAR relativeTime/the internal reference time ( horizontal alignment) in history view
/// HIPAR relativeTime/with respect to the acquisition with index 0.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryCurrentAcquisitionReferenceRelativeTime(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    relativeTime[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_ACQUISITION_HISTORY_TIMESTAMP_REFERENCE_RELATIVE_TIME, bufferSize, relativeTime, bytesRead),
                3, "Relative Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Switches the indicated measurement on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR enabled/Switches the indicated measurement on or off.
ViStatus _VI_FUNC rsmxo_EnableMeasurement(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the maximum number of measurements, which is the maximum value
/// HIFN  for the <mg> suffix.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR count/Returns the maximum number of measurements, which is the maximum value
/// HIPAR count/for the <mg> suffix.
ViStatus _VI_FUNC rsmxo_QueryMeasurementCount(ViSession instrSession,
                                              ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_MEASUREMENT_COUNT, count),
            2, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the measurement that is used as a source for math calculations
/// HIFN  and result analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR type/Defines the measurement that is used as a source for math calculations
/// HIPAR type/and result analysis.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementType(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_TYPE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the source of the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR source/Selects signal for the measurement.
/// HIPAR source2/Selects signal for the measurement.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementSource(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViInt32   source,
                                                   ViInt32   source2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar*  p2SourceCmdStr;
    ViChar*  p2Source2CmdStr;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngSource, source, &p2SourceCmdStr),
                3, "Source");

    if (source2 == RSMXO_VAL_SOURCE_NONE)
    {
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s", p2SourceCmdStr);
    }
    else
    {
        viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngSource, source2, &p2Source2CmdStr),
                    4, "Source 2")

        (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,%s", p2SourceCmdStr, p2Source2CmdStr);
    }

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_MEASUREMENT_SOURCE, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the first measurement source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR source/Defines the first measurement source.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementSource1(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_SOURCE_1,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_SOURCE_1, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the second measurement source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR source2/Defines the second measurement source.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementSource2(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   source2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_SOURCE_2,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_SOURCE_2, source2),
            3, "Source 2");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the gate of the measurement. Enable a gate before you assign a
/// HIFN  measurement to it (RSMXO_ATTR_GATE_ENABLED).
/// HIFN
/// HIFN     The query returns 0, if no gate is assigned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR gate/Sets the gate of the measurement. Enable a gate before you assign a
/// HIPAR gate/measurement to it (RSMXO_ATTR_GATE_ENABLED).
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementGate(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   gate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_GATE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_GATE, gate),
            3, "Gate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Relevant only for measurements on envelope waveforms. It selects the
/// HIFN  envelope to be used for measurement.
/// HIFN
/// HIFN     Prerequisites:
/// HIFN
/// HIFN     RSMXO_ATTR_ACQUISITION_MODE is set to Envelope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR envelope/Relevant only for measurements on envelope waveforms. It selects the
/// HIPAR envelope/envelope to be used for measurement.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementEnvelope(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViInt32   envelope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_ENVELOPE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_ENVELOPE, envelope),
            3, "Envelope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables statistics calculation for the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR statistics/Enables statistics calculation for the measurement.
ViStatus _VI_FUNC rsmxo_EnableMeasurementStatistics(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViBoolean statistics)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_STATISTICS_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_STATISTICS_ENABLED, statistics),
            3, "Statisctics");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If ON, the measurement is performed repeatedly if the measured
/// HIFN  parameter occurs several times inside the acquisition or defined gate.
/// HIFN  All results are included in evaluation, e.g. in statistics. To set the
/// HIFN  number of results to be considered, use
/// HIFN  RSMXO_ATTR_MEASUREMENT_STATISTICS_MAXIMUM_EVENTS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR allEvents/If ON, the measurement is performed repeatedly if the measured
/// HIPAR allEvents/parameter occurs several times inside the acquisition or defined gate.
/// HIPAR allEvents/All results are included in evaluation, e.g. in statistics. To set the
/// HIPAR allEvents/number of results to be considered, use
/// HIPAR allEvents/RSMXO_ATTR_MEASUREMENT_STATISTICS_MAXIMUM_EVENTS.
ViStatus _VI_FUNC rsmxo_EnableMeasurementStatisticsAllEvents(ViSession instrSession,
                                                             ViBoolean allEvents)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED, allEvents),
            2, "All Events");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the maximum number of measurements per acquisition if
/// HIFN  RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED is on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR maximumEvents/Sets the maximum number of measurements per acquisition if
/// HIPAR maximumEvents/RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED is on.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementStatisticsMaximumEvents(
                            ViSession instrSession,
                            ViInt32   maximumEvents)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_MEASUREMENT_STATISTICS_MAXIMUM_EVENTS, maximumEvents),
            2, "Maximum Events");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the statistics.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ClearMeasurementStatisticsResults(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_MEASUREMENT_STATISTICS_CLEAR_RESULTS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the vertical scale and the offset of the track, so that the
/// HIFN  complete height of the diagram is used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
ViStatus _VI_FUNC rsmxo_MeasurementFitToScreen(ViSession instrSession,
                                               ViInt32   measurement)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_MEASUREMENT_FIT_TO_SCREEN, measurement),
            2, "Measurement");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Performs an automatic scaling whenever the track does not fit in the
/// HIFN  diagram during the measurement period.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR autoscale/Performs an automatic scaling whenever the track does not fit in the
/// HIPAR autoscale/diagram during the measurement period.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAutoscale(ViSession instrSession,
                                                      ViInt32   measurement,
                                                      ViBoolean autoscale)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AUTOSCALE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AUTOSCALE, autoscale),
            3, "Autoscale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures measurement track.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR enabled/Enables or disables the track for the selected measurement.
/// HIPAR scale/Sets or queries the vertical scale of the track diagram.
/// HIPAR offset/Sets or queries the offset of the track waveform.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementTrack(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViBoolean enabled,
                                                  ViReal64  scale,
                                                  ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_TRACK_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_TRACK_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_TRACK_SCALE, scale),
            4, "Scale");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_TRACK_WAVEFORM_OFFSET, offset),
            5, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge of the clock from which setup and hold times are
/// HIFN  measured.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR slope/Sets the edge of the clock from which setup and hold times are
/// HIPAR slope/measured.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeClockSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_CLOCK_SLOPE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_CLOCK_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Set the pulse count.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR pulseCount/Set the pulse count.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimePulseCount(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   pulseCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_PULSE_COUNT,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_PULSE_COUNT, pulseCount),
            3, "Pulse Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Set the pulse slope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR pulseSlope/Set the pulse slope.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimePulseSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   pulseSlope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_PULSE_SLOPE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_PULSE_SLOPE, pulseSlope),
            3, "Pulse Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge direction to be used for delay measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR slope/Sets the edge direction to be used for delay measurement.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeEdgesSlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_EDGES_SLOPE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_EDGES_SLOPE, slope),
            3, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the edge of each source, between which the delay is measured.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR delay/Selects repeated capability DelayRC.
/// HIPAR slope/Sets the edge of each source, between which the delay is measured.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeDelaySlope(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   delay,
                            ViInt32   slope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   delayRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViInt32  delayCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_SLOPE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DelayRC", &delayCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, delay, 1, delayCount),
            3, "Delay");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_SLOPE, "DelayRC", delay - 1, RS_REPCAP_BUF_SIZE, delayRepCap),
                3, "Delay");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", delayRepCap, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_SLOPE, slope),
            4, "Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the direction for counting slopes for each source: from the
/// HIFN  beginning of the waveform or from the end.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR delay/Selects repeated capability DelayRC.
/// HIPAR direction/Selects the direction for counting slopes for each source: from the
/// HIPAR direction/beginning of the waveform or from the end.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeDelayDirection(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   delay,
                            ViInt32   direction)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   delayRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViInt32  delayCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_DIRECTION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DelayRC", &delayCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, delay, 1, delayCount),
            3, "Delay");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_DIRECTION, "DelayRC", delay - 1, RS_REPCAP_BUF_SIZE, delayRepCap),
                3, "Delay");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", delayRepCap, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_DIRECTION, direction),
            4, "Direction");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the edge direction to be used for delay measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR delay/Selects repeated capability DelayRC.
/// HIPAR delayToTrigger/Sets the edge direction to be used for delay measurement.
ViStatus _VI_FUNC rsmxo_ConfigureMeasurementAmplitudeTimeDelayToTrigger(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32   delay,
                            ViInt32   delayToTrigger)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   delayRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViInt32  delayCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_TO_TRIGGER,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DelayRC", &delayCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, delay, 1, delayCount),
            3, "Delay");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_TO_TRIGGER, "DelayRC", delay - 1, RS_REPCAP_BUF_SIZE, delayRepCap),
                3, "Delay");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", delayRepCap, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_AMPLITUDE_TIME_DELAY_TO_TRIGGER, delayToTrigger),
            4, "Delay To Trigger");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines if the reference level is set in absolute or relative values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/Selects repeated capability ReferenceLevel.
/// HIPAR mode/Defines if the reference level is set in absolute or relative values.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelMode(ViSession instrSession,
                                                    ViInt32   referenceLevel,
                                                    ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceLevelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceLevel", &referenceLevelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceLevel, 1, referenceLevelCount),
            2, "Reference Level");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_LEVEL_MODE,
            "ReferenceLevel", referenceLevel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Level");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configure reference level absolute values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/Selects repeated capability ReferenceLevel.
/// HIPAR lowerLevel/Sets the lower reference level in absolute values. This is required,
/// HIPAR lowerLevel/e.g., to determine a fall.
/// HIPAR middleLevel/Sets the middle reference level in absolute values.
/// HIPAR upperLevel/Sets the upper reference level in absolute values. This is required to
/// HIPAR upperLevel/determine a rise.
/// HIPAR hysteresis/Defines a hysteresis for the middle reference level. A rise or fall
/// HIPAR hysteresis/from the middle reference value that does not exceed the hysteresis is
/// HIPAR hysteresis/rejected as noise.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelAbsoluteSettings(
                            ViSession instrSession,
                            ViInt32   referenceLevel,
                            ViReal64  lowerLevel,
                            ViReal64  middleLevel,
                            ViReal64  upperLevel,
                            ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceLevelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceLevel", &referenceLevelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceLevel, 1, referenceLevelCount),
            2, "Reference Level");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_LOWER,
            "ReferenceLevel", referenceLevel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_LOWER, lowerLevel),
            3, "Lower Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_MIDDLE, middleLevel),
            4, "Middle Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_UPPER, upperLevel),
            5, "Upper Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_ABSOLUTE_HYSTERESIS, hysteresis),
            6, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  The lower, middle and upper reference levels, defined as percentages
/// HIFN  of the high signal level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/Selects repeated capability ReferenceLevel.
/// HIPAR relativeMode/The lower, middle and upper reference levels, defined as percentages
/// HIPAR relativeMode/of the high signal level.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelRelativeMode(ViSession instrSession,
                                                            ViInt32   referenceLevel,
                                                            ViInt32   relativeMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceLevelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceLevel", &referenceLevelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceLevel, 1, referenceLevelCount),
            2, "Reference Level");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE,
            "ReferenceLevel", referenceLevel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Level");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE, relativeMode),
            3, "Relative Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the relative reference levels if
/// HIFN  RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE is set to User.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceLevel/Selects repeated capability ReferenceLevel.
/// HIPAR lowerLevel/Sets the lower relative reference level if
/// HIPAR lowerLevel/RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE is set to User.
/// HIPAR middleLevel/Sets the  middle relative reference level if
/// HIPAR middleLevel/RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE is set to USER.
/// HIPAR upperLevel/Sets the upper relative reference level if
/// HIPAR upperLevel/RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MODE is set to USER.
/// HIPAR hysteresis/Defines a hysteresis for the middle reference level. A rise or fall
/// HIPAR hysteresis/from the middle reference value that does not exceed the hysteresis is
/// HIPAR hysteresis/rejected as noise.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceLevelRelativeSettings(
                            ViSession instrSession,
                            ViInt32   referenceLevel,
                            ViReal64  lowerLevel,
                            ViReal64  middleLevel,
                            ViReal64  upperLevel,
                            ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceLevelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceLevel", &referenceLevelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceLevel, 1, referenceLevelCount),
            2, "Reference Level");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_LOWER,
            "ReferenceLevel", referenceLevel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_LOWER, lowerLevel),
            3, "Lower Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_MIDDLE, middleLevel),
            4, "Middle Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_UPPER, upperLevel),
            5, "Upper Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_LEVEL_RELATIVE_HYSTERESIS, hysteresis),
            6, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the start and end of the selected measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR start/Returns the start of the selected measurement.
/// HIPAR stop/Returns the end of the selected measurement.
ViStatus _VI_FUNC rsmxo_QueryMeasurementBounds(ViSession instrSession,
                                               ViInt32   measurement,
                                               ViReal64* start,
                                               ViReal64* stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_RESULTS_START,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_RESULTS_START, start),
            3, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_RESULTS_STOP, stop),
            4, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the results count in the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR count/Returns the results count in the measurement.
ViStatus _VI_FUNC rsmxo_QueryResultsCount(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_RESULTS_START,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_RESULTS_COUNT, count),
            3, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the maximum result count.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR measurementType/Selects the measurement type.
/// HIPAR count/Sets the maximum count.
ViStatus _VI_FUNC rsmxo_ConfigureResultsMaximumCount(ViSession instrSession,
                                                     ViInt32   measurement,
                                                     ViInt32   measurementType,
                                                     ViInt32   count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar*  p2measTypeCmdString;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_MAXIMUM_COUNT,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMeasurementType, measurementType, &p2measTypeCmdString),
                3, "Measurement Type");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,%ld", p2measTypeCmdString, count);

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_MAXIMUM_COUNT, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables labels for selected measurement type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR measurementType/Selects the measurement type.
/// HIPAR showLabels/Enables or disables the labels.
ViStatus _VI_FUNC rsmxo_ShowResultsLabels(ViSession instrSession,
                                          ViInt32   measurement,
                                          ViInt32   measurementType,
                                          ViBoolean showLabels)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar*  p2measTypeCmdString;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULT_SHOW_LABELS,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMeasurementType, measurementType, &p2measTypeCmdString),
                3, "Measurement Type");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,%s", p2measTypeCmdString, showLabels ? "ON" : "OFF");

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULT_SHOW_LABELS, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, displays black font on white background using the full
/// HIFN  border frame type.Z
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR inverted/If enabled, displays black font on white background using the full
/// HIPAR inverted/border frame type.
ViStatus _VI_FUNC rsmxo_EnableResultsInvertedLabel(ViSession instrSession,
                                                   ViInt32   measurement,
                                                   ViBoolean inverted)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_INVERTED_LABELS,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "PLIS,%s", inverted ? "ON" : "OFF");

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_INVERTED_LABELS, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the display of frequencies for the selected
/// HIFN  measurement type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR measurementType/Selects the measurement type.
/// HIPAR showFrequency/Enables or disables the frequency display.
ViStatus _VI_FUNC rsmxo_ShowResultsFrequency(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   measurementType,
                                             ViBoolean showFrequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar*  p2measTypeCmdString;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_SHOW_FREQUENCY,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMeasurementType, measurementType, &p2measTypeCmdString),
                3, "Measurement Type");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,%s", p2measTypeCmdString, showFrequency ? "ON" : "OFF");

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_SHOW_FREQUENCY, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the layout of the labels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR layout/Selects the label layout.
ViStatus _VI_FUNC rsmxo_ConfigureResultsLabelsOrder(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   layout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar*  p2layoutCmdString;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_LABELS_ORDER,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngResultsLabelLayout, layout, &p2layoutCmdString),
                3, "Measurement Type");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "PLIS,%s", p2layoutCmdString);

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_LABELS_ORDER, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the number of measured events in one acquisition. Relevant for
/// HIFN  measurements of all events, see
/// HIFN  RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR eventCount/Returns the number of measured events in one acquisition. Relevant for
/// HIPAR eventCount/measurements of all events, see
/// HIPAR eventCount/RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
ViStatus _VI_FUNC rsmxo_QueryResultsEventCount(ViSession instrSession,
                                               ViInt32   measurement,
                                               ViInt32*  eventCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_RESULTS_EVENT_COUNT,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_RESULTS_EVENT_COUNT, eventCount),
            3, "Event Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the start time of the indicated measured event. Relevant for
/// HIFN  measurements of all events, see
/// HIFN  RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR eventIndex/Index number of the measured event.
/// HIPAR start/Returns the start time of the indicated measured event. Relevant for
/// HIPAR start/measurements of all events, see
/// HIPAR start/RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
ViStatus _VI_FUNC rsmxo_GetResultsEventStart(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   eventIndex,
                                             ViReal64* start)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_EVENT_START,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, eventIndex, 1, 1000000),
            3, "Event Index");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%ld", eventIndex);

    viCheckParm(RsCore_GetAttributeViReal64WithQparam(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_EVENT_START, param, start),
                4, "Start");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the end time of the indicated measured event. Relevant for
/// HIFN  measurements of all events, see
/// HIFN  RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR eventIndex/Index number of the measured event.
/// HIPAR stop/Returns the end time of the indicated measured event. Relevant for
/// HIPAR stop/measurements of all events, see
/// HIPAR stop/RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
ViStatus _VI_FUNC rsmxo_GetResultsEventStop(ViSession instrSession,
                                            ViInt32   measurement,
                                            ViInt32   eventIndex,
                                            ViReal64* stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_EVENT_STOP,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, eventIndex, 1, 1000000),
            3, "Event Index");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%ld", eventIndex);

    viCheckParm(RsCore_GetAttributeViReal64WithQparam(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_EVENT_STOP, param, stop),
                4, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the measured value of the indicated measured event. Relevant
/// HIFN  for measurements of all events, see
/// HIFN  RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR eventIndex/Index number of the measured event.
/// HIPAR value/Returns the measured value of the indicated measured event. Relevant
/// HIPAR value/for measurements of all events, see
/// HIPAR value/RSMXO_ATTR_MEASUREMENT_STATISTICS_ALL_EVENTS_ENABLED.
ViStatus _VI_FUNC rsmxo_GetResultsEventValue(ViSession instrSession,
                                             ViInt32   measurement,
                                             ViInt32   eventIndex,
                                             ViReal64* value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_RESULTS_EVENT_VALUE,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, eventIndex, 1, 1000000),
            3, "Event Index");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%ld", eventIndex);

    viCheckParm(RsCore_GetAttributeViReal64WithQparam(instrSession, repCap, RSMXO_ATTR_HIDDEN_RESULTS_EVENT_VALUE, param, value),
                4, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns measurement statistics of a previously acquired acquisition.
/// HIFN  The acquisition must be made previously to calling this.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR statisticsType/Selects the measurement statistics to return from the instrument.
/// HIPAR result/Returns the statistic results of the specified measurement.
ViStatus _VI_FUNC rsmxo_FetchMeasurementResultsStatistics(ViSession instrSession,
                                                          ViInt32   measurement,
                                                          ViInt32   statisticsType,
                                                          ViReal64* result)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViAttr   attr = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_CURRENT,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    switch (statisticsType)
    {
    case RSMXO_VAL_MEASUREMENT_STATISTICS_MAX:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_MAX;
        break;
    case RSMXO_VAL_MEASUREMENT_STATISTICS_MIN:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_MIN;
        break;
    case RSMXO_VAL_MEASUREMENT_STATISTICS_MEAN:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_MEAN;
        break;
    case RSMXO_VAL_MEASUREMENT_STATISTICS_RMS:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_RMS;
        break;
    case RSMXO_VAL_MEASUREMENT_STATISTICS_STANDARD_DEVIATION:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_STANDARD_DEVIATION;
        break;
    case RSMXO_VAL_MEASUREMENT_STATISTICS_EVENT_COUNT:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_EVENT_COUNT;
        break;
    case RSMXO_VAL_MEASUREMENT_STATISTICS_WAVE_COUNT:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_WAVE_COUNT;
        break;

    case RSMXO_VAL_MEASUREMENT_STATISTICS_CURRENT:
    default:
        attr = RSMXO_ATTR_MEASUREMENT_RESULTS_STATISTICS_CURRENT;
        break;
    }

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, attr, result),
            3, "Statistics Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTime) for the acquisition to complete, and returns the selected
/// HIFN  measurement statistic.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR maximumTime/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTime/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTime/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR statisticsType/Selects the measurement statistics to return from the instrument.
/// HIPAR result/Returns the statistic results of the specified measurement.
ViStatus _VI_FUNC rsmxo_ReadMeasurementResultsStatistics(ViSession instrSession,
                                                         ViInt32   measurement,
                                                         ViInt32   maximumTimeMs,
                                                         ViInt32   statisticsType,
                                                         ViReal64* result)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchMeasurementResultsStatistics(instrSession, measurement, statisticsType, result));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Return the statistic results of the specified measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR measurementType/Selects the measurement type.
/// HIPAR reliability/Returns the reliability of the specified measurement.
ViStatus _VI_FUNC rsmxo_FetchMeasurementReliability(ViSession instrSession,
                                                    ViInt32   measurement,
                                                    ViInt32   measurementType,
                                                    ViReal64* reliability)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";
    ViChar*  p2measTypeCmdStr;
    ViChar   instrumentResponse[RS_MAX_SHORT_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_MEASUREMENT_RESULTS_STATISTICS_RELIABILITY,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMeasurementType, measurementType, &p2measTypeCmdStr),
                3, "Measurement Type");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s", p2measTypeCmdStr);

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, repCap, RSMXO_ATTR_HIDDEN_MEASUREMENT_RESULTS_STATISTICS_RELIABILITY, param, RS_MAX_SHORT_MESSAGE_BUF_SIZE, instrumentResponse, NULL));

    *reliability = RsCore_Convert_String_To_ViReal64(instrumentResponse);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR enabled/Enables the gate.
ViStatus _VI_FUNC rsmxo_ConfigureGateEnabled(ViSession instrSession,
                                             ViInt32   gate,
                                             ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_ENABLED,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GATE_ENABLED, enabled),
            3, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the gate area is indicated in the source diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR display/If enabled, the gate area is indicated in the source diagram.
ViStatus _VI_FUNC rsmxo_ConfigureGateDisplay(ViSession instrSession,
                                             ViInt32   gate,
                                             ViBoolean display)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_DISPLAY,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GATE_DISPLAY, display),
            3, "Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  The gate coupling mode selects how the gate area is defined.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR couplingMode/The gate coupling mode selects how the gate area is defined.
ViStatus _VI_FUNC rsmxo_ConfigureGateCouplingMode(ViSession instrSession,
                                                  ViInt32   gate,
                                                  ViInt32   couplingMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_COUPLING_MODE,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GATE_COUPLING_MODE, couplingMode),
            3, "Coupling Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects if the gate settings are configured using absolute or relative
/// HIFN  values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR mode/Selects if the gate settings are configured using absolute or relative
/// HIPAR mode/values.
ViStatus _VI_FUNC rsmxo_ConfigureGateMode(ViSession instrSession,
                                          ViInt32   gate,
                                          ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_MODE,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GATE_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the absolute start and end values for the gate.
/// HIFN
/// HIFN     Available, if RSMXO_ATTR_GATE_COUPLING_MODE is set to Manual and
/// HIFN  RSMXO_ATTR_GATE_MODE to Absolute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR start/Define the absolute start and end values for the gate, respectively.
/// HIPAR stop/Define the absolute start and end values for the gate, respectively.
ViStatus _VI_FUNC rsmxo_ConfigureGateAbsoluteBounds(ViSession instrSession,
                                                    ViInt32   gate,
                                                    ViReal64  start,
                                                    ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_ABSOLUTE_START,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GATE_ABSOLUTE_START, start),
            3, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GATE_ABSOLUTE_STOP, stop),
            4, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the relative start and end values for the gate.
/// HIFN
/// HIFN     Available, if RSMXO_ATTR_GATE_COUPLING_MODE is set to Manual and
/// HIFN  RSMXO_ATTR_GATE_MODE to Relative.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR start/Define the relative start and end values for the gate, respectively.
/// HIPAR stop/Define the relative start and end values for the gate, respectively.
ViStatus _VI_FUNC rsmxo_ConfigureGateRelativeBounds(ViSession instrSession,
                                                    ViInt32   gate,
                                                    ViReal64  start,
                                                    ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_RELATIVE_START,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GATE_RELATIVE_START, start),
            3, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GATE_RELATIVE_STOP, stop),
            4, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Available for RSMXO_ATTR_GATE_COUPLING_MODE is set to Cursor.
/// HIFN
/// HIFN     Selects the cursor set to be used for measurement gating. The gate
/// HIFN  area is defined by the cursor lines.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR cursor/Available for RSMXO_ATTR_GATE_COUPLING_MODE is set to Cursor.
ViStatus _VI_FUNC rsmxo_ConfigureGateCursor(ViSession instrSession,
                                            ViInt32   gate,
                                            ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GATE_CURSOR,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GATE_CURSOR, cursor),
            3, "Cursor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Available for RSMXO_ATTR_GATE_COUPLING_MODE set to Zoom.
/// HIFN
/// HIFN     The gate area is defined identically to the zoom area for the selected
/// HIFN  zoom diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects repeated capability GateRC.
/// HIPAR gateName/Name of the gate on which the zoom is based.
/// HIPAR diagramGroup/Name of the diagram on which the zoom is based
/// HIPAR zoomDiagram/Name of the diagram on which the zoom is based
ViStatus _VI_FUNC rsmxo_ConfigureGateZoomDiagram(ViSession instrSession,
                                                 ViInt32   gate,
                                                 ViString  gateName,
                                                 ViString  diagramGroup,
                                                 ViString  zoomDiagram)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  gateCount = 0;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "GateRC", &gateCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gate, 1, gateCount),
            2, "Gate");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_HIDDEN_GATE_ZOOM_DIAGRAM,
            "GateRC", gate - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Gate");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\",\"%s\",\"%s\"", gateName, diagramGroup, zoomDiagram);

    checkErr(RsCore_SetAttributeViRawString(instrSession, repCap, RSMXO_ATTR_HIDDEN_GATE_ZOOM_DIAGRAM, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables the selected cursor measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR show/Enables the selected cursor measurement.
ViStatus _VI_FUNC rsmxo_ShowCursor(ViSession instrSession,
                                   ViInt32   cursor,
                                   ViBoolean show)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_SHOW,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_SHOW, show),
            3, "Show");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Switches all cursors off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_CursorDisableAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_CURSOR_DISABLE_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the maximum number of cursor sets, which is the maximum value
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR count/Returns the maximum number of cursor sets, which is the maximum value
/// HIPAR count/for the cursor suffix.
ViStatus _VI_FUNC rsmxo_QueryCursorCount(ViSession instrSession,
                                         ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_CURSOR_COUNT, count),
            2, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures cursor style and type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR style/Defines how the cursor is displayed in the diagram.
/// HIPAR type/Defines the cursor type to be used for the measurement.
ViStatus _VI_FUNC rsmxo_ConfigureCursorSettings(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViInt32   style,
                                                ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_STYLE,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_CURSOR_STYLE, style),
            3, "Style");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_CURSOR_TYPE, type),
            4, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures cursor source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR source/Selects the cursor source.
ViStatus _VI_FUNC rsmxo_ConfigureCursorSource(ViSession instrSession,
                                              ViInt32   cursor,
                                              ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_STYLE,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_CURSOR_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures a secondary cursor source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR enabled/Enables the second cursor source. To select the second source, use
/// HIPAR enabled/RSMXO_ATTR_CURSOR_SOURCE_2.
/// HIPAR source/Selects the second cursor source.
ViStatus _VI_FUNC rsmxo_ConfigureCursorSecondarySource(ViSession instrSession,
                                                       ViInt32   cursor,
                                                       ViBoolean enabled,
                                                       ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_SOURCE_2_ENABLED,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_SOURCE_2_ENABLED, enabled),
            3, "Enabled");

    if (enabled)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_CURSOR_SOURCE_2, source),
                3, "Value");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the vertical position of the cursor line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR x1Position/Defines the position of the left vertical cursor line.
/// HIPAR x2Position/Defines the position of the right vertical cursor line.
ViStatus _VI_FUNC rsmxo_ConfigureCursorXPositions(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViReal64  x1Position,
                                                  ViReal64  x2Position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_X1_POSITION,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_X1_POSITION, x1Position),
            3, "X1 Position");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_X2_POSITION, x2Position),
            4, "X2 Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the positions of the lower horizontal cursor line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR y2Position/Defines the position of the upper horizontal cursor line.
/// HIPAR y1Position/Defines the position of the lower horizontal cursor line.
ViStatus _VI_FUNC rsmxo_ConfigureCursorYPositions(ViSession instrSession,
                                                  ViInt32   cursor,
                                                  ViReal64  y1Position,
                                                  ViReal64  y2Position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_Y1_POSITION,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_Y1_POSITION, y1Position),
            3, "Y1 Position");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_Y2_POSITION, y2Position),
            4, "Y2 Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how the first horizontal cursor is positioned.
/// HIFN
/// HIFN     Prerequisites:
/// HIFN
/// HIFN     RSMXO_ATTR_ACQUISITION_MODE is set to Envelope.
/// HIFN  RSMXO_ATTR_CURSOR_TRACK_WAVEFORM is set to ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR envelope/Defines how the first horizontal cursor is positioned.
ViStatus _VI_FUNC rsmxo_ConfigureCursorEnvelope(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViInt32   envelope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_ENVELOPE,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_CURSOR_ENVELOPE, envelope),
            3, "Envelope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how the second horizontal cursor is positioned.
/// HIFN
/// HIFN     Prerequisites:
/// HIFN
/// HIFN     RSMXO_ATTR_ACQUISITION_MODE is set to Envelope.
/// HIFN  RSMXO_ATTR_CURSOR_TRACK_WAVEFORM is set to ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR envelope/Defines how the second horizontal cursor is positioned.
ViStatus _VI_FUNC rsmxo_ConfigureCursorEnvelope2(ViSession instrSession,
                                                 ViInt32   cursor,
                                                 ViInt32   envelope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_ENVELOPE_2,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_CURSOR_ENVELOPE_2, envelope),
            3, "Envelope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If enabled, the horizontal cursor lines tracks the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR trackWaveform/If enabled, the horizontal cursor lines tracks the waveform.
ViStatus _VI_FUNC rsmxo_ConfigureCursorTrackWaveform(ViSession instrSession,
                                                     ViInt32   cursor,
                                                     ViBoolean trackWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_TRACK_WAVEFORM,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_TRACK_WAVEFORM, trackWaveform),
            3, "Track Waveform");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures cursor coupling.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR x/Defines the positioning mode of the vertical cursor.
/// HIPAR y/Defines the positioning mode of the horizontal cursor. If the
/// HIPAR y/horizontal cursor lines track the waveform, the y-coupling is
/// HIPAR y/irrelevant (RSMXO_ATTR_CURSOR_TRACK_WAVEFORM is ON).
ViStatus _VI_FUNC rsmxo_ConfigureCursorCoupling(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViBoolean x,
                                                ViBoolean y)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_ADVANCED_X_COUPLING,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_ADVANCED_X_COUPLING, x),
            3, "X");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_ADVANCED_Y_COUPLING, y),
            4, "Y");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shows the enabled cursor measurements in all active diagrams of the
/// HIFN  same (time/spectrum) domain.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR showInAllDiagrams/Shows the enabled cursor measurements in all active diagrams of the
/// HIPAR showInAllDiagrams/same (time/spectrum) domain.
ViStatus _VI_FUNC rsmxo_ShowCursorInAllDiagrams(ViSession instrSession,
                                                ViInt32   cursor,
                                                ViBoolean showInAllDiagrams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_ADVANCED_SHOW_IN_ALL_DIAGRAMS,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_ADVANCED_SHOW_IN_ALL_DIAGRAMS, showInAllDiagrams),
            3, "Show In All Diagrams");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shows the cursor labels in the diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR showLabel/Shows the cursor labels in the diagram.
ViStatus _VI_FUNC rsmxo_ShowCursorLabel(ViSession instrSession,
                                        ViInt32   cursor,
                                        ViBoolean showLabel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_ADVANCED_SHOW_LABEL,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_CURSOR_ADVANCED_SHOW_LABEL, showLabel),
            3, "Show Label");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets both cursors to the absolute peak value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
ViStatus _VI_FUNC rsmxo_SetCursorPositionToAbsolutePeak(ViSession instrSession,
                                                        ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_ABSOLUTE_PEAK,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_ABSOLUTE_PEAK, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Cursor is set to the next smaller absolute peak from the current
/// HIFN  position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
ViStatus _VI_FUNC rsmxo_SetCursorPositionToNextPeak(ViSession instrSession,
                                                    ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Cursor is set to the next peak to the left of the current position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
ViStatus _VI_FUNC rsmxo_SetCursorPositionToNextPeakLeft(ViSession instrSession,
                                                        ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT_PEAK_LEFT,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT_PEAK_LEFT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Cursor is set to the next peak to the right of the current position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
ViStatus _VI_FUNC rsmxo_SetCursorPositionToNextPeakRight(ViSession instrSession,
                                                         ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT_PEAK_RIGHT,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_NEXT_PEAK_RIGHT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical cursor line Cu1 to the center frequency
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
ViStatus _VI_FUNC rsmxo_SetCursorPositionToCenterFrequency(ViSession instrSession,
                                                           ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_CENTER_FREQUENCY,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_CENTER_FREQUENCY, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the center frequency to the frequency value that is measured at
/// HIFN  cursor line Cu1.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
ViStatus _VI_FUNC rsmxo_SetCenterFrequencyToCursor(ViSession instrSession,
                                                   ViInt32   cursor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_SET_CENTER_TO_CURSOR,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_SET_CENTER_TO_CURSOR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets an absolute threshold as an additional condition for the peak
/// HIFN  search. Only peaks that exceed the threshold are detected.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR threshold/Sets an absolute threshold as an additional condition for the peak
/// HIPAR threshold/search. Only peaks that exceed the threshold are detected.
ViStatus _VI_FUNC rsmxo_ConfigureCursorPeakSearchThreshold(ViSession instrSession,
                                                           ViInt32   cursor,
                                                           ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_THRESHOLD,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_THRESHOLD, threshold),
            3, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the minimum level by which the waveform must rise or fall so that
/// HIFN  it will be identified as a maximum or a minimum by the search
/// HIFN  functions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR excursion/Sets the minimum level by which the waveform must rise or fall so that
/// HIPAR excursion/it will be identified as a maximum or a minimum by the search
/// HIPAR excursion/functions.
ViStatus _VI_FUNC rsmxo_ConfigureCursorPeakSearchExcursion(ViSession instrSession,
                                                           ViInt32   cursor,
                                                           ViReal64  excursion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_PEAK_SEARCH_EXCURSION,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_PEAK_SEARCH_EXCURSION, excursion),
            3, "Excursion");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries cursor X results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR dx/Queries the delta value (distance) of two vertical cursor lines.
/// HIPAR 1/dx/Queries the inverse value of the delta value (distance) of the two
/// HIPAR 1/dx/vertical cursor lines.
ViStatus _VI_FUNC rsmxo_QueryCursorResultsX(ViSession instrSession,
                                            ViInt32   cursor,
                                            ViReal64* dx,
                                            ViReal64* inversedx)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_RESULTS_DELTA_X,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_RESULTS_DELTA_X, dx),
            3, "dx");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_RESULTS_DELTA_X_INVERSE, inversedx),
            4, "1/dx");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the delta value (distance) of the two horizontal cursor lines.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR dy/Queries the delta value (distance) of the two horizontal cursor lines.
ViStatus _VI_FUNC rsmxo_QueryCursorResultsDeltaY(ViSession instrSession,
                                                 ViInt32   cursor,
                                                 ViReal64* dy)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_RESULTS_DELTA_Y,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_RESULTS_DELTA_Y, dy),
            3, "dy");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the inverse value of the voltage difference - the reciprocal
/// HIFN  of the vertical distance of two horizontal cursor lines: 1/V.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursor/Selects repeated capability Cursor.
/// HIPAR deltaYInverse/Returns the inverse value of the voltage difference - the reciprocal
/// HIPAR deltaYInverse/of the vertical distance of two horizontal cursor lines: 1/V.
ViStatus _VI_FUNC rsmxo_ConfigureCursorResultsDeltaYInverse(ViSession instrSession,
                                                            ViInt32   cursor,
                                                            ViReal64  deltaYInverse)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  cursorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Cursor", &cursorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, cursor, 1, cursorCount),
            2, "Cursor");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CURSOR_RESULTS_DELTA_Y_INVERSE,
            "Cursor", cursor - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Cursor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_CURSOR_RESULTS_DELTA_Y_INVERSE, deltaYInverse),
            3, "Delta Y Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the spectrum.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displaySpectrum/Enables the spectrum.
ViStatus _VI_FUNC rsmxo_DisplaySpectrum(ViSession instrSession,
                                        ViBoolean displaySpectrum)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_DISPLAY, displaySpectrum),
            2, "Display Spectrum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the source for the spectrogram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the source for the spectrogram.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumSource(ViSession instrSession,
                                                ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SOURCE, source),
            2, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the spectrum frequency span.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR center/Defines the position of the displayed frequency range, which is
/// HIPAR center/(Center - Span/2) to (Center + Span/2). The width of the range is
/// HIPAR center/defined using the frequency span setting.
/// HIPAR span/The span is specified in Hertz and defines the width of the displayed
/// HIPAR span/frequency range, which is (Center - Span/2) to (Center + Span/2). The
/// HIPAR span/position of the span is defined using the Center setting.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumCFSpan(ViSession instrSession,
                                                ViReal64  center,
                                                ViReal64  span)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_CENTER, center),
            2, "Center");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SPAN, span),
            3, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the start and end frequency of the displayed frequency span.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR spectrumStart/Defines the start frequency of the displayed frequency span.
/// HIPAR spectrumStop/Sets the stop frequency of the displayed frequency span.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumStartStop(ViSession instrSession,
                                                   ViReal64  spectrumStart,
                                                   ViReal64  spectrumStop)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_START, spectrumStart),
            2, "Spectrum Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_STOP, spectrumStop),
            3, "Spectrum Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the RBW setting.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoRWB/Couples the frequency span to the RBW setting.
/// HIPAR rbw/Queries or defines the used resolution bandwidth.
/// HIPAR span/rbw/Defines the coupling ratio for Span/RBW.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumRBWSettings(ViSession instrSession,
                                                     ViBoolean autoRBW,
                                                     ViReal64  rbw,
                                                     ViInt32   spanrbw)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_AUTO_RBW, autoRBW),
            2, "Auto RBW");

    if (autoRBW)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SPAN_RBW_RATIO, spanrbw),
                4, "Span/RBW");
    }
    else
    {
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_RBW, rbw),
                3, "RBW");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables spectrum traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR normal/Enables normal trace. The data of only one segment is considered. In
/// HIPAR normal/effect, no arithmetics are processed.
/// HIPAR minHold/Enables the minimum trace. Determines the minimum result for each
/// HIPAR minHold/input value from the data of the current acquisition and the
/// HIPAR minHold/acquisitions before.
/// HIPAR maxHold/Enables the maximum trace. Determines the maximum result for each
/// HIPAR maxHold/input value from the data of the current acquisition and the
/// HIPAR maxHold/acquisitions before.
/// HIPAR average/Enables the average trace. The average is calculated over the number
/// HIPAR average/ot segments set with Average count.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumTraces(ViSession instrSession,
                                                ViBoolean normal,
                                                ViBoolean minHold,
                                                ViBoolean maxHold,
                                                ViBoolean average)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_TRACES_NORMAL_ENABLED, normal),
            2, "Normal");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_TRACES_MIN_HOLD_ENABLED, minHold),
            3, "Min Hold");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_TRACES_MAX_HOLD_ENABLED, maxHold),
            4, "Max Hold");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_TRACES_AVERAGE_ENABLED, average),
            5, "Average");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of segments used for the averaging of the spectrum.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR averageCount/Sets the number of segments used for the averaging of the spectrum.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumTracesAverageCount(ViSession instrSession,
                                                            ViInt32   averageCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_TRACES_AVERAGE_COUNT, averageCount),
            2, "Average Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the window type. Windowing helps minimize the discontinuities
/// HIFN  at the end of the measured signal interval and thus reduces the effect
/// HIFN  of spectral leakage, increasing the frequency resolution.
/// HIFN
/// HIFN     Various different window functions are provided in the R&SMXO4 to suit
/// HIFN  different input signals. Each of the window functions has specific
/// HIFN  characteristics, including some advantages and some trade-offs. These
/// HIFN  characteristics need to be considered carefully to find the optimum
/// HIFN  solution for the measurement task.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the window type. Windowing helps minimize the discontinuities
/// HIPAR type/at the end of the measured signal interval and thus reduces the effect
/// HIPAR type/of spectral leakage, increasing the frequency resolution.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumWindowType(ViSession instrSession,
                                                    ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_WINDOW_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Presets the spectrum measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_SpectrumPreset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PRESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the unit for the y-axis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR magnitudeUnit/Sets the unit for the y-axis.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleMagnitudeUnit(ViSession instrSession,
                                                            ViInt32   magnitudeUnit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SCALE_MAGNITUDE_UNIT, magnitudeUnit),
            2, "Magnitude Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the maximum displayed value on the vertical scale.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalMaximum/Sets the maximum displayed value on the vertical scale.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleVerticalMaximum(
                            ViSession instrSession,
                            ViReal64  verticalMaximum)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SCALE_VERTICAL_MAXIMUM, verticalMaximum),
            2, "Vertical Maximum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the range of the spectrum values to be displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalRange/Sets the range of the spectrum values to be displayed.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleVerticalRange(ViSession instrSession,
                                                            ViReal64  verticalRange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SCALE_VERTICAL_RANGE, verticalRange),
            2, "Vertical Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the scale for the y-axis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalScale/Sets the scale for the y-axis.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumScaleVerticalScale(ViSession instrSession,
                                                            ViReal64  verticalScale)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_SCALE_VERTICAL_SCALE, verticalScale),
            2, "Vertical Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the starting value for the gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR start/Sets the starting value for the gate.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGateStart(ViSession instrSession,
                                                   ViReal64  start)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_GATE_START, start),
            2, "Start");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the end value for the gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR stop/Sets the end value for the gate.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGateStop(ViSession instrSession,
                                                  ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_GATE_STOP, stop),
            2, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the position of the displayed frequency range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR position/Sets the position of the displayed frequency range.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGatePosition(ViSession instrSession,
                                                      ViReal64  position)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_GATE_POSITION, position),
            2, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the width of the displayed gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR width/Defines the width of the displayed gate.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumGateWidth(ViSession instrSession,
                                                   ViReal64  width)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_GATE_WIDTH, width),
            2, "Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures settings for peak list table.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR peakTable/Enables the display of the peak table.
/// HIPAR threshold/Defines an absolute threshold as an additional condition for the peak
/// HIPAR threshold/search. Only peaks that exceed the threshold are detected.
/// HIPAR excursion/Defines a relative threshold, the minimum level value by which the
/// HIPAR excursion/waveform must rise by to be considered as a peak. To avoid identifying
/// HIPAR excursion/noise peaks, enter a peak excursion value that is higher than the noise
/// HIPAR excursion/levels.
/// HIPAR maxResults/Sets the maximum number of measurement results that are listed in the
/// HIPAR maxResults/result table.
/// HIPAR resultMode/Selects the way the measurement results are displayed.
/// HIPAR showFrequency/Includes the frequency of the detected peak in the diagram labels.
/// HIPAR source/Selects the source of the peak table. You can select one of the
/// HIPAR source/traces, that is enabled with 'Traces'.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListTableSettings(
                            ViSession instrSession,
                            ViBoolean peakTable,
                            ViReal64  threshold,
                            ViReal64  excursion,
                            ViInt32   maxResults,
                            ViInt32   resultMode,
                            ViBoolean showFrequency,
                            ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_SHOW_TABLE, peakTable),
            2, "Peak Table");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_PEAK_EXCURSION, excursion),
            4, "Excursion");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_MAX_RESULTS, maxResults),
            5, "Max Results");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_RESULT_MODE, resultMode),
            6, "Result Mode");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_SHOW_FREQUENCY, showFrequency),
            7, "Show Frequency");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_SOURCE, source),
            8, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the layout of the labels (full border, underline, or none).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frameType/Defines the layout of the labels (full border, underline, or none).
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListFrameType(ViSession instrSession,
                                                           ViInt32   frameType)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_FRAME_TYPE, frameType),
            2, "Frame Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the maximum number of measurement results that are listed in the
/// HIFN  result table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR maxResults/Sets the maximum number of measurement results that are listed in the
/// HIPAR maxResults/result table.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListLabelMaxResults(
                            ViSession instrSession,
                            ViInt32   maxResults)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_LABEL_MAX_RESULTS, maxResults),
            2, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the current peak list measurement results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR current/Returns the current peak list measurement results.
ViStatus _VI_FUNC rsmxo_QuerySpectrumPeakListCurrent(ViSession instrSession,
                                                     ViReal64* current)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_CURRENT, current),
            2, "Current");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the current number of peak list results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR count/Returns the current number of peak list results.
ViStatus _VI_FUNC rsmxo_QuerySpectrumPeakListCount(ViSession instrSession,
                                                   ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_COUNT, count),
            2, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Displays the labels in the peak list diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Displays the labels in the peak list diagram.
/// HIPAR invertColors/Inverts the colors of the peak list labels, the peak boxes are shown
/// HIPAR invertColors/with a white background.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListLabels(ViSession instrSession,
                                                        ViBoolean enabled,
                                                        ViBoolean invertColors)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_LABELS_ENABLED, enabled),
            2, "Enabled");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_LABELS_INVERT_COLORS, invertColors),
            3, "Invert Colors");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures peak list sort.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sort/Sorts the results in the spectrum peak list table either according to
/// HIPAR sort/the frequency or according to the value.
/// HIPAR order/Defines if the spectrum peak list results are sorted in an ascending
/// HIPAR order/(increasing) or descending (decreasing) order.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListSort(ViSession instrSession,
                                                      ViInt32   sort,
                                                      ViInt32   order)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_SORT, sort),
            2, "Sort");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_SORT_ORDER, order),
            3, "Order");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Displays the peaks for the spectrum.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR peaks/Displays the peaks for the spectrum.
ViStatus _VI_FUNC rsmxo_ConfigureSpectrumPeakListDisplayPeaks(
                            ViSession instrSession,
                            ViBoolean peaks)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SPECTRUM_PEAK_LIST_DISPLAY_PEAKS, peaks),
            2, "Peaks");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the mathematics and displays the defined math waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR display/Activates the mathematics and displays the defined math waveforms.
ViStatus _VI_FUNC rsmxo_DisplayMath(ViSession instrSession,
                                    ViInt32   math,
                                    ViBoolean display)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_DISPLAY,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_MATH_DISPLAY, display),
            3, "Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the math expression to be calculated for the specified math
/// HIFN  channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR source1/Selects the first signal source.
/// HIPAR source2/Selects the second signal source. It is only required for certain
/// HIPAR source2/operations, such as addition, multiplication etc.
/// HIPAR operator/Selects the math operation to perform on the selected signals.
/// HIPAR a/Slope coefficient (a) for rescaling operations.
/// HIPAR b/Y-intercept (b) coefficient for rescaling operations.
/// HIPAR noiseReject/Noise reject value for the derivation of x.
ViStatus _VI_FUNC rsmxo_DefineMathExpression(ViSession instrSession,
                                             ViInt32   math,
                                             ViInt32   source1,
                                             ViInt32   source2,
                                             ViInt32   operatorType,
                                             ViReal64  a,
                                             ViReal64  b,
                                             ViInt32   noiseReject)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;
    ViChar   mathExpression[RS_MAX_MESSAGE_LEN] = "";
    ViChar*  p2operatorCmdStr;
    ViChar*  p2sourceCmdStr;
    ViChar*  p2source2CmdStr;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_DISPLAY,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMathOperator, operatorType, &p2operatorCmdStr),
                3, "Operator Type");

    if (source1 == RSMXO_VAL_MATH_SOURCE_NONE)
    {
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, source1), 4, "Source 1");
    }

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMathSource, source1, &p2sourceCmdStr),
                4, "Source 1");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMathSource, source2, &p2source2CmdStr),
                5, "Source 2");

    switch (operatorType)
    {
    //These operations require the second source to contain a signal
    case RSMXO_VAL_MATH_OPERATOR_ADDITION:
    case RSMXO_VAL_MATH_OPERATOR_SUBTRACTION:
    case RSMXO_VAL_MATH_OPERATOR_MULTIPLICATION:
    case RSMXO_VAL_MATH_OPERATOR_DIVISION:
        if (source2 == RSMXO_VAL_MATH_SOURCE_NONE)
        {
            viCheckParm(RsCore_InvalidViInt32Value(instrSession, source2), 5, "Source 2");
        }
        (void)snprintf(mathExpression, RS_MAX_MESSAGE_LEN, "%s%s%s", p2sourceCmdStr, p2operatorCmdStr, p2source2CmdStr);
        break;

    case RSMXO_VAL_MATH_OPERATOR_DIFFERENTIAL:
        (void)snprintf(mathExpression, RS_MAX_MESSAGE_LEN, "%s(%s,%ld)", p2operatorCmdStr, p2sourceCmdStr, noiseReject);
        break;

    case RSMXO_VAL_MATH_OPERATOR_ABSOLUTE_VALUE:
    case RSMXO_VAL_MATH_OPERATOR_INTEGRAL:
    case RSMXO_VAL_MATH_OPERATOR_LOG10:
    case RSMXO_VAL_MATH_OPERATOR_LOG_NATURAL:
    case RSMXO_VAL_MATH_OPERATOR_BINARY_LOG:
    case RSMXO_VAL_MATH_OPERATOR_SQUARE:
    case RSMXO_VAL_MATH_OPERATOR_ROOT:
        (void)snprintf(mathExpression, RS_MAX_MESSAGE_LEN, "%s(%s)", p2operatorCmdStr, p2sourceCmdStr);
        break;

    case RSMXO_VAL_MATH_OPERATOR_RESCALE:
        (void)snprintf(mathExpression, RS_MAX_MESSAGE_LEN, "%s(%s,%lf,%lf)", p2operatorCmdStr, p2sourceCmdStr, a, b);
        break;

    case RSMXO_VAL_MATH_OPERATOR_NEGATE:
        (void)snprintf(mathExpression, RS_MAX_MESSAGE_LEN, "-%s", p2sourceCmdStr);
        break;

    case RSMXO_VAL_MATH_OPERATOR_INVERSE:
        (void)snprintf(mathExpression, RS_MAX_MESSAGE_LEN, "1/%s", p2sourceCmdStr);
        break;

    default:
        checkErr(RS_ERROR_INVALID_VALUE);
    }

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_MATH_EXPRESSION, mathExpression),
            3, "Math Expression");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the math expression to be calculated for the specified math
/// HIFN  channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR mathExpression/Defines the math expression to be calculated for the specified math
/// HIPAR mathExpression/channel.
ViStatus _VI_FUNC rsmxo_InputMathExpressionString(ViSession instrSession,
                                                  ViInt32   math,
                                                  ViString  mathExpression)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_DISPLAY,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_MATH_EXPRESSION, mathExpression),
            3, "Math Expression");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets how the vertical scale is adapted to the current measurement
/// HIFN  results. By default, scaling is done automatically to provide an
/// HIFN  optimal display. However, if necessary, you can define scaling values
/// HIFN  manually to suit your requirements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR mode/Sets how the vertical scale is adapted to the current measurement
/// HIPAR mode/results. By default, scaling is done automatically to provide an
/// HIPAR mode/optimal display. However, if necessary, you can define scaling values
/// HIPAR mode/manually to suit your requirements.
ViStatus _VI_FUNC rsmxo_ConfigureMathVerticalScaleMode(ViSession instrSession,
                                                       ViInt32   math,
                                                       ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_VERTICAL_SCALE_MODE,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MATH_VERTICAL_SCALE_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets  the scale and offset of the y-axis in the math function diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR scale/Sets  the scale of the y-axis in the math function diagram. The value
/// HIPAR scale/is defined as '<unit> per division', e.g. 50m V/div. In this case, the
/// HIPAR scale/horizontal grid lines are displayed in intervals of 50mV.
/// HIPAR offset/Sets a voltage offset to adjust the vertical position of the math
/// HIPAR offset/function on the screen. Negative values move the waveform, positive
/// HIPAR offset/values move it down.
ViStatus _VI_FUNC rsmxo_ConfigureMathVerticalAxis(ViSession instrSession,
                                                  ViInt32   math,
                                                  ViReal64  scale,
                                                  ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_DISPLAY,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_MATH_VERTICAL_SCALE, scale),
            3, "Scale");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_MATH_VERTICAL_OFFSET, offset),
            4, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the signal type of the source of the math waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR mathSignalType/Returns the signal type of the source of the math waveform.
ViStatus _VI_FUNC rsmxo_QueryMathSignalType(ViSession instrSession,
                                            ViInt32   math,
                                            ViInt32*  mathSignalType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_SIGNAL_TYPE,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MATH_SIGNAL_TYPE, mathSignalType),
            3, "Math Signal Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the upper or lower part of the input waveform for mathematic
/// HIFN  calculation, or a combination of both.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR waveformSelection/Selects the upper or lower part of the input waveform for mathematic
/// HIPAR waveformSelection/calculation, or a combination of both.
ViStatus _VI_FUNC rsmxo_ConfigureMathEnvelopeWaveformSelection(
                            ViSession instrSession,
                            ViInt32   math,
                            ViInt32   waveformSelection)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_ENVELOPE_WAVEFORM_SELECTION,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_MATH_ENVELOPE_WAVEFORM_SELECTION, waveformSelection),
            3, "Waveform Selection");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables or disables the selected bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR enabled/Enables or disables the selected bus.
ViStatus _VI_FUNC rsmxo_EnableSerialBus(ViSession instrSession,
                                        ViInt32   serialBus,
                                        ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SERIAL_BUS_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SERIAL_BUS_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the bus type for analysis. The type of available buses depends
/// HIFN  on the installed options.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR type/Defines the bus type for analysis. The type of available buses depends
/// HIPAR type/on the installed options.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolType(ViSession instrSession,
                                              ViInt32   serialBus,
                                              ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_TYPE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures protocol display settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR showDecodeTable/Opens a table with decoded data of the serial signal. This requires
/// HIPAR showDecodeTable/the option for the analyzed protocol.
/// HIPAR dataFormat/Sets the data format for the values displayed in the decode table and
/// HIPAR dataFormat/in the combs of the decoded signal.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolDisplaySettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViBoolean showDecodeTable,
                                                         ViInt32   dataFormat)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SHOW_DECODE_TABLE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SHOW_DECODE_TABLE, showDecodeTable),
            3, "Show Decode Table");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_DATA_FORMAT, dataFormat),
            4, "Data Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the decode zoom and result table are synchronized. If you
/// HIFN  select a row in the result table, this result is shown in the decode
/// HIFN  zoom.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR zoomCoupling/If enabled, the decode zoom and result table are synchronized. If you
/// HIPAR zoomCoupling/select a row in the result table, this result is shown in the decode
/// HIPAR zoomCoupling/zoom.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolZoomCoupling(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViBoolean zoomCoupling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_ZOOM_COUPLING,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_ZOOM_COUPLING, zoomCoupling),
            3, "Zoom Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the threshold lines are displayed in the diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR showThresholdLines/If enabled, the threshold lines are displayed in the diagram.
ViStatus _VI_FUNC rsmxo_ShowProtocolThresholdLines(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViBoolean showThresholdLines)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SHOW_THRESHOLD_LINES,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SHOW_THRESHOLD_LINES, showThresholdLines),
            3, "Show Threshold Lines");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Executes the measurement of reference levels and sets the thresholds
/// HIFN  to the middle reference level of the measured amplitude.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
ViStatus _VI_FUNC rsmxo_SetProtocolReferenceLevels(ViSession instrSession,
                                                   ViInt32   serialBus)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SET_REFERENCE_LEVELS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SET_REFERENCE_LEVELS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the SDA source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the source channel to which the data line is connected.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSDASource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_SDA_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SDA_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the SDA settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets the threshold value.
/// HIPAR hysteresis/Sets the hysteresis for SDA.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSDASettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_SDA_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SDA_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SDA_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the SCL source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the source channel to which the data line is connected.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSCLSource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_SCL_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SCL_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the SCL settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets the threshold for SCL.
/// HIPAR hysteresis/Sets the hysteresis for SCL.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSCLSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_SCL_THRESHOLD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SCL_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SCL_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the symbol list to be used for decoding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR showSymbols/Activates the symbol list to be used for decoding.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CShowSymbols(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean showSymbols)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_SHOW_SYMBOLS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SHOW_SYMBOLS, showSymbols),
            3, "Show Symbols");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads a symbol list file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR file/Loads a symbol list file.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CSymbolListFile(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViString  file)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_SYMBOL_LIST_FILE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_SYMBOL_LIST_FILE, file),
            3, "File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frameCount/Returns the number of decoded frames.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CFrameCount(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  frameCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FRAME_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FRAME_COUNT, frameCount),
            3, "Frame Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on I2C frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR filter/Enables the filtering on I2C frames. Only the frames that match the
/// HIPAR filter/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean filter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_ENABLED, filter),
            3, "Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the frame type that you want to filter on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR frameEnabled/Enables the frame type that you want to filter on.
ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean frameEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_FRAME_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_FRAME_ENABLED, frameEnabled),
            4, "Frame Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR field/Selects the Field.
/// HIPAR fieldEnabled/Enables or disables the checking condition for the selected field of
/// HIPAR fieldEnabled/the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilterField(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViBoolean fieldEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_FIELD_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_FIELD_ENABLED, fieldEnabled),
            5, "Field Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the error type to be filtered on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR error/Selects the Error.
/// HIPAR error/Defines the error type to be filtered on.
ViStatus _VI_FUNC rsmxo_EnableProtocolI2CFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean errorEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_ERROR_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_ERROR, errorNumber),
            3, "Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_ERROR_ENABLED, errorEnabled),
            4, "Error Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the bit state of a field that only consists of one bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR field/Selects the Field.
/// HIPAR condition/Sets the bit state of a field that only consists of one bit.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CFilterCondition(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   condition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_CONDITION,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_CONDITION, condition),
            5, "Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures index operator and index values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR field/Selects the Field.
/// HIPAR index/Sets the operator for the index in the selected field of the selected
/// HIPAR index/frame.
/// HIPAR startValue/Specifies the index, or sets the start value of an index range.
/// HIPAR endValue/Sets the end value of an index range if the operator is set to
/// HIPAR endValue/INRange.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CFilterIndex(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   index,
                                                        ViInt32   startValue,
                                                        ViInt32   endValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_INDEX,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_INDEX, index),
            5, "Index");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_START_INDEX, startValue),
            6, "Start Value");

    if (index == RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_RANG)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_END_INDEX, endValue),
                7, "End Value");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets data operature and values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR field/Selects the Field.
/// HIPAR data/Sets the operator for the data pattern in the selected field of the
/// HIPAR data/selected frame.
/// HIPAR startValue/Specifies the data pattern, or sets the start value of an data pattern
/// HIPAR startValue/range.
/// HIPAR endValue/Sets the end value of a data pattern  range if the operator is set to
/// HIPAR endValue/In range  or Out Of Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CFilterData(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   field,
                                                       ViInt32   data,
                                                       ViString  startValue,
                                                       ViString  endValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_FILTER_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_DATA, data),
            5, "Data");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_START_DATA, startValue),
            6, "Start Value");

    if (data >= RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_IN_RANGE)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_FILTER_END_DATA, endValue),
                7, "End Value");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger type for I2C analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger type for I2C analysis.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerType(ViSession instrSession,
                                                        ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures no ack trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR addressNack/Triggers if the address acknowledge bit is missing - no slave
/// HIPAR addressNack/recognizes the address.
/// HIPAR dataWriteNack/Triggers if a date acknowledge bit is missing - the addressed slave
/// HIPAR dataWriteNack/does not accept the data.
/// HIPAR dataReadNack/Triggers on the end of the read process when the master reads data
/// HIPAR dataReadNack/from the slave. This Nack is sent according to the protocol definition,
/// HIPAR dataReadNack/it is not an error.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerNoAckSettings(
                            ViSession instrSession,
                            ViBoolean addressNack,
                            ViBoolean dataWriteNack,
                            ViBoolean dataReadNack)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_NACK, addressNack),
            2, "Address Nack");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_WRITE_NACK, dataWriteNack),
            3, "Data Write Nack");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_READ_NACK, dataReadNack),
            4, "Data Read Nack");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the address length adn Read Write bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR addressType/Sets the address length to be triggered on: 7 bit or 10 bit.
/// HIPAR r/wBit/Toggles the trigger condition between read and write access of the
/// HIPAR r/wBit/primary. Select Either if the transfer direction is not relevant  for
/// HIPAR r/wBit/the trigger condition.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerAddressSettings(
                            ViSession instrSession,
                            ViInt32   addressType,
                            ViInt32   rwBit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE, addressType),
            2, "Address Type");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_R_W_BIT, rwBit),
            3, "R/W Bit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator to set a specific address or an address range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR address/Sets the operator to set a specific address or an address range.
/// HIPAR addressMinimum/Triggers on the specified address, or sets the start value of an
/// HIPAR addressMinimum/address range depending on the condition set with
/// HIPAR addressMinimum/RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS
/// HIPAR addressMaximum/Sets the end value of an address range if the condition is set to an
/// HIPAR addressMaximum/address range with RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerAddress(ViSession instrSession,
                                                           ViInt32   address,
                                                           ViString  addressMinimum,
                                                           ViString  addressMaximum)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS, address),
            2, "Address");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_MIN, addressMinimum),
            3, "Address Minimum");

    if (address >= RSMXO_VAL_CONDITION_OPERATOR_IN_RANGE)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_MAX, addressMaximum),
                4, "Address Maximum");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator value for data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR data/Sets the operator to set a specific data value or a data range.
/// HIPAR dataMinumum/Specifies the data bit pattern, or sets the start value of a data
/// HIPAR dataMinumum/pattern range. Enter the bytes in msb first bit order. The maximum
/// HIPAR dataMinumum/pattern length is 64 bit. Waveform data is compared with the pattern
/// HIPAR dataMinumum/byte-by-byte.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerData(ViSession instrSession,
                                                        ViInt32   data,
                                                        ViString  minimum)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA, data),
            2, "Data");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_MIN, minimum),
            3, "Minimum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the data position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataPosition/Sets the number of data bytes to be skipped after the address.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolI2CTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_TRIGGER_DATA_POSITION, dataPosition),
            2, "Data Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the frame decode table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR state/Returns the overall state of the frame.
/// HIPAR frameStart/Returns the start time of the specified frame.
/// HIPAR frameEnd/Returns the end time of the specified frame.
/// HIPAR addressType/Returns the address length.
/// HIPAR address/Returns the device address value of the indicated frame. That is, the
/// HIPAR address/address value that is shown in the decoded cells and in the decode
/// HIPAR address/results table.
/// HIPAR rwBit/Returns the value of the R/W bit of the indicated frame.
/// HIPAR dataRate/Returns the primary bit rate.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsDecodeTable(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32*  state,
                                                           ViReal64* frameStart,
                                                           ViReal64* frameEnd,
                                                           ViInt32*  addressType,
                                                           ViInt32*  address,
                                                           ViInt32*  rwBit,
                                                           ViReal64* dataRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_FRAME_START, frameStart),
            5, "Frame Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_FRAME_END, frameEnd),
            6, "Frame End");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_TYPE, addressType),
            7, "Address Type");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS, address),
            8, "Address");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT, rwBit),
            9, "RW Bit");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BIT_RATE, dataRate),
            10, "Data Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the symbolic label of the specified frame if the label list is
/// HIFN  enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR symbolLabel/Returns the symbolic label of the specified frame if the label list is
/// HIPAR symbolLabel/enabled.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsSymbol(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   bufferSize,
                                                      ViChar    symbolLabel[],
                                                      ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_SYMBOL,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_SYMBOL, bufferSize, symbolLabel, bytesRead),
                4, "Symbol Label");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the address results for the indicated frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR complete/Returns if the address is completely contained in the acquisition.
/// HIPAR type/Returns the address length.
/// HIPAR address/Returns the device address value of the indicated frame. That is, the
/// HIPAR address/address value that is shown in the decoded cells and in the decode
/// HIPAR address/results table.
/// HIPAR start/Returns the start time of the address for the indicated frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsAddress(ViSession  instrSession,
                                                       ViInt32    serialBus,
                                                       ViInt32    frame,
                                                       ViBoolean* complete,
                                                       ViInt32*   type,
                                                       ViInt32*   address,
                                                       ViReal64*  start)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_COMPLETE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_COMPLETE, complete),
            4, "Complete");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_TYPE, type),
            5, "Type");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS, address),
            6, "Address");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_START, start),
            7, "Start");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the start time and value of the address acknowledge bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR ackBitStart/Returns the start time of the address acknowledge bit.
/// HIPAR ackBit/Returns the address acknowledge bit value for the indicated frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsAddressAckBit(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViReal64* ackBitStart,
                                                             ViInt32*  ackBit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_ACK_BIT_START,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_ACK_BIT_START, ackBitStart),
            4, "ACK Bit Start");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_ADDRESS_ACK_BIT, ackBit),
            5, "ACk Bit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the pure device address of the indicated frame without the R/W
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR deviceAddress/Returns the pure device address of the indicated frame without the R/W
/// HIPAR deviceAddress/bit.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsDeviceAddress(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32*  deviceAddress)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_DEVICE_ADDRESS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_DEVICE_ADDRESS, deviceAddress),
            4, "Device Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the start time and value of the R/W bit
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR rwBitStart/Returns the start time of the R/W bit
/// HIPAR rwBit/Returns the value of the R/W bit of the indicated frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsRWBit(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViReal64* rwBitStart,
                                                     ViInt32*  rwBit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT_START,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT_START, rwBitStart),
            4, "RW Bit Start");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT, rwBit),
            5, "RW Bit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data words of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR data/Returns the data words of the specified frame.
/// HIPAR bytesRead/Returns the number of data points read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsData(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViReal64  data[],
                                                    ViInt32*  pointsRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_RW_BIT_START,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_DATA, NULL, bufferSize, data, pointsRead),
                4, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of bytes in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR count/Returns the number of bytes in the specified frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsByteCount(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_COUNT, count),
            4, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns results for of the specified data byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Selects the Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR complete/Returns if the indicated byte is completely contained in the
/// HIPAR complete/acquisition.
/// HIPAR start/Returns the start time of the specified data byte.
/// HIPAR ackBitStart/Returns the start time of the acknowledge bit of the specified byte.
/// HIPAR ackBit/Returns the acknowledge bit value of the specified data byte.
/// HIPAR value/Returns the data value of the specified byte.
ViStatus _VI_FUNC rsmxo_QueryProtocolI2CResultsByte(ViSession  instrSession,
                                                    ViInt32    serialBus,
                                                    ViInt32    frame,
                                                    ViInt32    byteNumber,
                                                    ViBoolean* complete,
                                                    ViReal64*  start,
                                                    ViReal64*  ackBitStart,
                                                    ViInt32*   ackBit,
                                                    ViInt32*   value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_COMPLETE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_I2C_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    viCheckParm(rsmxo_GetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_COMPLETE, complete),
            5, "Complete");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_START, start),
            6, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_ACK_BIT_START, ackBitStart),
            7, "ACK Bit Start");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_ACK_BIT, ackBit),
            8, "ACK Bit");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_I2C_RESULTS_BYTE_DATA, value),
            9, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frameCount/Returns the number of decoded frames.
ViStatus _VI_FUNC rsmxo_QueryProtocolSPIFrameCount(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32*  frameCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FRAME_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FRAME_COUNT, frameCount),
            3, "Frame Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the MOSI lines source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the input channel of the MOSI line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMOSISource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_MOSI_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MOSI_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the MOSI lines settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Set user-defined threshold values for the respective line.
/// HIPAR hysteresis/Sets a value for the hysteresis for the MOSI channel.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMOSISettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_MOSI_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MOSI_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MOSI_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures settings for the MISO line source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the input channel of the MISO line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMISOSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_MISO_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MISO_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures settings for the MISO line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Set user-defined threshold values for the respective line.
/// HIPAR hysteresis/Sets a value for the hysteresis for the MISO channel.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIMISOSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_MISO_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MISO_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MISO_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the SCLK line source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the input channel of the SCLK line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPISCLKSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_SCLK_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_SCLK_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the SCLK line settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Set user-defined threshold values for the respective line.
/// HIPAR hysteresis/Sets a value for the hysteresis for the SCLK channel.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPISCLKSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_SCLK_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_SCLK_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_SCLK_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the CS line source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the input channel of the CS line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPICSSource(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_CS_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_CS_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the CS line settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Set user-defined threshold values for the respective line.
/// HIPAR hysteresis/Sets a value for the hysteresis for the CS channel.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPICSSettings(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViReal64  threshold,
                                                       ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_CS_THRESHOLD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_CS_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_CS_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the polarity values for MOSI, MISO and CS lines.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR mosiPolarity/Selects if the transmitted signal for the respective line is active
/// HIPAR mosiPolarity/high (high = 1) or active low (low = 1).
/// HIPAR csPolarity/Selects if the transmitted signal for the respective line is active
/// HIPAR csPolarity/high (high = 1) or active low (low = 1).
/// HIPAR misoPolarity/Selects if the transmitted signal for the respective line is active
/// HIPAR misoPolarity/high (high = 1) or active low (low = 1).
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIPolarityValues(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   mosiPolarity,
                                                           ViInt32   csPolarity,
                                                           ViInt32   misoPolarity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_MOSI_POLARITY,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MOSI_POLARITY, mosiPolarity),
            3, "MOSI Polarity");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_MISO_POLARITY, misoPolarity),
            4, "MISO Polarity");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_CS_POLARITY, csPolarity),
            5, "CS Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the bit order, which determines if the data of the messages
/// HIFN  starts with MSB (most significant bit) or LSB (least significant bit).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR bitOrder/Selects the bit order, which determines if the data of the messages
/// HIPAR bitOrder/starts with MSB (most significant bit) or LSB (least significant bit).
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIBitOrder(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   bitOrder)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_BIT_ORDER,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_BIT_ORDER, bitOrder),
            3, "Bit Order");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the word length (or symbol size), which is the number of bits in
/// HIFN  a message. The maximum word length is 32 bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR wordLength/Sets the word length (or symbol size), which is the number of bits in
/// HIPAR wordLength/a message. The maximum word length is 32 bit.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIWordLength(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   wordLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_WORD_LENGTH,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_WORD_LENGTH, wordLength),
            3, "Word Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines advanced SPI settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frameCondition/Defines the start of a frame. A frame contains a number of successive
/// HIPAR frameCondition/words, at least one word.
/// HIPAR timeout/Sets the minimum clock idle time if a timeout on the clock line SCLK
/// HIPAR timeout/is used as limiter between two frames.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIAdvancedSettings(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frameCondition,
                                                             ViReal64  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FRAME_CONDITION,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FRAME_CONDITION, frameCondition),
            3, "Frame Condition");

    if (frameCondition == RSMXO_VAL_PROTOCOL_SPI_FRAME_CONDITION_CLK_TIMEOUT)
    {
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_TIMEOUT, timeout),
                4, "Timeout");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on SPI frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR enabled/Enables the filtering on SPI frames. Only the frames that match the
/// HIPAR enabled/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR enabled/Enables or disables the checking condition for the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_FRAME_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_FRAME_ENABLED, enabled),
            4, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR fieldEnabled/Enables or disables the checking condition for the selected field of
/// HIPAR fieldEnabled/the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilterField(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViBoolean fieldEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_FIELD_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_FIELD_ENABLED, fieldEnabled),
            5, "Field Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the error type to be filtered on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR error/Sets the repeated capability value for Error.
/// HIPAR enabled/Defines the error type to be filtered on.
ViStatus _VI_FUNC rsmxo_EnableProtocolSPIFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_ERROR_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_ERROR, errorNumber),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_ERROR_ENABLED, enabled),
            4, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and values for the index in the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR index/Sets the operator for the index in the selected field of the selected
/// HIPAR index/frame.
/// HIPAR startIndex/Specifies the index, or sets the start value of an index range.
/// HIPAR endIndex/Sets the end value of an index range if the operator is set to In
/// HIPAR endIndex/Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIFilterIndex(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   index,
                                                        ViInt32   startIndex,
                                                        ViInt32   endIndex)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_INDEX,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_INDEX, index),
            5, "Index");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_START_INDEX, startIndex),
            6, "Start Index");

    if (index == RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_INRANGE)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_END_INDEX, endIndex),
                7, "End Index");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and values for the data pattern in the selected
/// HIFN  field of the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR data/Sets the operator for the data pattern in the selected field of the
/// HIPAR data/selected frame.
/// HIPAR start/Specifies the data pattern, or sets the start value of an data pattern
/// HIPAR start/range.
/// HIPAR end/Sets the end value of a data pattern   range if the operator is set to
/// HIPAR end/In Range or Out Of Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIFilterData(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   frame,
                                                       ViInt32   field,
                                                       ViInt32   data,
                                                       ViString  start,
                                                       ViString  end)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_DATA, data),
            5, "Data");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_START_DATA, start),
            6, "Start");

    if (data >= RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_IN_RANGE)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_END_DATA, end),
                7, "End");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the bit state of a field that only consists of one bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR condition/Sets the bit state of a field that only consists of one bit.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPIFilterCondition(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   condition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_FILTER_CONDITION,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_FILTER_CONDITION, condition),
            5, "Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger type for SPI analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger type for SPI analysis.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerType(ViSession instrSession,
                                                        ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how the specified data pattern is searched.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR searchMode/Defines how the specified data pattern is searched.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerSearchMode(
                            ViSession instrSession,
                            ViInt32   searchMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_SEARCH_MODE, searchMode),
            2, "Search Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the operator and data values for the MISO and MOSI pattern.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR data/Selects the operator for the MISO and MOSI pattern.
/// HIPAR dataPattern/Specifies a data bit pattern, or sets the start value of a pattern
/// HIPAR dataPattern/range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerData(ViSession instrSession,
                                                        ViInt32   data,
                                                        ViString  dataPattern)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_DATA, data),
            2, "Data");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_DATA_PATTERN, dataPattern),
            3, "Data Pattern");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the data position.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataPosition/Sets the number of bits or words to be ignored before the first bit or
/// HIPAR dataPosition/word od interest. The effect is defined by
/// HIPAR dataPosition/RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_SEARCH_MODE.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolSPITriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_TRIGGER_DATA_POSITION, dataPosition),
            2, "Data Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns results of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Returns the overall state of the specified frame.
/// HIPAR start/Returns the start time of the specified frame.
/// HIPAR end/Returns the end time of the specified frame.
/// HIPAR count/Returns the number of decoded frames.
/// HIPAR bitRate/Returns the bit rate of the specified frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  state,
                                                     ViReal64* start,
                                                     ViReal64* end,
                                                     ViInt32*  count,
                                                     ViReal64* bitRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FRAME_START, start),
            5, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FRAME_END, end),
            6, "End");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_COUNT, count),
            7, "Count");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_BIT_RATE, bitRate),
            8, "Bit Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of words in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR wordCount/Returns the number of words in the specified frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsWordCount(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  wordCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_DATA_WORD_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_DATA_WORD_COUNT, wordCount),
            4, "Word Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the results of the selected word.

/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR word/Sets the repeated capability Word.
/// HIPAR start/Returns the start time of the specified data word.
/// HIPAR end/Returns the end time of the specified data word.
/// HIPAR mosiValue/Returns the data value of the specified word on the MOSI line.
/// HIPAR misoValue/Returns the data value of the specified word on the MISO line.
/// HIPAR formatedMOSI/Returns the formatted value of the specified word on the MOSI line.
/// HIPAR formatedMISO/Returns the formatted value of the specified word on the MISO line.
ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsWord(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   word,
                                                    ViReal64* start,
                                                    ViReal64* end,
                                                    ViReal64* mosiValue,
                                                    ViReal64* misoValue,
                                                    ViReal64* formatedMOSI,
                                                    ViReal64* formatedMISO)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_WORD_START,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_WORD, word),
            4, "Word");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_WORD_START, start),
            5, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_WORD_END, end),
            6, "End");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_MOSI_VALUE, mosiValue),
            7, "MOSI Value");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_MISO_VALUE, misoValue),
            8, "MISO Value");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FORMATED_MOSI, formatedMOSI),
            9, "Formated MOSI");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_FORMATED_MISO, formatedMISO),
            10, "Formated MISO");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data words of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR data/Returns the data words of the specified frame.
/// HIPAR pointsReturned/Returns the number of data points read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolSPIResultsData(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViReal64  data[],
                                                    ViInt32*  pointsRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_SPI_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_PROTOCOL_SPI_RESULTS_DATA, NULL, bufferSize, data, pointsRead),
                5, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the transmitter source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Selects the input channel for the transmitter signal.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTXSource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_TX_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_TX_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the transmitter settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets a user-defined threshold value for the Tx line.
/// HIPAR hysteresis/Sets the hysteresis for the Tx line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTXSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_TX_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_TX_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_TX_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configres the reciever source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Selects the input channel for the receiver signal.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTRXSource(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RX_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RX_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configres the settings for the reciever.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets a user-defined threshold value for the Rx line.
/// HIPAR hysteresis/Sets the hysteresis for the Tx line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTRXSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RX_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RX_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RX_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the logic levels of the bus. The idle state corresponds to a
/// HIFN  logic 1. The start bit corresponds to a logic 0. Idle high (high=1) is
/// HIFN  used, for example, for control signals, while Idle low (low=1) is
/// HIFN  defined for data lines (RS-232).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR polarity/Defines the logic levels of the bus. The idle state corresponds to a
/// HIPAR polarity/logic 1. The start bit corresponds to a logic 0. Idle high (high=1) is
/// HIPAR polarity/used, for example, for control signals, while Idle low (low=1) is
/// HIPAR polarity/defined for data lines (RS-232).
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTPolarity(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   polarity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_POLARITY,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_POLARITY, polarity),
            3, "Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of transmitted bits per second.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR bitRate/Sets the number of transmitted bits per second.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTBitRate(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  bitRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_BIT_RATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_BIT_RATE, bitRate),
            3, "Bit Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the bit order, which determines if the data of the messages
/// HIFN  starts with MSB (most significant bit) or LSB (least significant bit).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR bitOrder/Selects the bit order, which determines if the data of the messages
/// HIPAR bitOrder/starts with MSB (most significant bit) or LSB (least significant bit).
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTBitOrder(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   bitOrder)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_BIT_ORDER,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_BIT_ORDER, bitOrder),
            3, "Bit Order");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of data bits of a word in a range from 5 bits to 8
/// HIFN  bits. If no parity bit is used, then 9 data bits are possible.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR dataBits/Sets the number of data bits of a word in a range from 5 bits to 8
/// HIPAR dataBits/bits. If no parity bit is used, then 9 data bits are possible.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTDataBits(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   dataBits)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_DATA_BITS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_DATA_BITS, dataBits),
            3, "Data Bits");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the optional parity bit that is used for error detection.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR parity/Defines the optional parity bit that is used for error detection.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTParity(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   parity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_PARITY,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_PARITY, parity),
            3, "Parity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of stop bits: 1 or 1.5 or 2 stop bits are possible.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR stopBits/Sets the number of stop bits: 1 or 1.5 or 2 stop bits are possible.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTStopBits(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   stopBits)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_STOP_BITS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_STOP_BITS, stopBits),
            3, "Stop Bits");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the advanced UART protocol settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR packets/Defines the method of packet separation. A packet is a number of
/// HIPAR packets/subsequent words in a date stream.
/// HIPAR timeout/Sets the timeout between packets in a UART data stream. A new packet
/// HIPAR timeout/starts with the first start bit after the timeout.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTAdvancedSettings(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   packets,
                            ViReal64  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_PACKETS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_PACKETS, packets),
            3, "Packets");

    if (packets == RSMXO_VAL_PROTOCOL_UART_PACKET_TIMEOUT)
    {
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_TIMEOUT, timeout),
                4, "Timeout");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the end pattern of the packets. A new packet starts with the
/// HIFN  first start bit after the defined end pattern.
/// HIFN
/// HIFN     This setting is relevant if RSMXO_ATTR_PROTOCOL_UART_PACKETS is set to
/// HIFN  End Word.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR endWord/Sets the end pattern of the packets. A new packet starts with the
/// HIPAR endWord/first start bit after the defined end pattern.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTEndWord(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   endWord)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_END_WORD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_END_WORD, endWord),
            3, "End Word");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on UART frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR enabled/Enables the filtering on UART frames. Only the frames that match the
/// HIPAR enabled/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilter(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR frameEnabled/Enables or disables the checking condition for the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilterFrame(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViBoolean frameEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_FRAME_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_FRAME_ENABLED, frameEnabled),
            4, "Frame Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR fieldEnabled/Enables or disables the checking condition for the selected field of
/// HIPAR fieldEnabled/the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilterField(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViBoolean fieldEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_FRAME_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_FIELD_ENABLED, fieldEnabled),
            5, "Field Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the error type to be filtered on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR enabled/Defines the error type to be filtered on.
/// HIPAR error/Sets the repeated capability value for Error.
ViStatus _VI_FUNC rsmxo_EnableProtocolUARTFilterError(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   errorNumber,
                                                      ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_ERROR_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_ERROR, errorNumber),
            3, "Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_ERROR_ENABLED, enabled),
            4, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and values for the index in the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR index/Sets the operator for the index in the selected field of the selected
/// HIPAR index/frame.
/// HIPAR start/Specifies the index, or sets the start value of an index range.
/// HIPAR end/Sets the end value of an index range if the operator is set to In
/// HIPAR end/Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTFilterIndex(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   field,
                                                         ViInt32   index,
                                                         ViInt32   start,
                                                         ViInt32   end)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_INDEX,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_INDEX, index),
            5, "Index");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_START_INDEX, start),
            6, "Start");

    if (index == RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_INRANGE)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_END_INDEX, end),
                7, "End");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and value for the data pattern in the selected field
/// HIFN  of the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR data/Sets the operator for the data pattern in the selected field of the
/// HIPAR data/selected frame.
/// HIPAR start/Specifies the data pattern, or sets the start value of an data pattern
/// HIPAR start/range.
/// HIPAR end/Sets the end value of a data pattern   range if the operator is set to
/// HIPAR end/In Range or Out Of Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTFilterData(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32   field,
                                                        ViInt32   data,
                                                        ViString  start,
                                                        ViString  end)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_DATA, data),
            5, "Data");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_START_DATA, start),
            6, "Start");

    if (data >= RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_IN_RANGE)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_END_DATA, end),
                7, "End");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the bit state of a field that only consists of one bit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR condition/Sets the bit state of a field that only consists of one bit.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTFilterCondition(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   condition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_FILTER_CONDITION,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_FILTER_CONDITION, condition),
            5, "Condition");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger condition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger condition.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerType(ViSession instrSession,
                                                         ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_TRIGGER_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the transmitter or receiver line as trigger source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerSource/Selects the transmitter or receiver line as trigger source.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerSource(ViSession instrSession,
                                                           ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_TRIGGER_SOURCE, triggerSource),
            2, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the operator for the Data pattern.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR data/Selects the operator for the Data pattern.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerData(ViSession instrSession,
                                                         ViInt32   data)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_TRIGGER_DATA, data),
            2, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the data pattern to be found on the specified trigger
/// HIFN  source. Enter the words in msb first bit order.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR pattern/Specifies the data pattern to be found on the specified trigger
/// HIPAR pattern/source. Enter the words in msb first bit order.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerPattern(ViSession instrSession,
                                                            ViString  pattern)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_TRIGGER_PATTERN, pattern),
            2, "Pattern");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of words before the first word of interest. These
/// HIFN  offset words are ignored.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataPosition/Sets the number of words before the first word of interest. These
/// HIPAR dataPosition/offset words are ignored.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION, dataPosition),
            2, "Data Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator for the data pattern in the selected field of the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR operator/Sets the operator for the data pattern in the selected field of the
/// HIPAR operator/selected frame.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolUARTTriggerOperator(ViSession instrSession,
                                                             ViInt32   operatorType)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_TRIGGER_OPERATOR, operatorType),
            2, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the line on which the specified word was transferred.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Returns the line on which the specified word was transferred.
/// HIPAR word/Sets the repeated capability Word.
ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsSource(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViInt32   word,
                                                       ViInt32*  source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RESULTS_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_WORD, word),
            3, "Word");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_SOURCE, source),
            4, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of words in the acquisition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR word/Sets the repeated capability Word.
/// HIPAR count/Returns the number of words in the acquisition.
ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsWordCount(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   word,
                                                          ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RESULTS_WORD_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_WORD, word),
            3, "Word");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_WORD_COUNT, count),
            4, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the stop time of the specified word.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR word/Sets the repeated capability Word.
/// HIPAR end/Returns the stop time of the specified word.
ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsWordEnd(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   word,
                                                        ViReal64* end)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RESULTS_STOP,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_WORD, word),
            3, "Word");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_STOP, end),
            4, "End");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the decode table results for Tx line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR word/Sets the repeated capability Word.
/// HIPAR state/Returns the status of the specified word.
/// HIPAR start/Returns the start time of the specified word.
/// HIPAR txValue/Returns the value of the specified word on the Tx line.
/// HIPAR dataRate/Returns the primary bit rate.
ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsDecodeTableTransmitter(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   word,
                            ViInt32*  state,
                            ViReal64* start,
                            ViReal64* txValue,
                            ViReal64* dataRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RESULTS_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_WORD, word),
            3, "Word");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_START, start),
            5, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_TX_VALUE, txValue),
            6, "TX Value");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_DATA_RATE, dataRate),
            7, "Data Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the decode table results for Rx line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR word/Sets the repeated capability Word.
/// HIPAR state/Returns the status of the specified word.
/// HIPAR start/Returns the start time of the specified word.
/// HIPAR rxValue/Returns the value of the specified word on the Rx line.
/// HIPAR dataRate/Returns the primary bit rate.
ViStatus _VI_FUNC rsmxo_QueryProtocolUARTResultsDecodeTableReciever(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   word,
                            ViInt32*  state,
                            ViReal64* start,
                            ViReal64* rxValue,
                            ViReal64* dataRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_UART_RESULTS_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_UART_SELECTED_WORD, word),
            3, "Word");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_START, start),
            5, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_RX_VALUE, rxValue),
            6, "RX Value");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_UART_RESULTS_DATA_RATE, dataRate),
            7, "Data Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the source channel to which the data line is connected.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the source channel to which the data line is connected.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSource(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the CAN-High or CAN-Low line. Both lines are required for
/// HIFN  differential signal transmission used by CAN.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR type/Selects the CAN-High or CAN-Low line. Both lines are required for
/// HIPAR type/differential signal transmission used by CAN.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANType(ViSession instrSession,
                                                 ViInt32   serialBus,
                                                 ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_TYPE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a user-defined threshold and hysteresis value for the data line.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets a user-defined threshold value for the data line.
/// HIPAR hysteresis/Sets a hysteresis value for the data line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSettings(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  threshold,
                                                     ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_THRESHOLD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the transceiver mode for the CAN decoding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR mode/Selects the transceiver mode for the CAN decoding.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTransceiverMode(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_TRANSCEIVER_MODE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_TRANSCEIVER_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a threshold and hysteresis value for the SIC transceiver mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets a threshold value for the SIC transceiver mode.
/// HIPAR hysteresis/Sets a hysteresis value for the SIC transceiver mode.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSICSettings(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViReal64  threshold,
                                                        ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_SIC_THRESHOLD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_SIC_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_SIC_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a threshold and hysteresis value for the fast transceiver mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets a threshold value for the fast transceiver mode.
/// HIPAR hysteresis/Sets a hysteresis value for the fast transceiver mode.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFASTSettings(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViReal64  threshold,
                                                         ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FAST_THRESHOLD, "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
                2, "Serial Bus")

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FAST_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FAST_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the number of transmitted bits per second.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR nominalBitRate/Sets the number of transmitted bits per second.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANNominalBitRate(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViReal64  nominalBitRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_NOMINAL_BIT_RATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_NOMINAL_BIT_RATE, nominalBitRate),
            3, "Nominal Bit Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the bit rate and sample poinf of the data phase.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR bitRate/Sets the bit rate of the data phase.
/// HIPAR samplePoint/Sets the position of the sample point within the bit in percent of the
/// HIPAR samplePoint/nominal bit time.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFDSettings(ViSession instrSession,
                                                       ViInt32   serialBus,
                                                       ViReal64  bitRate,
                                                       ViReal64  samplePoint)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FD_BIT_RATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FD_BIT_RATE, bitRate),
            3, "Bit Rate");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FD_SAMPLE_POINT, samplePoint),
            4, "Sample Point");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the number of decoded frames for the CAN protocol analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR decodedFrames/Returns the number of decoded frames for the CAN protocol analysis.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANDecodedFrames(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32*  decodedFrames)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_DECODED_FRAMES,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_DECODED_FRAMES, decodedFrames),
            3, "Decoded Frames");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the bit rate of the data phase for the CAN-XL frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR bitrate/Sets the bit rate of the data phase for the CAN-XL frame.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLBitrate(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   bitrate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_BITRATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_BITRATE, bitrate),
            3, "Bitrate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the position of the sample point within the bit in percent of the
/// HIFN  nominal bit time for the CAN-XL frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR samplePoint/Sets the position of the sample point within the bit in percent of the
/// HIPAR samplePoint/nominal bit time for the CAN-XL frame.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLSamplePoint(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   samplePoint)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_SAMPLE_POINT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_SAMPLE_POINT, samplePoint),
            3, "Sample Point");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the symbol list to be used for decoding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR showSymbols/Activates the symbol list to be used for decoding.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANShowSymbols(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViBoolean showSymbols)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_SHOW_SYMBOLS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_SHOW_SYMBOLS, showSymbols),
            3, "Show Symbols");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads a symbol list file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR file/Loads a symbol list file.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANSymbolListFile(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViString  file)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_SYMBOL_LIST_FILE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_SYMBOL_LIST_FILE, file),
            3, "File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on CAN frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR filter/Enables the filtering on CAN frames. Only the frames that match the
/// HIPAR filter/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean filter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_ENABLED, filter),
            3, "Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on CAN frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR enabled/Enables the filtering on CAN frames. Only the frames that match the
/// HIPAR enabled/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_ENABLED, enabled),
            4, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR enabled/Enables or disables the checking condition for the selected field of
/// HIPAR enabled/the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilterFrameField(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32   field,
                                                          ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_FIELD_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FRAME_FIELD_ENABLED, enabled),
            5, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the error type to be filtered on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR error/Sets the repeated capability value for Error.
/// HIPAR enabled/Defines the error type to be filtered on.
ViStatus _VI_FUNC rsmxo_EnableProtocolCANFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_ERROR_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_ERROR, errorNumber),
            3, "Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_ERROR_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator for the data pattern in the selected field of the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR operatorType/Sets the operator for the data pattern in the selected field of the
/// HIPAR operatorType/selected frame.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFilterFieldOperator(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   operatorType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_OPERATOR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_OPERATOR, operatorType),
            5, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and the data pattern in the selected field of the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR operatorType/Sets the operator for the data pattern in the selected field of the
/// HIPAR operatorType/selected frame.
/// HIPAR startData/Specifies the data pattern, or sets the start value of a data pattern
/// HIPAR startData/range.
/// HIPAR endData/Sets the end value of a data pattern   range if the operator is set to
/// HIPAR endData/In Range or Out Of RAnge.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFilterFieldData(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   operatorType,
                                                            ViString  startData,
                                                            ViString  endData)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_DATA_OPERATOR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_DATA_OPERATOR, operatorType),
            5, "Operator Type");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_START_DATA, startData),
            6, "Start Data");

    if (operatorType >= RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_IN_RANGE)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_END_DATA, endData),
                7, "End Data");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and the index in the selected field of the selected
/// HIFN  frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR operator/Sets the operator for the index in the selected field of the selected
/// HIPAR operator/frame.
/// HIPAR startIndex/Specifies the index, or sets the start value of an index range.
/// HIPAR endIndex/Sets the end value of an index range if the operator is set to In
/// HIPAR endIndex/Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANFilterFieldIndex(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   operatorType,
                                                             ViInt32   startIndex,
                                                             ViInt32   endIndex)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_INDEX_OPERATOR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_INDEX_OPERATOR, operatorType),
            5, "Operator Type");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_START_INDEX, startIndex),
            6, "Start Index");

    if (operatorType == RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_INRANGE)
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_FILTER_FIELD_END_INDEX, endIndex),
                7, "End Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger type for CAN analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger type for CAN analysis.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerType(ViSession instrSession,
                                                        ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the CAN frame type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Sets the CAN frame type.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerFrameType(ViSession instrSession,
                                                             ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_FRAME_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the format of data and remote frames.
/// HIFN
/// HIFN     Remote frames are not available in the CAN FD protocol.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the format of data and remote frames.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerIdentifierType(
                            ViSession instrSession,
                            ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the identifier operator and identifier range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR identifier/Sets the operator to set a specific identifier or an identifier range.
/// HIPAR identifierMinimum/Specifies a message identifier pattern, or sets the start value of an
/// HIPAR identifierMinimum/identifier range.
/// HIPAR identifierMaximum/Sets the end value of an identifier range if
/// HIPAR identifierMaximum/RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_CONDITION is set to In Range
/// HIPAR identifierMaximum/or Out Of Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerIdentifier(
                            ViSession instrSession,
                            ViInt32   identifier,
                            ViString  identifierMinimum,
                            ViString  identifierMaximum)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_CONDITION, identifier),
            2, "Identifier");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_MINIMUM, identifierMinimum),
            3, "Identifier Minimum");

    if (identifier == RSMXO_VAL_CONDITION_OPERATOR_IN_RANGE || identifier == RSMXO_VAL_CONDITION_OPERATOR_OF_RANGE)
        viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_IDENTIFIER_MAXIMUM, identifierMaximum),
                4, "Identifier Maximum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator to set a specific data pattern or a data pattern
/// HIFN  range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataPattern/Sets the operator to set a specific data pattern or a data pattern
/// HIPAR dataPattern/range.
/// HIPAR dataValue/Sets a data pattern, or sets the start value of a data pattern range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerData(ViSession instrSession,
                                                        ViInt32   dataPattern,
                                                        ViString  dataValue)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_CONDITION, dataPattern),
            2, "Data Pattern");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_MINIMUM, dataValue),
            3, "Data Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the number of the first data byte at which the data pattern
/// HIFN  may start.
/// HIFN
/// HIFN     The setting is available for CAN FD option.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR position/Defines the number of the first data byte at which the data pattern
/// HIPAR position/may start.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   index)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DATA_POSITION, index),
            2, "Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the error trigger conditions.
/// HIFN
/// HIFN     The trigger type has to be set before:
/// HIFN  RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_TYPE to Error Condition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR checksumError/Triggers on CRC errors. A CRC error occurs when the CRC calculated by
/// HIPAR checksumError/the receiver differs from the received value in the CRC sequence.
/// HIPAR formError/Triggers when a fixed-form bit field contains one or more illegal
/// HIPAR formError/bits.
/// HIPAR bitStuffingError/Triggers if a stuff error occurs - when the 6th consecutive equal bit
/// HIPAR bitStuffingError/level in the mentioned fields is detected.
/// HIPAR ackError/Triggers when the transmitter does not receive an acknowledgment - a
/// HIPAR ackError/dominant bit during the Ack Slot.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerErrorCondition(
                            ViSession instrSession,
                            ViBoolean checksumError,
                            ViBoolean formError,
                            ViBoolean bitStuffingError,
                            ViBoolean ackError)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_CHECKSUM_ERROR_ENABLED, checksumError),
            2, "Checksum Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_FORM_ERROR_ENABLED, formError),
            3, "Form Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_BIT_STUFFING_ERROR_ENABLED, bitStuffingError),
            4, "Bit Stuffing Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_ACK_ERROR_ENABLED, ackError),
            5, "Ack Error");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Triggers on stuff count errors. A stuff count error occurs if th
/// HIFN  received stuff count value does not match the value calculated from the
/// HIFN  own stuff bit count.
/// HIFN
/// HIFN     The trigger type RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_TYPE must be set to
/// HIFN  Error Condition.
/// HIFN
/// HIFN     Only relevant for CAN FD signals in ISO standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR stuffCount/Triggers on stuff count errors. A stuff count error occurs if th
/// HIPAR stuffCount/received stuff count value does not match the value calculated from the
/// HIPAR stuffCount/own stuff bit count.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerStuffCountErrorEnabled(
                            ViSession instrSession,
                            ViBoolean stuffCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_STUFF_COUNT_ERROR_ENABLED, stuffCount),
            2, "Stuff Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures CAN-FD trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR brs/Sets the bit rate switch bit.
/// HIPAR esi/Sets the error state indicator bit.
/// HIPAR dlcCondition/Operator to set the data length code for triggering on CAN and CAN FD
/// HIPAR dlcCondition/data.
/// HIPAR dlc/Sets the Data Length Code, the number of data bytes to be found. For
/// HIPAR dlc/complete definition, set also the operator with
/// HIPAR dlc/RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DLC_CONDITION.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANTriggerCANFDSettings(
                            ViSession instrSession,
                            ViInt32   brs,
                            ViInt32   esi,
                            ViInt32   dlcCondition,
                            ViInt32   dlc)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_BRS, brs),
            2, "BRS");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_ESI, esi),
            3, "ESI");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DLC_CONDITION, dlcCondition),
            4, "DLC Condition");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_TRIGGER_DLC, dlc),
            5, "DLC");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets a value for the simple extended content (SEC) field. It
/// HIFN  indicates, if the CAN XL data frame uses the CADsec protocol.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sec/Sets a value for the simple extended content (SEC) field. It
/// HIPAR sec/indicates, if the CAN XL data frame uses the CADsec protocol.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerSEC(ViSession instrSession,
                                                         ViInt32   sec)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_XL_TRIGGER_SEC, sec),
            2, "SEC");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures AF Trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for the acceptance field to a specific
/// HIPAR condition/value or a range.
/// HIPAR max/Sets the end value of an acceptance field if
/// HIPAR max/RSMXO_ATTR_PROTOCOL_CAN_XL_AF_TRIGGER_CONDITION is set to INRange or
/// HIPAR max/OORange.
/// HIPAR min/Specifies an acceptance field pattern, or sets the start value of a
/// HIPAR min/range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerAF(ViSession instrSession,
                                                        ViInt32   condition,
                                                        ViReal64  max[],
                                                        ViReal64  min[])
{
    ViStatus error = VI_SUCCESS;
    ViString paramMax = "";
    ViString paramMin = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_XL_AF_TRIGGER_CONDITION, condition),
            2, "Condition");

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, max, RS_PARAM_BUF_SIZE, NULL, &paramMax));
    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, min, RS_PARAM_BUF_SIZE, NULL, &paramMin));

    if (condition == RSMXO_VAL_XDATA_CONDITION_OPERATOR_OOR || condition == RSMXO_VAL_XDATA_CONDITION_OPERATOR_INR)
    {
        checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_PROTOCOL_CAN_XL_AF_TRIGGER_MAX, RS_VAL_DIRECT_USER_CALL, paramMax));
    }

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_PROTOCOL_CAN_XL_AF_TRIGGER_MIN, RS_VAL_DIRECT_USER_CALL, paramMin));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures SDT Trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for the acceptance field to a specific
/// HIPAR condition/value or a range.
/// HIPAR max/Sets the end value of an acceptance field if
/// HIPAR max/RSMXO_ATTR_PROTOCOL_CAN_XL_SDT_TRIGGER_CONDITION is set to INRange or
/// HIPAR max/OORange.
/// HIPAR min/Specifies an acceptance field pattern, or sets the start value of a
/// HIPAR min/range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerSDT(ViSession instrSession,
                                                         ViInt32   condition,
                                                         ViReal64  max[],
                                                         ViReal64  min[])
{
    ViStatus error = VI_SUCCESS;
    ViString paramMax = "";
    ViString paramMin = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_XL_SDT_TRIGGER_CONDITION, condition),
            2, "Condition");

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, max, RS_PARAM_BUF_SIZE, NULL, &paramMax));
    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, min, RS_PARAM_BUF_SIZE, NULL, &paramMin));

    if (condition == RSMXO_VAL_XDATA_CONDITION_OPERATOR_OOR || condition == RSMXO_VAL_XDATA_CONDITION_OPERATOR_INR)
    {
        checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_PROTOCOL_CAN_XL_SDT_TRIGGER_MAX, RS_VAL_DIRECT_USER_CALL, paramMax));
    }

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_PROTOCOL_CAN_XL_SDT_TRIGGER_MIN, RS_VAL_DIRECT_USER_CALL, paramMin));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures VCID Trigger.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Sets the comparison condition for the VCID to a specific value or a
/// HIPAR condition/range.
/// HIPAR max/Sets the end value of an acceptance field if
/// HIPAR max/RSMXO_ATTR_PROTOCOL_CAN_XL_VCID_TRIGGER_CONDITION is set to INRange or
/// HIPAR max/OORange.
/// HIPAR min/Specifies a VCID pattern, or sets the start value of a range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolCANXLTriggerVCID(ViSession instrSession,
                                                          ViInt32   condition,
                                                          ViReal64  max[],
                                                          ViReal64  min[])
{
    ViStatus error = VI_SUCCESS;
    ViString paramMax = "";
    ViString paramMin = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_XL_VCID_TRIGGER_CONDITION, condition),
            2, "Condition");

    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, max, RS_PARAM_BUF_SIZE, NULL, &paramMax));
    checkErr(RsCore_Convert_ViReal64array_To_String(instrSession, min, RS_PARAM_BUF_SIZE, NULL, &paramMin));

    if (condition == RSMXO_VAL_XDATA_CONDITION_OPERATOR_OOR || condition == RSMXO_VAL_XDATA_CONDITION_OPERATOR_INR)
    {
        checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_PROTOCOL_CAN_XL_VCID_TRIGGER_MAX, RS_VAL_DIRECT_USER_CALL, paramMax));
    }

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_PROTOCOL_CAN_XL_VCID_TRIGGER_MIN, RS_VAL_DIRECT_USER_CALL, paramMin));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the results of the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Returns the overall state of the selected frame.
/// HIPAR type/Returns the frame type of the selected frame.
/// HIPAR start/Return the start time of the selected frame.
/// HIPAR stop/Return the stop time of the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32*  state,
                                                     ViInt32*  type,
                                                     ViReal64* start,
                                                     ViReal64* stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_TYPE, type),
            5, "Type");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_START, start),
            6, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_STOP, stop),
            7, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the symbol of the specified frame if the label list is
/// HIFN  enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR symbol/Returns the symbol of the specified frame if the label list is
/// HIPAR symbol/enabled.
/// HIPAR frame/Sets the repeated capability value for Frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFrameSymbol(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   bufferSize,
                                                           ViChar    symbol[],
                                                           ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_SYMBOL,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    checkErr(RsCore_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FRAME_SYMBOL, RS_VAL_DIRECT_USER_CALL, bufferSize, symbol, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Return the results of the identifier.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Return the states of the identifier state.
/// HIPAR type/Returns the identifier type of the selected frame, the identifier
/// HIPAR type/format of data and remote frames.
/// HIPAR value/Returns the identifier value of the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsIdentifier(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  state,
                                                          ViInt32*  type,
                                                          ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_TYPE, type),
            5, "Type");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ID_VALUE, value),
            6, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Return the results of the acknowledgement field.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Return the states of the acknowledgement field.
/// HIPAR value/Returns the value of the acknowledge slot for the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsACK(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32*  state,
                                                   ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_VALUE, value),
            5, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Return the state of the acknowledgement field.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Return the states of the acknowledgement field.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsACKState(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Return the results of the acknowledgement field.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR value/Returns the value of the acknowledge slot for the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsACKValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_ACK_VALUE, value),
            4, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the state of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR state/Returns the state of the specified byte.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsByteState(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   byteNumber,
                                                         ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BYTE_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BYTE_STATE, state),
            5, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the results of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR value/Returns the value of the specified byte.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsByteValue(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   byteNumber,
                                                         ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BYTE_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BYTE_VALUE, value),
            5, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Return the state of the checksum field (CRC).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Return the states of the checksum field (CRC).
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsCRCState(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_CRC_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_CRC_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Return the value of the checksum field (CRC).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR value/Returns the CRC sequence value of the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsCRCValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_CRC_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_CRC_VALUE, value),
            4, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Return the state of the state of data length code.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR state/Return the states of the state of data length code.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDLCState(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DLC_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DLC_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Return the value of the state of data length code.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR value/Returns the data length code of the selected frame - the number of
/// HIPAR value/data bytes in the frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDLCValue(ViSession instrSession,
                                                        ViInt32   serialBus,
                                                        ViInt32   frame,
                                                        ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DLC_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DLC_VALUE, value),
            4, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the location of a bit stuffing error.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR errorPosition/Returns the location of a bit stuffing error.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsBitStuffingErrorPosition(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViReal64* errorPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BIT_STUFFING_ERROR_POSITION,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_BIT_STUFFING_ERROR_POSITION, errorPosition),
            4, "Error Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns information on a form error, if the frame status query
/// HIFN  (SBUS<m>:CAN:FRAMe<fr>:STATus?) returned a FORM error.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR formError/Returns information on a form error, if the frame status query
/// HIPAR formError/(SBUS<m>:CAN:FRAMe<fr>:STATus?) returned a FORM error.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsFormError(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32*  formError)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FORM_ERROR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FORM_ERROR, formError),
            4, "Form Error");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of data bytes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR dataBytesNumber/Returns the number of data bytes.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsDataBytesNumber(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  dataBytesNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA_BYTES_NUMBER,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            2, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA_BYTES_NUMBER, dataBytesNumber),
            3, "Data Bytes Number");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR data/Returns the data of the specified frame.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsData(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViInt32   frame,
                                                    ViInt32   bufferSize,
                                                    ViChar    data[],
                                                    ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(RsCore_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_DATA, RS_VAL_DIRECT_USER_CALL, bufferSize, data, bytesRead),
                5, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a list of comma-separated pattern data values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR patternData/Returns a list of comma-separated pattern data values.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsPatternData(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViInt32   bufferSize,
                                                           ViChar    patternData[],
                                                           ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_PATTERN_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_PATTERN_DATA, bufferSize, patternData, bytesRead),
                5, "Pattern Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the symbolic data of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR symbolicData/Returns the symbolic data of the specified frame.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsSymbolicData(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   bufferSize,
                                                            ViChar    symbolicData[],
                                                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_SYMBOLIC_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_SYMBOLIC_DATA, bufferSize, symbolicData, bytesRead),
                5, "Symbolic Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the symbolic data of the frame in export format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR bufferSize/Size of output array.
/// HIPAR dataExport/Returns the symbolic data of the frame in export format.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsSymbolicDataExport(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   bufferSize,
                            ViChar    dataExport[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_SYMBOLIC_DATA_EXPORT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_SYMBOLIC_DATA_EXPORT, bufferSize, dataExport, bytesRead),
                5, "Data Export");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the stuff count field.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR stuffCountField/Returns the value of the stuff count field.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsStuffCountField(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  stuffCountField)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_STUFF_COUNT_FIELD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_STUFF_COUNT_FIELD, stuffCountField),
            4, "Stuff Count Field");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the value of the bit rate switch (BRS) field for the selected
/// HIFN  frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR brs/Returns the value of the bit rate switch (BRS) field for the selected
/// HIPAR brs/frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsBRS(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViInt32*  brs)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FIELD_BRS,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FIELD_BRS, brs),
            5, "BRS");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the error state indicator (ESI) field for the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR esi/Returns the value of the error state indicator (ESI) field for the
/// HIPAR esi/selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANResultsESI(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   frame,
                                                   ViInt32   field,
                                                   ViInt32*  esi)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FIELD_ESI,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_RESULTS_FIELD_ESI, esi),
            5, "ESI");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the acceptance field for the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR resultsFieldAcceptance/Returns the value of the acceptance field for the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsAcceptance(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViReal64* resultsFieldAcceptance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_ACCEPTANCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_ACCEPTANCE, resultsFieldAcceptance),
            5, "Results Field Acceptance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the preamble cyclic redundant check (PCRC) for
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR pcrc/Returns the value of the preamble cyclic redundant check (PCRC) for
/// HIPAR pcrc/the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsPCRC(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViInt32*  pcrc)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_PCRC,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_PCRC, pcrc),
            5, "PCRC");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the stuff bit count (SBC) field for the selected
/// HIFN  CAN XL frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR sbc/Returns the value of the stuff bit count (SBC) field for the selected
/// HIPAR sbc/CAN XL frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsSBC(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViInt32*  sbc)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SBC,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SBC, sbc),
            5, "SBC");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the service data unit field for the selected
/// HIFN  frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR fieldServiceDataUnit/Returns the value of the service data unit field for the selected
/// HIPAR fieldServiceDataUnit/frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsServiceDataUnit(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32*  fieldServiceDataUnit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SERVICE_DATA_UNIT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SERVICE_DATA_UNIT, fieldServiceDataUnit),
            5, "Field Service Data Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the simple extended content (SEC) field for the
/// HIFN  selected CAN XL frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR sec/Returns the value of the simple extended content (SEC) field for the
/// HIPAR sec/selected CAN XL frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsSEC(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViInt32*  sec)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SEC,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_SEC, sec),
            5, "SEC");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the value of the VCID field for the selected CAN XL frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialbus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability value for Frame.
/// HIPAR field/Sets the repeated capability value for Field.
/// HIPAR vcid/Returns the value of the VCID field for the selected CAN XL frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolCANXLResultsVCID(ViSession instrSession,
                                                      ViInt32   serialBus,
                                                      ViInt32   frame,
                                                      ViInt32   field,
                                                      ViInt32*  vcid)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_VCID,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_CAN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_CAN_XL_RESULTS_FIELD_VCID, vcid),
            5, "VCID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the version of the LIN standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR standard/Selects the version of the LIN standard.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINStandard(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   standard)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_STANDARD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_STANDARD, standard),
            3, "Standard");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the waveform of the data line
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR source/Sets the waveform of the data line.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINSource(ViSession instrSession,
                                                   ViInt32   serialBus,
                                                   ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_SOURCE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_SOURCE, source),
            3, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a user-defined threshold and hysteresis values for the data
/// HIFN  channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR threshold/Sets a user-defined threshold value for the data channel.
/// HIPAR hysteresis/Sets a value for the hysteresis for the data channel.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINSettings(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViReal64  threshold,
                                                     ViReal64  hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_THRESHOLD,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_THRESHOLD, threshold),
            3, "Threshold");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the idle state of the bus. The idle state is the rezessive
/// HIFN  state and corresponds to a logic 1.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR polarity/Defines the idle state of the bus. The idle state is the rezessive
/// HIPAR polarity/state and corresponds to a logic 1.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINPolarity(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   polarity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_POLARITY,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_POLARITY, polarity),
            3, "Polarity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of transmitted bits per second. The maximum bit rate
/// HIFN  for LIN is 20 kbit/s.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR bitRate/Sets the number of transmitted bits per second. The maximum bit rate
/// HIPAR bitRate/for LIN is 20 kbit/s.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINBitRate(ViSession instrSession,
                                                    ViInt32   serialBus,
                                                    ViReal64  bitRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_BIT_RATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_BIT_RATE, bitRate),
            3, "Bit Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on LIN frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR filter/Enables the filtering on LIN frames. Only the frames that match the
/// HIPAR filter/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilter(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean filter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_ENABLED, filter),
            3, "Filter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the filtering on LIN frames. Only the frames that match the
/// HIFN  selected filter conditions are displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR enabled/Enables the filtering on LIN frames. Only the frames that match the
/// HIPAR enabled/selected filter conditions are displayed.
ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilterFrame(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FRAME_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FRAME_ENABLED, enabled),
            4, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the checking condition for the selected field of
/// HIFN  the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR field/Sets the repeated capability Field.
/// HIPAR enabled/Enables or disables the checking condition for the selected field of
/// HIPAR enabled/the selected frame.
ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilterField(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   frame,
                                                     ViInt32   field,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_ENABLED, enabled),
            5, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the error type to be filtered on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR enabled/Sets the repeated capability Error.
/// HIPAR enabled/Defines the error type to be filtered on.
ViStatus _VI_FUNC rsmxo_EnableProtocolLINFilterError(ViSession instrSession,
                                                     ViInt32   serialBus,
                                                     ViInt32   errorNumber,
                                                     ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_ERROR_ENABLED,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_ERROR, errorNumber),
            2, "Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_ERROR_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator for the data pattern in the selected field of the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR field/Sets the repeated capability Field.
/// HIPAR operatorType/Sets the operator for the data pattern in the selected field of the
/// HIPAR operatorType/selected frame.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINFilterFieldOperator(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   field,
                            ViInt32   operatorType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_OPERATOR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_OPERATOR, operatorType),
            5, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the data operator and patterns in the selected field of the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR field/Sets the repeated capability Field.
/// HIPAR operatorType/Sets the operator for the data pattern in the selected field of the
/// HIPAR operatorType/selected frame.
/// HIPAR startData/Specifies the data pattern, or sets the start value of a data pattern
/// HIPAR startData/range.
/// HIPAR endData/Sets the end value of a data pattern  range if the operator is set to
/// HIPAR endData/In Range or Out Of Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINFilterFieldData(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32   field,
                                                            ViInt32   operatorType,
                                                            ViString  startData,
                                                            ViString  endData)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_DATA_OPERATOR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_DATA_OPERATOR, operatorType),
            5, "Operator Type");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_START_DATA, startData),
            6, "Start Data");

    if (operatorType >= RSMXO_VAL_PROCOTOL_FILTER_DATA_OPERATOR_IN_RANGE)
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_END_DATA, endData),
                7, "End Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the index operator and values in the selected field of the
/// HIFN  selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR field/Sets the repeated capability Field.
/// HIPAR operatorType/Sets the operator for the index in the selected field of the selected
/// HIPAR operatorType/frame.
/// HIPAR startIndex/Specifies the index, or sets the start value of an index range.
/// HIPAR endIndex/Sets the end value of an index range if the operator is set to In
/// HIPAR endIndex/Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINFilterFieldIndex(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32   field,
                                                             ViInt32   operatorType,
                                                             ViInt32   startIndex,
                                                             ViInt32   endIndex)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_INDEX_OPERATOR,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FIELD, field),
            4, "Field");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_INDEX_OPERATOR, operatorType),
            5, "Operator Type");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_START_INDEX, startIndex),
            6, "Start Index");

    if (operatorType == RSMXO_VAL_PROTOCOL_FILTER_INDEX_OPERATOR_INRANGE)
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_FILTER_FIELD_END_INDEX, endIndex),
                7, "End Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the trigger type for LIN analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the trigger type for LIN analysis.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerType(ViSession instrSession,
                                                        ViInt32   type)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_TYPE, type),
            2, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures error types for the trigger.
/// HIFN
/// HIFN     Available, if RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_TYPE is set to Error
/// HIFN  Condition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR parityError/Triggers if an error occurs in the identifier parity bits. These are
/// HIPAR parityError/the bits 6 and 7 of the identifier.
/// HIPAR syncError/Triggers if a synchronization error occurs.
/// HIPAR checksumError/Triggers on checksum errors.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerErrorTypes(
                            ViSession instrSession,
                            ViBoolean parityError,
                            ViBoolean syncError,
                            ViBoolean checksumError)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_PARITY_ERROR_ENABLED, parityError),
            2, "Parity Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_SYNC_ERROR_ENABLED, syncError),
            3, "Sync Error");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_CHECKSUM_ERROR_ENABLED, checksumError),
            4, "Checksum Error");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator to set a specific data pattern or a data pattern
/// HIFN  range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR operatorType/Sets the operator to set a specific data pattern or a data pattern
/// HIPAR operatorType/range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerDataOperator(
                            ViSession instrSession,
                            ViInt32   operatorType)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_DATA_OPERATOR, operatorType),
            2, "Operator Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies a data pattern, or sets the start value of a data pattern
/// HIFN  range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataPattern/Specifies a data pattern, or sets the start value of a data pattern
/// HIPAR dataPattern/range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerDataPattern(
                            ViSession instrSession,
                            ViString  dataPattern)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_DATA_PATTERN, dataPattern),
            2, "Data Pattern");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number of data events that are ignored, before trigger
/// HIFN  condition check of the data starts.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataPosition/Sets the number of data events that are ignored, before trigger
/// HIPAR dataPosition/condition check of the data starts.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerDataPosition(
                            ViSession instrSession,
                            ViInt32   dataPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_DATA_POSITION, dataPosition),
            2, "Data Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the operator and values to set a specific identifier or an
/// HIFN  identifier range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR operatorType/Sets the operator to set a specific identifier or an identifier range.
/// HIPAR min/Specifies a secondary identifier pattern, or sets the start value of
/// HIPAR min/an identifier range.
/// HIPAR max/Sets the end value of an identifier range if
/// HIPAR max/RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER is set to In Range or Out Of
/// HIPAR max/Range.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolLINTriggerIdentifier(
                            ViSession instrSession,
                            ViInt32   operatorType,
                            ViString  min,
                            ViString  max)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_IDENTIFIER, operatorType),
            2, "Operator Type");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_FRAME_ID_MIN, min),
            3, "Min");

    if (operatorType >= RSMXO_VAL_PROTOCOL_LIN_TRIGGER_IDENTIFIER_IN_RANGE)
        viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_TRIGGER_FRAME_ID_MAX, max),
                4, "Max");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of decoded frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frameCount/Returns the number of decoded frames.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameCount(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32*  frameCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_COUNT, frameCount),
            3, "Frame Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the overall state of the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR state/Returns the overall state of the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameState(ViSession instrSession,
                                                          ViInt32   serialBus,
                                                          ViInt32   frame,
                                                          ViInt32*  state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the start and stop time of the selected frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR start/Returns the start time of the selected frame.
/// HIPAR end/Returns the stop time of the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameBounds(ViSession instrSession,
                                                           ViInt32   serialBus,
                                                           ViInt32   frame,
                                                           ViReal64* start,
                                                           ViReal64* end)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_START,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_START, start),
            4, "Start");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_END, end),
            5, "End");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data bytes of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR arraySize/Size of output array.
/// HIPAR data/Returns the data bytes of the specified frame.
/// HIPAR valuesReturned/Returns the number of data points read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameData(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   arraySize,
                                                         ViInt32   data[],
                                                         ViInt32*  valuesReturned)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_DATA,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    checkErr(RsCore_GetAttributeViStringAsViInt32ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_DATA, NULL, arraySize, data, valuesReturned));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the primary bit rate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR bitrate/Returns the primary bit rate.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameBitrate(ViSession instrSession,
                                                            ViInt32   serialBus,
                                                            ViInt32   frame,
                                                            ViInt32*  bitrate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BITRATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BITRATE, bitrate),
            4, "Bitrate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the checksum value of the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR checksum/Returns the checksum value of the specified frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameChecksum(ViSession instrSession,
                                                             ViInt32   serialBus,
                                                             ViInt32   frame,
                                                             ViInt32*  checksum)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_CHECKSUM,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_CHECKSUM, checksum),
            4, "Checksum");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the identifier information of the selected frame.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_STATE
/// HIFN     RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_PARITY
/// HIFN     RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     SBUS<sb>:LIN:FRAMe<fr>:IDSTate?
/// HIFN     SBUS<sb>:LIN:FRAMe<fr>:IDPValue?
/// HIFN     SBUS<sb>:LIN:FRAMe<fr>:IDValue?
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR state/Returns the identifier state of the selected frame.
/// HIPAR identifier/Returns the identifier value of the selected frame.
/// HIPAR parity/Returns the value of the identifier parity bits of the selected frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameIdentifier(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32*  state,
                            ViInt32*  identifier,
                            ViInt32*  parity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_STATE, state),
            4, "State");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID, identifier),
            5, "Identifier");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_ID_PARITY, parity),
            6, "Parity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of bytes in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR count/Returns the number of bytes in the specified frame.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByteCount(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_COUNT,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_COUNT, count),
            5, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the state and value of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR state/Returns the state of the specified byte.
/// HIPAR value/Returns the value of the specified byte.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByte(ViSession instrSession,
                                                         ViInt32   serialBus,
                                                         ViInt32   frame,
                                                         ViInt32   byteNumber,
                                                         ViInt32*  state,
                                                         ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_STATE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_STATE, state),
            5, "State");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_VALUE, value),
            6, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the formatted value of the specified byte.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR bufferSize/Size of output array.
/// HIPAR formattedValue/Returns the formatted value of the specified byte.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByteFormattedValue(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViInt32   bufferSize,
                            ViChar    formattedValue[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_FORMATTED_VALUE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    checkErr(RsCore_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_FORMATTED_VALUE, RS_VAL_DIRECT_USER_CALL, bufferSize, formattedValue, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the label of the bytes in the specified frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR frame/Sets the repeated capability Frame.
/// HIPAR byte/Sets the repeated capability Byte.
/// HIPAR bufferSize/Size of output array.
/// HIPAR label/Returns the label of the bytes in the specified frame.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryProtocolLINResultsFrameByteLabel(
                            ViSession instrSession,
                            ViInt32   serialBus,
                            ViInt32   frame,
                            ViInt32   byteNumber,
                            ViInt32   bufferSize,
                            ViChar    label[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, repCapCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_LABEL,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_FRAME, frame),
            3, "Frame");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_PROTOCOL_LIN_SELECTED_BYTE, byteNumber),
            4, "Byte Number");

    checkErr(RsCore_GetAttributeViStringWithRealLen(instrSession, repCap, RSMXO_ATTR_PROTOCOL_LIN_RESULTS_FRAME_BYTE_LABEL, RS_VAL_DIRECT_USER_CALL, bufferSize, label, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures export settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR includeTiming/If enabled, includes the frame timing in the export result file.
/// HIPAR includeDetails/If enabled, includes the detailed results for all frames in the export
/// HIPAR includeDetails/result file.
ViStatus _VI_FUNC rsmxo_ConfigureProtocolExport(ViSession instrSession,
                                                ViInt32   serialBus,
                                                ViBoolean includeTiming,
                                                ViBoolean includeDetails)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_EXPORT_INCLUDE_TIMING,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_EXPORT_INCLUDE_TIMING, includeTiming),
            3, "Include Timing");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_PROTOCOL_EXPORT_INCLUDE_DETAILS, includeDetails),
            4, "Include Details");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the selected results to the indicated file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serialBus/Selects repeated capability SerialBus.
/// HIPAR fileName/Saves the selected results to the indicated file.
ViStatus _VI_FUNC rsmxo_SaveProtocolExportFile(ViSession instrSession,
                                               ViInt32   serialBus,
                                               ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  serialBusCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SerialBus", &serialBusCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, serialBus, 1, serialBusCount),
            2, "Serial Bus");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_PROTOCOL_EXPORT_SAVE,
            "SerialBus", serialBus - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Serial Bus");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_PROTOCOL_EXPORT_SAVE, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the selected parallel bus. The corresponding signal icon
/// HIFN  appears on the signal bar.
/// HIFN
/// HIFN     Dependencies: At least one digital channel must be enabled for the
/// HIFN  selected bus, otherwise the command does not work.
/// HIFN
/// HIFN     The bus is enabled automatically if the first digital channel is
/// HIFN  enabled with RSMXO_ATTR_LOGIC_BIT_STATE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR state/Enables the selected parallel bus. The corresponding signal icon
/// HIPAR state/appears on the signal bar.
ViStatus _VI_FUNC rsmxo_EnableLogic(ViSession instrSession,
                                    ViInt32   logic,
                                    ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_STATE,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_LOGIC_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the logic settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR showDigitalSignals/If enabled, the selected digital channels are shown in the diagram.
/// HIPAR showDigitalSignals/Each channel is displayed as a logic signal.
/// HIPAR technology/Selects the threshold voltage for various types of integrated circuits
/// HIPAR technology/and applies it to all digital channels.
/// HIPAR levelCoupling/Sets the threshold and the hysteresis for all digital channels and all
/// HIPAR levelCoupling/buses to the same value.
ViStatus _VI_FUNC rsmxo_ConfigureLogicSettings(ViSession instrSession,
                                               ViInt32   logic,
                                               ViBoolean showDigitalSignals,
                                               ViInt32   technology,
                                               ViBoolean levelCoupling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_SHOW_DIGITAL_SIGNALS,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_LOGIC_SHOW_DIGITAL_SIGNALS, showDigitalSignals),
            3, "Show Digital Signals");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_LOGIC_TECHNOLOGY, technology),
            4, "Technology");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_LOGIC_LEVEL_COUPLING, levelCoupling),
            5, "Level Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a general delay for all digital channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR skew/Sets a general delay for all digital channels.
ViStatus _VI_FUNC rsmxo_ConfigureLogicSkew(ViSession instrSession,
                                           ViInt32   logic,
                                           ViReal64  skew)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_SKEW,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_SKEW, skew),
            3, "Skew");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Removes all assigned digital channels from the bus
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
ViStatus _VI_FUNC rsmxo_LogicClear(ViSession instrSession,
                                   ViInt32   logic)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_CLEAR,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_LOGIC_CLEAR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the logical threshold for the indicated channel group.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR channelGroup/Selects repeated capability ChannelGroup.
/// HIPAR threshold/Sets the logical threshold for the indicated channel group.
ViStatus _VI_FUNC rsmxo_ConfigureLogicChannelGroupThreshold(ViSession instrSession,
                                                            ViInt32   logic,
                                                            ViInt32   channelGroup,
                                                            ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;
    ViInt32  channelGroupCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_CHANNEL_GROUP_THRESHOLD,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ChannelGroup", &channelGroupCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelGroup, 1, channelGroupCount),
            3, "Channel Group");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_CHANNEL_GROUP_THRESHOLD, "ChannelGroup", channelGroup - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel Group");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_CHANNEL_GROUP_THRESHOLD, threshold),
            4, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the size of the hysteresis for the respective channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR channelGroup/Selects repeated capability ChannelGroup.
/// HIPAR hysteresis/Defines the size of the hysteresis for the respective channels.
ViStatus _VI_FUNC rsmxo_ConfigureLogicChannelGroupHysteresis(ViSession instrSession,
                                                             ViInt32   logic,
                                                             ViInt32   channelGroup,
                                                             ViInt32   hysteresis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCapChannel[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;
    ViInt32  channelGroupCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_CHANNEL_GROUP_HYSTERESIS,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ChannelGroup", &channelGroupCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelGroup, 1, channelGroupCount),
            3, "Channel Group");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_CHANNEL_GROUP_HYSTERESIS, "ChannelGroup", channelGroup - 1, RS_REPCAP_BUF_SIZE, repCapChannel),
                3, "Channel Group");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapChannel, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_LOGIC_CHANNEL_GROUP_HYSTERESIS, hysteresis),
            4, "Hysteresis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures an individual digital channel iside the bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR bit/Selects repeated capability BusWordBit.
/// HIPAR state/Enables the selected parallel bus. The corresponding signal icon
/// HIPAR state/appears on the signal bar.
/// HIPAR label/Sets a name for the indicated digital channel. The name is displayed
/// HIPAR label/in the diagram.
/// HIPAR skew/Sets an individual delay for each digital channel to time-align it
/// HIPAR skew/with other digital channels.The skew value compensates delays that are
/// HIPAR skew/known from the circuit specifics or caused by the different length of
/// HIPAR skew/cables. The skew between the probe boxes of the digital channels and
/// HIPAR skew/the probe connectors of the analog channels is automatically aligned by
/// HIPAR skew/the instrument.
ViStatus _VI_FUNC rsmxo_ConfigureLogicBitSettings(ViSession instrSession,
                                                  ViInt32   logic,
                                                  ViInt32   bit,
                                                  ViBoolean state,
                                                  ViString  label,
                                                  ViReal64  skew)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCapBit[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;
    ViInt32  bitCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_BIT_STATE,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "BusWordBit", &bitCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bit, 0, bitCount),
            3, "Bit");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_BIT_STATE, "BusWordBit", bit, RS_REPCAP_BUF_SIZE, repCapBit),
                3, "Bit");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapBit, NULL));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_LOGIC_BIT_STATE, state),
            4, "State");

    if (state)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_LOGIC_BIT_LABEL, label),
                5, "Label");

        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_BIT_SKEW, skew),
                6, "Skew");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the position of the indicated logic group waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR position/Sets the position of the indicated logic group waveform.
ViStatus _VI_FUNC rsmxo_ConfigureLogicPosition(ViSession instrSession,
                                               ViInt32   logic,
                                               ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_POSITION,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_POSITION, position),
            3, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the size of the display that is used by the indicated logic group
/// HIFN  waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR sizeOfTheDisplay/Sets the size of the display that is used by the indicated logic group
/// HIPAR sizeOfTheDisplay/waveform.
ViStatus _VI_FUNC rsmxo_ConfigureLogicSizeOfTheDisplay(ViSession instrSession,
                                                       ViInt32   logic,
                                                       ViReal64  sizeOfTheDisplay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_SIZE_OF_THE_DISPLAY,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_SIZE_OF_THE_DISPLAY, sizeOfTheDisplay),
            3, "Size of the Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical position of all active digital channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR position/Sets the vertical position of all active digital channels.
ViStatus _VI_FUNC rsmxo_ConfigureLogicDigitalChannelVerticalPosition(
                            ViSession instrSession,
                            ViInt32   logic,
                            ViReal64  position)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_DIGITAL_CHANNEL_VERTICAL_POSITION,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_DIGITAL_CHANNEL_VERTICAL_POSITION, position),
            3, "Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the size of the display that is used by each active digital
/// HIFN  signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR sizeOfTheDisplay/Sets the size of the display that is used by each active digital
/// HIPAR sizeOfTheDisplay/signal.
ViStatus _VI_FUNC rsmxo_ConfigureLogicDigitalChannelSizeOfTheDisplay(
                            ViSession instrSession,
                            ViInt32   logic,
                            ViReal64  sizeOfTheDisplay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_DIGITAL_CHANNEL_SIZE_OF_THE_DISPLAY,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_LOGIC_DIGITAL_CHANNEL_SIZE_OF_THE_DISPLAY, sizeOfTheDisplay),
            3, "Size of the Display");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the resulting bus signal and bus values are displayed in
/// HIFN  the diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR showBus/If enabled, the resulting bus signal and bus values are displayed in
/// HIPAR showBus/the diagram.
ViStatus _VI_FUNC rsmxo_ConfigureLogicBusShow(ViSession instrSession,
                                              ViInt32   logic,
                                              ViBoolean showBus)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_BUS_SHOW,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_LOGIC_BUS_SHOW, showBus),
            3, "Show Bus");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the data format of bus values, which are displayed in the decode
/// HIFN  table and on the comb bus display.
/// HIFN
/// HIFN     It also sets the format for the number representation for remote data
/// HIFN  transfer with RSMXO_ATTR_LOGIC_BUS_DATA_VALUE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR dataFormat/Sets the data format of bus values, which are displayed in the decode
/// HIPAR dataFormat/table and on the comb bus display.
ViStatus _VI_FUNC rsmxo_ConfigureLogicBusDataFormat(ViSession instrSession,
                                                    ViInt32   logic,
                                                    ViInt32   dataFormat)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_BUS_DATA_FORMAT,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_LOGIC_BUS_DATA_FORMAT, dataFormat),
            3, "Data Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures a clocked bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability ClockedLogic.
/// HIPAR busClocked/Defines if the bus is a clocked bus - one of the digital channels
/// HIPAR busClocked/serves as clock of the bus.
/// HIPAR clockSource/Selects the digital channel used as clock.
/// HIPAR clockSlope/Selects the slope of the clock signal at which all digital channels of
/// HIPAR clockSlope/the bus are analyzed.
ViStatus _VI_FUNC rsmxo_ConfigureLogicBusClocked(ViSession instrSession,
                                                 ViInt32   logic,
                                                 ViBoolean busClocked,
                                                 ViInt32   clockSource,
                                                 ViInt32   clockSlope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_BUS_CLOCKED_ENABLED,
            "ClockedLogic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_LOGIC_BUS_CLOCKED_ENABLED, busClocked),
            3, "Bus Clocked");

    if (busClocked)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_LOGIC_BUS_CLOCKED_SOURCE, clockSource),
                4, "Clock Source");

        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_LOGIC_BUS_CLOCKED_SLOPE, clockSlope),
                5, "Clock Slope");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the indicated digital channel, displays it, and
/// HIFN  enables the parallel Logic 1 if the bus was disabled.
/// HIFN
/// HIFN     If another active bus already uses the selected digital channel, the
/// HIFN  instrument disables the other bus to avoid conflicts.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR state/Enables or disables the indicated digital channel, displays it, and
/// HIPAR state/enables the parallel Logic 1 if the bus was disabled.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelState(ViSession instrSession,
                                                     ViInt32   digitalChannel,
                                                     ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_STATE,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the threshold voltage for various types of integrated circuits
/// HIFN  and applies it to all digital channels.
/// HIFN
/// HIFN     The setting affects only the settings of the first MSO bus (Logic1).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR technology/Selects the threshold voltage for various types of integrated circuits
/// HIPAR technology/and applies it to all digital channels.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelTechnology(ViSession instrSession,
                                                          ViInt32   digitalChannel,
                                                          ViInt32   technology)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_TECHNOLOGY,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_TECHNOLOGY, technology),
            3, "Technology");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets an individual delay for each digital channel to time-align it
/// HIFN  with other digital channels. The skew value compensates delays that are
/// HIFN  known from the circuit specifics or caused by the different length of
/// HIFN  cables.
/// HIFN
/// HIFN     The setting affects only the settings of the first MSO bus (Logic1).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR skew/Sets an individual delay for each digital channel to time-align it
/// HIPAR skew/with other digital channels. The skew value compensates delays that are
/// HIPAR skew/known from the circuit specifics or caused by the different length of
/// HIPAR skew/cables.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelSkew(ViSession instrSession,
                                                    ViInt32   digitalChannel,
                                                    ViReal64  skew)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_SKEW,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_SKEW, skew),
            3, "Skew");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a name for the indicated digital channel. The name is displayed
/// HIFN  in the diagram.
/// HIFN
/// HIFN     The setting affects only the settings of the first MSO bus (Logic1).
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR label/Sets a name for the indicated digital channel. The name is displayed
/// HIPAR label/in the diagram.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelLabel(ViSession instrSession,
                                                     ViInt32   digitalChannel,
                                                     ViString  label)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_LABEL,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_LABEL, label),
            3, "Label");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets digital channel size.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR size/Sets digital channel size.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelSize(ViSession instrSession,
                                                    ViInt32   digitalChannel,
                                                    ViReal64  size)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_SIZE,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_SIZE, size),
            3, "Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the threshold and the hysteresis for all digital channels of
/// HIFN  Logic1 to the same value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR thCoupling/Sets the threshold and the hysteresis for all digital channels of
/// HIPAR thCoupling/Logic1 to the same value.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelTHCoupling(ViSession instrSession,
                                                          ViInt32   digitalChannel,
                                                          ViBoolean thCoupling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_TH_COUPLING,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_TH_COUPLING, thCoupling),
            3, "TH Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the logical threshold for the channel group to which the
/// HIFN  indicated digital channel belongs.
/// HIFN
/// HIFN     The setting affects only the settings of the first MSO bus (Logic1).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR threshold/Sets the logical threshold for the channel group to which the
/// HIPAR threshold/indicated digital channel belongs.
ViStatus _VI_FUNC rsmxo_ConfigureDigitalChannelThreshold(ViSession instrSession,
                                                         ViInt32   digitalChannel,
                                                         ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_CHANNEL_THRESHOLD,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_DIGITAL_CHANNEL_THRESHOLD, threshold),
            3, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Autoscale of the Frequency Analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoscale/Autoscale of the Frequency Analysis.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAutoscale(
                            ViSession instrSession,
                            ViBoolean autoscale)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AUTOSCALE, autoscale),
            2, "Autoscale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Runs a calibration sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_FrequencyResponseAnalysisCalibrationStart(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_START, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the result of the calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR result/Returns the result of the calibration.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisCalibrationResult(
                            ViSession instrSession,
                            ViInt32*  result)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_RESULT, result),
            2, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the state of calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationState/Sets the state of calibration.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisCalibrationState(
                            ViSession instrSession,
                            ViBoolean calibrationState)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_CALIBRATION_STATE, calibrationState),
            2, "Calibration State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables Frequency Response Analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frequencyResponseAnalysis/Enables or disables Frequency Response Analysis.
ViStatus _VI_FUNC rsmxo_EnableFrequencyResponseAnalysis(ViSession instrSession,
                                                        ViBoolean frequencyResponseAnalysis)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_ENABLED, frequencyResponseAnalysis),
            2, "Frequency Response Analysis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the frequency response analysis settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR input/Sets the channel for the input signal of the DUT.
/// HIPAR output/Sets the channel for the output signal of the DUT.
/// HIPAR generator/Selects the built-in generator to start a frequency sweep for a
/// HIPAR generator/defined frequency range.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisSettings(
                            ViSession instrSession,
                            ViInt32   input,
                            ViInt32   output,
                            ViInt32   generator)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_INPUT, input),
            2, "Input");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_OUTPUT, output),
            3, "Output");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GENERATOR, generator),
            4, "Generator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the start and end frequency of the sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR start/Sets the start frequency of the sweep.
/// HIPAR stop/Sets the stop frequency of the sweep.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisSweepBounds(
                            ViSession instrSession,
                            ViReal64  start,
                            ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_START, start),
            2, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_STOP, stop),
            3, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects, if the number of points for the FRA are measured as total or
/// HIFN  per decade.
/// HIFN
/// HIFN     You can set the number of points with
/// HIFN  RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_TOTAL/
/// HIFN  RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_LOGARITHMIC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects, if the number of points for the FRA are measured as total or
/// HIPAR mode/per decade.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPointsMode(
                            ViSession instrSession,
                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Set the total number of points for the FRA analysis, if
/// HIFN  RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE is set to Total.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR points/Set the total number of points for the FRA analysis, if
/// HIPAR points/RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE is set to Total.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPointsTotal(
                            ViSession instrSession,
                            ViInt32   points)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_TOTAL, points),
            2, "Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the number of points that are measured per decade, if
/// HIFN  RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE is set to Decade.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR points/Selects the number of points that are measured per decade, if
/// HIPAR points/RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_MODE is set to Decade.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPointsLogarithmic(
                            ViSession instrSession,
                            ViInt32   points)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_POINTS_LOGARITHMIC, points),
            2, "Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the generator voltage display for 50 or high impedance load.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR userLoad/Selects the generator voltage display for 50 or high impedance load.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisUserLoad(
                            ViSession instrSession,
                            ViInt32   userLoad)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_USER_LOAD, userLoad),
            2, "User Load");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects, if the amplitude is a constant value
/// HIFN  (RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE) or is defined as an
/// HIFN  amplitude profile.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects, if the amplitude is a constant value
/// HIPAR mode/(RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE) or is defined as an
/// HIPAR mode/amplitude profile.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeMode(
                            ViSession instrSession,
                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a fixed amplitude for the frequency response analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR amplitude/Sets a fixed amplitude for the frequency response analysis.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitude(
                            ViSession instrSession,
                            ViReal64  amplitude)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE, amplitude),
            2, "Amplitude");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Repeats the measurement, using the same parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR repeat/Repeats the measurement, using the same parameters.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisRepeat(
                            ViSession instrSession,
                            ViBoolean repeat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_REPEAT, repeat),
            2, "Repeat");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the frequency response analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ResetFrequencyResponseAnalysis(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts the frequency response analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR action/Starts the frequency response analysis.
ViStatus _VI_FUNC rsmxo_RunFrequencyResponseAnalysis(ViSession instrSession,
                                                     ViInt32   action)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_RUN, action),
            2, "Action");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the display of the measurement points for the frequency
/// HIFN  response analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayPoints/Enables the display of the measurement points for the frequency
/// HIPAR displayPoints/response analysis.
/// HIPAR resultsTable/Enables the display of the result table for the FRA.
/// HIPAR markers/Enables the display of the marker table for the FRA.
/// HIPAR margin/Enables the display of the margin table for the FRA.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisDisplaySettings(
                            ViSession instrSession,
                            ViBoolean displayPoints,
                            ViBoolean resultsTable,
                            ViBoolean markers,
                            ViBoolean margin)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_POINTS, displayPoints),
            2, "Display Points");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_RESULT_TABLE, resultsTable),
            3, "Results Table");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_MARKERS, markers),
            4, "Markers");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DISPLAY_MARGIN, margin),
            5, "Margin");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the upper boundary of the vertical phase window.The lower
/// HIFN  boundary is given by Maximum phase - 360.By default, the Maximum phase
/// HIFN  is set to 180 for a phase window ranging from -180 to 180 accordingly.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR maximumPhase/Sets the upper boundary of the vertical phase window.The lower
/// HIPAR maximumPhase/boundary is given by Maximum phase - 360.By default, the Maximum phase
/// HIPAR maximumPhase/is set to 180 for a phase window ranging from -180 to 180 accordingly.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisMaximumPhase(
                            ViSession instrSession,
                            ViReal64  maximumPhase)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MAXIMUM_PHASE, maximumPhase),
            2, "Maximum Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures measurement delay settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Enables the measurement delay. Set a measurement delay time with
/// HIPAR enabled/RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DELAY_TIME.
/// HIPAR delayTime/Sets a time delay, that the system waits before measuring the next
/// HIPAR delayTime/point of the plot. This is helpful in systems that need more time to
/// HIPAR delayTime/adapt to the new frequency, for example if filters with significant
/// HIPAR delayTime/time group delays are present.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisMeasurementDelay(
                            ViSession instrSession,
                            ViBoolean enabled,
                            ViReal64  delayTime)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MEASUREMENT_DELAY_ENABLED, enabled),
            2, "Enabled");

    if (enabled)
        viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_DELAY_TIME, delayTime),
                3, "Delay Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the resolution bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR rbw/Sets the resolution bandwidth.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisRBW(
                            ViSession instrSession,
                            ViInt32   rbw)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_RBW, rbw),
            2, "RBW");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the amplitude profile point frequency and amplitude values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR profilePoint/Sets the repeated capability value for Amplitude Point.
/// HIPAR frequency/Set the frequency and amplitude values for the selected point.
/// HIPAR amplitude/Set the amplitude value for the selected point.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeProfilePoint(
                            ViSession instrSession,
                            ViInt32   profilePoint,
                            ViReal64  frequency,
                            ViReal64  amplitude)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SELECTED_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_POINT, profilePoint),
            2, "Profile Point");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_FREQUENCY, frequency),
            3, "Frequency");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_AMPLITUDE, amplitude),
            4, "Amplitude");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of defined points for the amplitude profile.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR profilePointCount/Returns the number of defined points for the amplitude profile.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisAmplitudeProfilePointCount(
                            ViSession instrSession,
                            ViInt32*  profilePointCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_POINT_COUNT, profilePointCount),
            2, "Profile Point Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects if the voltage change is done as a single step or as a ramp.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR voltageChange/Selects if the voltage change is done as a single step or as a ramp.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeProfileVoltageChange(
                            ViSession instrSession,
                            ViInt32   voltageChange)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_VOLTAGE_CHANGE, voltageChange),
            2, "Voltage Change");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sorts the points in the amplitude table by frequency, starting with
/// HIFN  the lowest frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_SortFrequencyResponseAnalysisAmplitudeProfile(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_SORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Adds a new point to the amplitude profile.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_AddFrequencyResponseAnalysisAmplitudeProfilePoint(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_ADD, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Removes the selected amplitude point from the list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_DeleteFrequencyResponseAnalysisAmplitudeProfilePoint(
                            ViSession instrSession,
                            ViInt32   profilePoint)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SELECTED_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_POINT, profilePoint),
            2, "Profile Point");

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_PROFILE_DELETE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the gain waveform for the frequency response analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gain/Enables the gain waveform for the frequency response analysis.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisGainEnabled(
                            ViSession instrSession,
                            ViBoolean gain)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_ENABLED, gain),
            2, "Gain");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical scale and offset for the gain waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalScale/Sets the vertical scale for the gain waveform.
/// HIPAR verticalOffset/Sets a vertical offset of the gain waveform.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisGainVerticalSettings(
                            ViSession instrSession,
                            ViReal64  verticalScale,
                            ViReal64  verticalOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_VERTICAL_SCALE, verticalScale),
            2, "Vertical Scale");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_VERTICAL_OFFSET, verticalOffset),
            3, "Vertical Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the phase waveform for the frequency response analysis.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR phase/Enables the phase waveform for the frequency response analysis.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPhaseEnabled(
                            ViSession instrSession,
                            ViBoolean phase)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_ENABLED, phase),
            2, "Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical scale and offset for the phase waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalScale/Sets the vertical scale for the phase waveform.
/// HIPAR verticalOffset/Sets a vertical offset of the phase waveform.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisPhaseSettings(
                            ViSession instrSession,
                            ViReal64  verticalScale,
                            ViReal64  verticalOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_VERTICAL_SCALE, verticalScale),
            2, "Vertical Scale");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_VERTICAL_OFFSET, verticalOffset),
            3, "Vertical Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables the amplitude signal for the frequency response analysis. You
/// HIFN  can then define the amplitude profile of the signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR amplitude/Enables the amplitude signal for the frequency response analysis. You
/// HIPAR amplitude/can then define the amplitude profile of the signal.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeEnabled(
                            ViSession instrSession,
                            ViBoolean amplitude)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_ENABLED, amplitude),
            2, "Amplitude");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical scale and offset for the amplitude waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR verticalScale/Sets the vertical scale for the amplitude waveform.
/// HIPAR verticalOffset/Sets a vertical offset of the amplitude waveform.
ViStatus _VI_FUNC rsmxo_ConfigureFrequencyResponseAnalysisAmplitudeSettings(
                            ViSession instrSession,
                            ViReal64  verticalScale,
                            ViReal64  verticalOffset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_VERTICAL_SCALE, verticalScale),
            2, "Vertical Scale");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_AMPLITUDE_VERTICAL_OFFSET, verticalOffset),
            3, "Vertical Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the frequency and value of the gain margin.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frequency/Returns the frequency of the gain margin.
/// HIPAR value/Returns the value of the gain margin.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisGainMargin(
                            ViSession instrSession,
                            ViReal64* frequency,
                            ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_MARGIN_FREQUENCY, frequency),
            2, "Frequency");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_MARGIN_VALUE, value),
            3, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the frequency and value of the phase margin.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frequency/Returns the frequency of the phase margin.
/// HIPAR value/Returns the value of the phase margin.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisPhaseMargin(
                            ViSession instrSession,
                            ViReal64* frequency,
                            ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_MARGIN_FREQUENCY, frequency),
            2, "Frequency");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_MARGIN_VALUE, value),
            3, "Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data of the gain waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR data/Returns the data of the gain waveform.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisGainData(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_GAIN_DATA, bufferSize, data, bytesRead),
                3, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data of the phase waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR data/Returns the data of the phase waveform.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisPhaseData(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_PHASE_DATA, bufferSize, data, bytesRead),
                3, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the data of the frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR data/Returns the data of the frequency.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisFrequencyData(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    data[],
                            ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_FREQUENCY_DATA, bufferSize, data, bytesRead),
                3, "Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the frequency, gain and phase values for the specified marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/Selects repeated capability FRAMarker.
/// HIPAR frequency/Returns the frequency for the specified marker.
/// HIPAR gain/Returns the gain for the specified marker.
/// HIPAR phase/Returns the phase value for the specified marker.
ViStatus _VI_FUNC rsmxo_QueryFrequencyResponseAnalysisMarkerResults(
                            ViSession instrSession,
                            ViInt32   marker,
                            ViReal64* frequency,
                            ViReal64* gain,
                            ViReal64* phase)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  markersCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &markersCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, markersCount),
            2, "Marker");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_FREQUENCY,
            "FRAMarker", marker - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Marker");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_FREQUENCY, frequency),
            3, "Frequency");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_GAIN, gain),
            4, "Gain");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_FREQUENCY_RESPONSE_ANALYSIS_MARKER_PHASE, phase),
            5, "Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures a reference waveform setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR show/Enables the display of the reference waveform in the diagram.
/// HIPAR source/Selects the source waveform from the active waveforms of input
/// HIPAR source/channels, math signals and other reference waveforms.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformSetup(ViSession instrSession,
                                                        ViInt32   referenceWaveform,
                                                        ViBoolean show,
                                                        ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_SHOW,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_SHOW, show),
            3, "Show");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_SOURCE, source),
            4, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies the selected source waveform with all its settings to the
/// HIFN  memory of the reference waveform. If the acquisition is running, the
/// HIFN  reference waveform is a snapshot.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_CreateUpdateReferenceWaveform(ViSession instrSession,
                                                      ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_CREATE_UPDATE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_CREATE_UPDATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  The selected reference waveform disappears, its memory is deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_ClearReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_CLEAR,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_CLEAR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the time scale and the reference point to the original values
/// HIFN  of the reference waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_ResetReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_RESET,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Aborts a running reference waveform export, which was started with
/// HIFN  RSMXO_ATTR_REFERENCE_WAVEFORM_SAVE, or a running reference waveform
/// HIFN  update, which was started with
/// HIFN  RSMXO_ATTR_REFERENCE_WAVEFORM_CREATE_UPDATE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_AbortReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, repCapCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_ABORT,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the name of the reference waveform file to be loaded, saved or
/// HIFN  deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR fileName/Defines the name of the reference waveform file to be loaded, saved or
/// HIPAR fileName/deleted.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformName(ViSession instrSession,
                                                       ViInt32   referenceWaveform,
                                                       ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_NAME,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_NAME, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the reference waveform to the file selected by
/// HIFN  RSMXO_ATTR_REFERENCE_WAVEFORM_NAME.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_SaveReferenceWaveform(ViSession instrSession,
                                              ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_SAVE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_SAVE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the reference waveform file selected by
/// HIFN  RSMXO_ATTR_REFERENCE_WAVEFORM_NAME.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_OpenReferenceWaveform(ViSession instrSession,
                                              ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_OPEN,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_OPEN, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the coupling of vertical settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR mode/Selects the coupling of vertical settings.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalMode(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_MODE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical scale in Volts per division. The vertical scale
/// HIFN  defines the displayed amplitude of the selected waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR verticalScale/Sets the vertical scale in Volts per division. The vertical scale
/// HIPAR verticalScale/defines the displayed amplitude of the selected waveform.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalScale(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViReal64  verticalScale)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE, verticalScale),
            3, "Vertical Scale");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Available, if RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_MODE is set to
/// HIFN  INDependent.
/// HIFN
/// HIFN     Moves the reference waveform up or down in the diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR verticalPosition/Available, if RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_MODE is set to
/// HIPAR verticalPosition/INDependent.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalPosition(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViReal64  verticalPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION, verticalPosition),
            3, "Vertical Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  The vertical offset moves the reference waveform vertically. Enter a
/// HIFN  value with the unit of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR verticalOffset/The vertical offset moves the reference waveform vertically. Enter a
/// HIPAR verticalOffset/value with the unit of the waveform.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformVerticalOffset(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViReal64  verticalOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_OFFSET,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_OFFSET, verticalOffset),
            3, "Vertical Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Available, if RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_MODE is set to
/// HIFN  INDependent.
/// HIFN
/// HIFN     Restores the original vertical settings of the reference waveform
/// HIFN  (vertical scale, position, and offset).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
ViStatus _VI_FUNC rsmxo_SetVerticalSettingsToOriginal(ViSession instrSession,
                                                      ViInt32   referenceWaveform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_RESET,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_VERTICAL_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures reference waveform vertical rescaling.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR enabled/If enabled, the vertical offset and factor are applied to the
/// HIPAR enabled/reference waveform.
/// HIPAR scaleFactor/Sets the vertical scale factor. A factor greater than 1 stretches the
/// HIPAR scaleFactor/waveform vertically, a factor lower than 1 compresses the curve.
/// HIPAR offset/The vertical offset moves the reference waveform vertically. Enter a
/// HIPAR offset/value with the unit of the waveform.Like vertical offset of a channel
/// HIPAR offset/waveform, the offset of a reference waveform is subtracted from the
/// HIPAR offset/measured value. Negative values shift the waveform up, positive values
/// HIPAR offset/shift it down.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformRescaleVertical(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViBoolean enabled,
                            ViReal64  scaleFactor,
                            ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_ENABLED,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_SCALE_FACTOR, scaleFactor),
            4, "Scale Factor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_VERTICAL_OFFSET, offset),
            5, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the coupling of horizontal settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR mode/Selects the coupling of horizontal settings.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformRescaleHorizontalMode(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_MODE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures horizontal rescaling.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR enable/If enabled, the horizontal offset and factor are applied to the
/// HIPAR enable/reference waveform.
/// HIPAR scaleFactor/Sets the horizontal scale factor. A factor greater than 1 stretches
/// HIPAR scaleFactor/the waveform horizontally, a factor lower than 1 compresses the curve.
/// HIPAR offset/Moves the waveform horizontally. Enter a value with a time unit
/// HIPAR offset/suitable for the time scale of the diagram.Positive values shift the
/// HIPAR offset/waveform to the right, negative values shift it to the left.
ViStatus _VI_FUNC rsmxo_ConfigureReferenceWaveformRescaleHorizontal(
                            ViSession instrSession,
                            ViInt32   referenceWaveform,
                            ViBoolean enable,
                            ViReal64  scaleFactor,
                            ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_ENABLE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_ENABLE, enable),
            3, "Enable");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_SCALE_FACTOR, scaleFactor),
            4, "Scale Factor");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_RESCALE_HORIZONTAL_OFFSET, offset),
            5, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the header of track data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchMeasurementTrackDataHeader(ViSession instrSession,
                                                        ViInt32   measurement,
                                                        ViReal64* xStart,
                                                        ViReal64* xStop,
                                                        ViInt32*  recordLength,
                                                        ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;
    ViReal64 measurementHeader[4] = {0, 0, 0, 0};
    ViInt32  numberOfReurnedValues = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MEASUREMENT_TRACK_DATA_HEADER,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_MEASUREMENT_TRACK_DATA_HEADER, NULL, 4, measurementHeader, &numberOfReurnedValues));

    if (numberOfReurnedValues == 4)
    {
        if (xStart != NULL)
            *xStart = measurementHeader[0];
        if (xStop != NULL)
            *xStop = measurementHeader[1];
        if (recordLength != NULL)
            *recordLength = (ViInt32)floor(measurementHeader[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        if (valuesPerSample != NULL)
            *valuesPerSample = measurementHeader[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the data of the indicated track waveform for transmission from
/// HIFN  the instrument to the controlling computer. The data can be used in
/// HIFN  MATLAB, for example.
/// HIFN
/// HIFN     Without parameters, the complete waveform is retrieved. Using the
/// HIFN  offset and length parameters, data can be retrieved in smaller
/// HIFN  portions, which makes the command faster.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchMeasurementTrackData(ViSession instrSession,
                                                  ViInt32   measurement,
                                                  ViInt32   waveformArraySize,
                                                  ViReal64  waveformData[],
                                                  ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;MEAS%ld:TRAC:DATA:VAL?", measurement);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the waveform generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR state/Enables or disables the waveform generator.
ViStatus _VI_FUNC rsmxo_EnableGenerator(ViSession instrSession,
                                        ViInt32   generator,
                                        ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_STATE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Inverts the waveform at the offset level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR inversion/Inverts the waveform at the offset level.
ViStatus _VI_FUNC rsmxo_EnableGeneratorInversion(ViSession instrSession,
                                                 ViInt32   generator,
                                                 ViBoolean inversion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_INVERSION_ENABLED,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_INVERSION_ENABLED, inversion),
            3, "Inversion");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the type of waveform to be generated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR functionType/Selects the type of waveform to be generated.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorFunctionType(ViSession instrSession,
                                                       ViInt32   generator,
                                                       ViInt32   functionType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_FUNCTION_TYPE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_FUNCTION_TYPE, functionType),
            3, "Function Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the frequency of the waveform. The maximum frequency depends on
/// HIFN  the generated function type set by RSMXO_ATTR_GENERATOR_FUNCTION_TYPE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR frequency/Sets the frequency of the waveform. The maximum frequency depends on
/// HIPAR frequency/the generated function type set by RSMXO_ATTR_GENERATOR_FUNCTION_TYPE.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorFrequency(ViSession instrSession,
                                                    ViInt32   generator,
                                                    ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_FREQUENCY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the amplitude of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR amplitude/Sets the amplitude of the waveform.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorAmplitude(ViSession instrSession,
                                                    ViInt32   generator,
                                                    ViReal64  amplitude)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_AMPLITUDE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_AMPLITUDE, amplitude),
            3, "Amplitude");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the vertical offset of the generated waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR offset/Sets the vertical offset of the generated waveform.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorOffset(ViSession instrSession,
                                                 ViInt32   generator,
                                                 ViReal64  offset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_OFFSET,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_OFFSET, offset),
            3, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the symmetry of a ramp waveform, the percentage of time the
/// HIFN  waveform is rising. By changing the symmetry of the ramp, you can
/// HIFN  create, for example, triangular waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR symmetry/Sets the symmetry of a ramp waveform, the percentage of time the
/// HIPAR symmetry/waveform is rising. By changing the symmetry of the ramp, you can
/// HIPAR symmetry/create, for example, triangular waveforms.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSymmetry(ViSession instrSession,
                                                   ViInt32   generator,
                                                   ViReal64  symmetry)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_SYMMETRY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_SYMMETRY, symmetry),
            3, "Symmetry");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the duty cycle for the pulse function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR dutyCycle/Sets the duty cycle for the pulse function.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorDutyCycle(ViSession instrSession,
                                                    ViInt32   generator,
                                                    ViReal64  dutyCycle)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_DUTY_CYCLE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_DUTY_CYCLE, dutyCycle),
            3, "Duty Cycle");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the pulse period for generated signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR period/Sets the pulse period for generated signal.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorPeriod(ViSession instrSession,
                                                 ViInt32   generator,
                                                 ViReal64  period)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_PERIOD,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_PERIOD, period),
            3, "Period");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the pulse width, the pulse duration of the generated pulse
/// HIFN  waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR pulseWidth/Sets the pulse width, the pulse duration of the generated pulse
/// HIPAR pulseWidth/waveform.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorPulseWidth(ViSession instrSession,
                                                     ViInt32   generator,
                                                     ViReal64  pulseWidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_PULSE_WIDTH,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_PULSE_WIDTH, pulseWidth),
            3, "Pulse Width");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the level of the noise in percentage of the set Amplitude output
/// HIFN  of the signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR noiseLevel/Sets the level of the noise in percentage of the set Amplitude output
/// HIPAR noiseLevel/of the signal.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorNoiseLevelInPercent(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  noiseLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_NOISE_LEVEL_IN_PERCENT,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_NOISE_LEVEL_IN_PERCENT, noiseLevel),
            3, "Noise Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries absolute noise level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR absoluteNoiseLevel/Queries absolute noise level.
ViStatus _VI_FUNC rsmxo_QueryGeneratorNoiseLevelAbsolute(ViSession instrSession,
                                                         ViInt32   generator,
                                                         ViReal64* absoluteNoiseLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_NOISE_LEVEL_ABSOLUTE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_GetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_NOISE_LEVEL_ABSOLUTE, absoluteNoiseLevel),
            3, "Absolute Noise Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the DC Level and noise level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR dcLevel/Sets the DC voltage level.
/// HIPAR noiseLevel/Sets the DC noise level.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorDCSettings(ViSession instrSession,
                                                     ViInt32   generator,
                                                     ViReal64  dcLevel,
                                                     ViReal64  noiseLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_DC_LEVEL,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_DC_LEVEL, dcLevel),
            3, "DC Level");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_NOISE_DC_LEVEL, noiseLevel),
            4, "Noise Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the voltage values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR lowVoltage/Sets low voltage value.
/// HIPAR highVoltage/Sets the high voltage value.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorVoltage(ViSession instrSession,
                                                  ViInt32   generator,
                                                  ViReal64  lowVoltage,
                                                  ViReal64  highVoltage)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_LOW_VOLTAGE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_LOW_VOLTAGE, lowVoltage),
            3, "Low Voltage");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_HIGH_VOLTAGE, highVoltage),
            4, "High Voltage");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Select the user load, the load of the DUT at its connection.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR userLoad/Select the user load, the load of the DUT at its connection.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorUserLoad(ViSession instrSession,
                                                   ViInt32   generator,
                                                   ViInt32   userLoad)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_USER_LOAD,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_USER_LOAD, userLoad),
            3, "User Load");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Presets the generator to a default setup. This includes the following
/// HIFN  settings:Function type = SineFrequency = 1 MHzAmplitude = 1 Vpp
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
ViStatus _VI_FUNC rsmxo_GeneratorDefaultSetup(ViSession instrSession,
                                              ViInt32   generator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_DEFAULT_SETUP,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_GENERATOR_DEFAULT_SETUP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies settings from Gen1/Gen2 and applies them to Gen2/Gen1.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
ViStatus _VI_FUNC rsmxo_GeneratorCopySettings(ViSession instrSession,
                                              ViInt32   generator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_COPY_SETTINGS,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_GENERATOR_COPY_SETTINGS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the sweep settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR state/Enables or disables the sweeping.
/// HIPAR type/Sets the type of the sweep, a linear or logarithmic change of the
/// HIPAR type/frequency.
/// HIPAR startFrequency/Sets the start frequency of the sweep signal.
/// HIPAR stopFrequency/Sets the stop frequency of the sweep signal.
/// HIPAR sweepTime/Sets the duration of the sweep.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSweepSettings(ViSession instrSession,
                                                        ViInt32   generator,
                                                        ViBoolean state,
                                                        ViInt32   type,
                                                        ViReal64  startFrequency,
                                                        ViReal64  stopFrequency,
                                                        ViReal64  sweepTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_SWEEP_STATE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_SWEEP_STATE, state),
            3, "State");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_SWEEP_TYPE, type),
            4, "Type");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_SWEEP_START_FREQUENCY, startFrequency),
            5, "Start Frequency");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_SWEEP_STOP_FREQUENCY, stopFrequency),
            6, "Start Frequency");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_SWEEP_TIME, sweepTime),
            7, "Sweep Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stores the current waveform generator settings to the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generatorSave/Stores the current waveform generator settings to the specified file.
ViStatus _VI_FUNC rsmxo_GeneratorSave(ViSession instrSession,
                                      ViString  generatorSave)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_GENERATOR_SAVE, generatorSave),
            2, "Generator Save");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Restores the waveform generator from the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generatorRecall/Restores the waveform generator from the specified file.
ViStatus _VI_FUNC rsmxo_GeneratorRecall(ViSession instrSession,
                                        ViString  generatorRecall)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_GENERATOR_RECALL, generatorRecall),
            2, "Generator Recall");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables or disables modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR modulation/Enables or disables modulation.
ViStatus _VI_FUNC rsmxo_EnableGeneratorModulation(ViSession instrSession,
                                                  ViInt32   generator,
                                                  ViBoolean modulation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  repCapCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &repCapCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, repCapCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_ENABLED,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_ENABLED, modulation),
            3, "Modulation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the modulation setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR type/Selects the modulation type, which defines how the carrier signal is
/// HIPAR type/modified.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationSetup(ViSession instrSession,
                                                          ViInt32   generator,
                                                          ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_TYPE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_TYPE, type),
            3, "Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the modulation carrier period and frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR period/Sets the modulation carrier period.
/// HIPAR frequency/Set the moduation carrier frequency.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationCarrierSettings(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  period,
                            ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_CARRIER_PERIOD,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_CARRIER_PERIOD, period),
            3, "Period");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_CARRIER_FREQUENCY, frequency),
            4, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the type of the modulating signal for AM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR signalType/Selects the type of the modulating signal for AM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMSignalType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signalType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_AM_SIGNAL_TYPE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_AM_SIGNAL_TYPE, signalType),
            3, "Signal Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the duty cycle for a square waveform. The duty cycle expresses
/// HIFN  for what percentage fraction of the period, the waveform is active,
/// HIFN  i.e. the signal state is high.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR dutyCycle/Sets the duty cycle for a square waveform. The duty cycle expresses
/// HIPAR dutyCycle/for what percentage fraction of the period, the waveform is active,
/// HIPAR dutyCycle/i.e. the signal state is high.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_AM_DUTY_CYCLE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_AM_DUTY_CYCLE, dutyCycle),
            3, "Duty Cycle");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the symmetry for the ramp modulation waveform, the percentage of
/// HIFN  time that the waveform is rising.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR symmetry/Sets the symmetry for the ramp modulation waveform, the percentage of
/// HIPAR symmetry/time that the waveform is rising.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_AM_SYMMETRY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_AM_SYMMETRY, symmetry),
            3, "Symmetry");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the frequency of the modulating waveform for AM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR frequency/Sets the frequency of the modulating waveform for AM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_AM_FREQUENCY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_AM_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the modulation depth, the percentage of the amplitude range that
/// HIFN  is used for AM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR depth/Sets the modulation depth, the percentage of the amplitude range that
/// HIPAR depth/is used for AM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationAMDepth(ViSession instrSession,
                                                            ViInt32   generator,
                                                            ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_AM_DEPTH,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_AM_DEPTH, depth),
            3, "Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the type of the modulating signal for PWM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR signalType/Selects the type of the modulating signal for PWM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMSignalType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signalType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_PWM_SIGNAL_TYPE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_PWM_SIGNAL_TYPE, signalType),
            3, "Signal Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the duty cycle for a square waveform. The duty cycle expresses
/// HIFN  for what percentage fraction of the period, the waveform is active,
/// HIFN  i.e. the signal state is high.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR dutyCycle/Sets the duty cycle for a square waveform. The duty cycle expresses
/// HIPAR dutyCycle/for what percentage fraction of the period, the waveform is active,
/// HIPAR dutyCycle/i.e. the signal state is high.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_PWM_DUTY_CYCLE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_PWM_DUTY_CYCLE, dutyCycle),
            3, "Duty Cycle");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the symmetry for the ramp modulation waveform, the percentage of
/// HIFN  time that the waveform is rising.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR symmetry/Sets the symmetry for the ramp modulation waveform, the percentage of
/// HIPAR symmetry/time that the waveform is rising.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_PWM_SYMMETRY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_PWM_SYMMETRY, symmetry),
            3, "Symmetry");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the frequency of the modulating waveform for PWM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR frequency/Sets the frequency of the modulating waveform for PWM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_PWM_FREQUENCY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_PWM_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the modulation depth, the percentage of the amplitude range that
/// HIFN  is used for PWM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR depth/Sets the modulation depth, the percentage of the amplitude range that
/// HIPAR depth/is used for PWM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationPWMDepth(ViSession instrSession,
                                                             ViInt32   generator,
                                                             ViReal64  depth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_PWM_DEPTH,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_PWM_DEPTH, depth),
            3, "Depth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the type of the modulating signal for FM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR signalType/Selects the type of the modulating signal for AM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMSignalType(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32   signalType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_FM_SIGNAL_TYPE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FM_SIGNAL_TYPE, signalType),
            3, "Signal Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the duty cycle for a square waveform. The duty cycle expresses
/// HIFN  for what percentage fraction of the period, the waveform is active,
/// HIFN  i.e. the signal state is high.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR dutyCycle/Sets the duty cycle for a square waveform. The duty cycle expresses
/// HIPAR dutyCycle/for what percentage fraction of the period, the waveform is active,
/// HIPAR dutyCycle/i.e. the signal state is high.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMDutyCycle(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  dutyCycle)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_FM_DUTY_CYCLE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FM_DUTY_CYCLE, dutyCycle),
            3, "Duty Cycle");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the symmetry for the ramp modulation waveform, the percentage of
/// HIFN  time that the waveform is rising.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR symmetry/Sets the symmetry for the ramp modulation waveform, the percentage of
/// HIPAR symmetry/time that the waveform is rising.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMSymmetry(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  symmetry)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_FM_SYMMETRY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FM_SYMMETRY, symmetry),
            3, "Symmetry");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the frequency of the modulating waveform for FM modulation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR frequency/Sets the frequency of the modulating waveform for FM modulation.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMFrequency(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_FM_FREQUENCY,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FM_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the frequency deviation, the maximum difference between the FM
/// HIFN  modulated signal and the carrier signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR deviation/Sets the frequency deviation, the maximum difference between the FM
/// HIPAR deviation/modulated signal and the carrier signal.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFMDeviation(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  deviation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_FM_DEVIATION,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FM_DEVIATION, deviation),
            3, "Deviation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the frequencies and rate of signals in FSK modulated signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR frequency1/Sets the frequency of the first signal in FSK modulated signal.
/// HIPAR frequency2/Sets the frequency of the second signal in FSK modulated signal.
/// HIPAR fskRate/Sets the FSK modulation rate.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorModulationFSKSettings(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  frequency1,
                            ViReal64  frequency2,
                            ViReal64  fskRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_MODULATION_FSK_FREQUENCY_1,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FSK_FREQUENCY_1, frequency1),
            3, "Frequency 1");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FSK_FREQUENCY_2, frequency2),
            4, "Frequency 2");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_MODULATION_FSK_RATE, fskRate),
            5, "FSK Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the source of the arbitrary waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arbitraryWaveformSource/Selects the source of the arbitrary waveform.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitraryWaveformSource(
                            ViSession instrSession,
                            ViInt32   arbitraryWaveformSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_SOURCE, arbitraryWaveformSource),
            2, "Arbitrary Waveform Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines filepath to arbitrary waveform for openning. To open the
/// HIFN  waveform use the RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_OPEN
/// HIFN  attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR name/Defines filepath to arbitrary waveform for openning. To open the
/// HIPAR name/waveform use the RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_OPEN control.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitraryWaveformName(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViString  name)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_NAME,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_NAME, name),
            3, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads the arbitrary waveform, that is selected with the
/// HIFN  RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_NAME command.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
ViStatus _VI_FUNC rsmxo_OpenGeneratorArbitraryWaveform(ViSession instrSession,
                                                       ViInt32   generator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_OPEN,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_OPEN, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the run mode for arbitrary waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR runMode/Selects the run mode for arbitrary waveform.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitraryRunMode(ViSession instrSession,
                                                           ViInt32   generator,
                                                           ViInt32   runMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_ARBITRARY_RUN_MODE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_ARBITRARY_RUN_MODE, runMode),
            3, "Run Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the sample rate for the arbitrary waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR sampleRate/Sets the sample rate for the arbitrary waveform.
ViStatus _VI_FUNC
rsmxo_ConfigureGeneratorArbitrarySampleRate(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  sampleRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_ARBITRARY_SAMPLE_RATE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_ARBITRARY_SAMPLE_RATE, sampleRate),
            3, "Sample Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the number of samples for the arbitrary waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR sampleRate/Sets the sample rate for the arbitrary waveform.
/// HIPAR numberOfSamples/Queries the sample rate for the arbitrary waveform.
ViStatus _VI_FUNC rsmxo_QueryGeneratorArbitraryNumberOfSamples(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  numberOfSamples)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_ARBITRARY_SAMPLE_RATE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_GENERATOR_ARBITRARY_NUMBER_OF_SAMPLES, numberOfSamples),
            3, "Number Of Samples");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the oscilloscope source, from which the arbitrary signal is
/// HIFN  loaded, if RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_SOURCE  is set to
/// HIFN  Scope.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the oscilloscope source, from which the arbitrary signal is
/// HIPAR source/loaded, if RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_SOURCE  is set to
/// HIPAR source/Scope.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorArbitrarySignalSource(
                            ViSession instrSession,
                            ViInt32   source)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_GENERATOR_ARBITRARY_SIGNAL_SOURCE, source),
            2, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Executes a single period of the arbitrary signal generator, if
/// HIFN  RSMXO_ATTR_GENERATOR_ARBITRARY_RUN_MODE is set to
/// HIFN  RSMXO_VAL_GENERATOR_ARBITRARY_RUN_MODE_SINGLE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
ViStatus _VI_FUNC rsmxo_GeneratorArbitraryWaveformRunSingle(ViSession instrSession,
                                                            ViInt32   generator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_RUN_SINGLE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    checkErr(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_GENERATOR_ARBITRARY_WAVEFORM_RUN_SINGLE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets which signals generated from the waveform generator are
/// HIFN  synchronized.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR synchronisationStart/Sets which signals generated from the waveform generator are
/// HIPAR synchronisationStart/synchronized.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSynchronisationStart(
                            ViSession instrSession,
                            ViInt32   synchronisationStart)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_GENERATOR_SYNCHRONISATION_START, synchronisationStart),
            2, "Synchronisation Start");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the phase shift between the waveform of Gen1 and Gen2 when the
/// HIFN  frequency parameters of the two waveforms are coupled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR phaseShift/Sets the phase shift between the waveform of Gen1 and Gen2 when the
/// HIPAR phaseShift/frequency parameters of the two waveforms are coupled.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorSynchronisationPhaseShift(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViReal64  phaseShift)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_SYNCHRONIZE_PHASE_SHIFT,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_GENERATOR_SYNCHRONIZE_PHASE_SHIFT, phaseShift),
            3, "Phase Shift");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR enabled/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR enabled/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorTemperatureEnabled(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_ENABLED,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the transition filter if an warn overload for the 50  terminator
/// HIFN  has occurred.
/// HIFN
/// HIFN     If a bit is
/// HIFN     set, a transition from 1 to 0 in the condition part causes an entry to
/// HIFN  be made in the  corresponding bit of  the EVENt part of the register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR negative/Sets the negative transition filter if an warn overload for the 50
/// HIPAR negative/terminator has occurred.
/// HIPAR positive/Sets the positive transition filter if an warn overload for the 50
/// HIPAR positive/terminator  has occurred.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorTemperatureTransition(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_NEGATIVE_TRANSITION,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENtpart of the channel
/// HIFN  status, to check if a negative/positive temperature value is violated.
/// HIFN
/// HIFN     Reading the CONDition registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if a negative/positive temperature value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if an overload has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterGeneratorTemperature(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  condition,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_CONDITION,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_TEMPERATURE_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR enabled/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR enabled/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorGOverloadEnabled(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_ENABLED,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the transition filter if an warn overload for the 50  terminator
/// HIFN  has occurred.
/// HIFN
/// HIFN     If a bit is
/// HIFN     set, a transition from 1 to 0 in the condition part causes an entry to
/// HIFN  be made in the  corresponding bit of  the EVENt part of the register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR negative/Sets the negative transition filter if an warn overload for the 50
/// HIPAR negative/terminator has occurred.
/// HIPAR positive/Sets the positive transition filter if an warn overload for the 50
/// HIPAR positive/terminator  has occurred.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterGeneratorGOverloadTransition(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_NEGATIVE_TRANSITION,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the channel
/// HIFN  status, to check if a negative/positive temperature value is violated.
/// HIFN
/// HIFN     Reading the CONDition registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if a negative/positive temperature value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if an overload has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterGeneratorGOverload(
                            ViSession instrSession,
                            ViInt32   generator,
                            ViInt32*  condition,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_CONDITION,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_GENERATOR_G_OVERLOAD_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables the coupling of the generators, with the selected set of
/// HIFN  parameters: amplitude, frequency and noise.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generator/Selects repeated capability Generator.
/// HIPAR synchronisation/Enables the coupling of the generators, with the selected set of
/// HIPAR synchronisation/parameters: amplitude, frequency and noise.
ViStatus _VI_FUNC rsmxo_EnableGeneratorCoupling(ViSession instrSession,
                                                ViInt32   generator,
                                                ViBoolean synchronisation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_SYNCHRONISATION_ENABLE,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_SYNCHRONISATION_ENABLE, synchronisation),
            3, "Synchronisation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables the coupling of frequency and amplitude parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR amplitudeParameters/Enables the coupling of all amplitude parameters of the generators.
/// HIPAR frequencyParameters/Enables the coupling of all frequency parameters of the generators.
ViStatus _VI_FUNC rsmxo_ConfigureGeneratorCouplingSettings(ViSession instrSession,
                                                           ViInt32   generator,
                                                           ViBoolean amplitudeParameters,
                                                           ViBoolean frequencyParameters)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  generatorCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Generator", &generatorCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, generator, 1, generatorCount),
            2, "Generator");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_GENERATOR_SYNCHRONISATION_AMPLITUDE_PARAMETERS,
            "Generator", generator - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Generator");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_SYNCHRONISATION_AMPLITUDE_PARAMETERS, amplitudeParameters),
            3, "Amplitude Parameters");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_GENERATOR_SYNCHRONISATION_FREQUENCY_PARAMETERS, frequencyParameters),
            4, "Frequency Parameters");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables inclusion of preview image in the saved set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR includePreviewImage/Enables or disables inclusion of preview image in the saved set.
ViStatus _VI_FUNC rsmxo_IncludeSavesetPreviewImage(ViSession instrSession,
                                                   ViBoolean includePreviewImage)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_SAVESET_INCLUDE_PREVIEW_IMAGE, includePreviewImage),
            2, "Include Preview Image");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the path list of available drives.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR drivesCatalog/Returns the path list of available drives.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryDrivesCatalog(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    drivesCatalog[],
                                           ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_DRIVES_CATALOG, bufferSize, drivesCatalog, bytesRead),
                3, "Drives Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of files and subdirectories of the current or
/// HIFN  specified directory. The number includes the parent directory strings
/// HIFN  '.' and '..' .
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/String parameter to specify the directory. If the directory is omitted,
/// HIPAR it queries directory specified with RSMXO_ATTR_DIRECTORY_DEFAULT
/// HIPAR catalogSize/Returns the number of files and subdirectories of the current or
/// HIPAR catalogSize/specified directory. The number includes the parent directory strings
/// HIPAR catalogSize/'.' and '..' .
ViStatus _VI_FUNC rsmxo_QueryMemoryCatalogSize(ViSession instrSession,
                                               ViString  path,
                                               ViInt32*  catalogSize)
{
    ViChar   param[RS_PARAM_BUF_SIZE] = "";
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (path)
    {
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\"", path);

        viCheckParm(RsCore_GetAttributeViInt32WithQparam(instrSession, NULL, RSMXO_ATTR_MEMORY_CATALOG_SIZE, param, catalogSize),
                    2, "Path");
    }
    else
        viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_MEMORY_CATALOG_SIZE, catalogSize),
                3, "Catalog Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the a list of files contained in the specified directory. The
/// HIFN  result corresponds to the number of files returned by
/// HIFN  RSMXO_ATTR_MEMORY_CATALOG_SIZE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/String parameter to specify the directory. If the directory is
/// HIPAR path/omitted, it queries directory specified with
/// HIPAR path/RSMXO_ATTR_DIRECTORY_DEFAULT
/// HIPAR format/Defines what information is included in the result.
/// HIPAR bufferSize/Size of output array.
/// HIPAR catalog/Returns the a list of files contained in the specified directory. The
/// HIPAR catalog/result corresponds to the number of files returned by
/// HIPAR catalog/RSMXO_ATTR_MEMORY_CATALOG_SIZE.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryMemoryCatalog(ViSession instrSession,
                                           ViString  pathname,
                                           ViInt32   format,
                                           ViInt32   bufferSize,
                                           ViChar    catalog[],
                                           ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";
    ViChar*  p2format;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngMemoryCatalogFormat, format, &p2format),
                3, "Format");

    if (pathname)
    {
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\",%s", pathname, p2format);
    }
    else
    {
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"\",%s", p2format);
    }

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, NULL, RSMXO_ATTR_HIDDEN_MEMORY_CATALOG, param, bufferSize, catalog, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Restores the waveform generator settings from the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR waveformGeneratorSettings/Restores the waveform generator settings from the specified file.
ViStatus _VI_FUNC rsmxo_LoadWaveformGeneratorSettings(ViSession instrSession,
                                                      ViString  waveformGeneratorSettings)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_LOAD_WAVEFORM_GENERATOR_SETTINGS, waveformGeneratorSettings),
            2, "Waveform Generator Settings");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Stores the current waveform generator settings to the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR waveformGeneratorSettings/Stores the current waveform generator settings to the specified file.
ViStatus _VI_FUNC rsmxo_StoreWaveformGeneratorSettings(ViSession instrSession,
                                                       ViString  waveformGeneratorSettings)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_STORE_WAVEFORM_GENERATOR_SETTINGS, waveformGeneratorSettings),
            2, "Waveform Generator Settings");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Stores the current instrument settings to the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Stores the current instrument settings to the specified file.
ViStatus _VI_FUNC rsmxo_SaveInstrumentSettingsFile(ViSession instrSession,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_SAVE_INSTRUMENT_SETTINGS, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Restores the instrument settings from the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Restores the instrument settings from the specified file.
ViStatus _VI_FUNC rsmxo_LoadInstrumentSettingsFile(ViSession instrSession,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_LOAD_INSTRUMENT_SETTINGS, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Removes the specified file(s). To delete directories, use
/// HIFN  RSMXO_ATTR_DIRECTORY_DELETE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Removes the specified file(s). To delete directories, use
/// HIPAR fileName/RSMXO_ATTR_DIRECTORY_DELETE.
ViStatus _VI_FUNC rsmxo_DeleteFile(ViSession instrSession,
                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_FILE_DELETE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Copies an existing file to a new file.
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     MMEMory:COPY
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileSource/String parameter, contains name and path of the file to be copied.
/// HIPAR fileDestination/String parameter, contains name and path of the new file. If the file
/// HIPAR fileDestination/already exists, it is overwritten without notice. If no file
/// HIPAR fileDestination/destination is specified, the source file is written to the current
/// HIPAR fileDestination/directory.
ViStatus _VI_FUNC rsmxo_CopyFile(ViSession instrSession,
                                 ViString  fileSource,
                                 ViString  fileDestination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (fileDestination)
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\",\"%s\"", fileSource, fileDestination);
    else
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\"", fileSource);

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_FILE_COPY, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Moves the specified file to a new location on the same drive and
/// HIFN  renames it.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileSource/String parameter, contains name and path of the file to be copied.
/// HIPAR fileDestination/String parameter, contains name and path of the new file.
ViStatus _VI_FUNC rsmxo_MoveFile(ViSession instrSession,
                                 ViString  fileSource,
                                 ViString  fileDestination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\",\"%s\"", fileSource, fileDestination);

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_FILE_MOVE, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets file attributes for the specified file(s). Can be used for files
/// HIFN  only.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/String parameter, contains name and path of the file. Wildcards (* and
/// HIPAR fileName/?) are allowed.
/// HIPAR attributes/String with controls and setting information.
ViStatus _VI_FUNC rsmxo_ConfigureFileAttribute(ViSession instrSession,
                                               ViString  fileName,
                                               ViString  attributes)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\",\"%s\"", fileName, attributes);

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_FILE_ATTRIBUTE, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Changes the default directory for file access.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Changes the default directory for file access.
ViStatus _VI_FUNC rsmxo_ConfigureDefaultDirectory(ViSession instrSession,
                                                  ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_DIRECTORY_DEFAULT, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a new directory with the specified name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Creates a new directory with the specified name.
ViStatus _VI_FUNC rsmxo_CreateDirectory(ViSession instrSession,
                                        ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_DIRECTORY_CREATE, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Deletes the specified directory.
ViStatus _VI_FUNC rsmxo_DeleteDirectory(ViSession instrSession,
                                        ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_DIRECTORY_DELETE, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of subdirectories of the current or of a specified
/// HIFN  directory. The number includes the parent directory strings '.' and
/// HIFN  '..'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/String parameter to specify the directory. If the directory is
/// HIPAR path/omitted, the command queries the contents of the current directory.
/// HIPAR catalogSize/Returns the number of subdirectories of the current or of a specified
/// HIPAR catalogSize/directory. The number includes the parent directory strings '.' and
/// HIPAR catalogSize/'..'.
ViStatus _VI_FUNC rsmxo_QueryDirectoryCatalogSize(ViSession instrSession,
                                                  ViString  path,
                                                  ViInt32*  catalogSize)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    if (path)
    {
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\"", path);

        viCheckParm(RsCore_GetAttributeViInt32WithQparam(instrSession, NULL, RSMXO_ATTR_HIDDEN_DIRECTORY_CATALOG_SIZE, param, catalogSize),
                    2, "Catalog Length");
    }
    else
        viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_HIDDEN_DIRECTORY_CATALOG_SIZE, catalogSize),
                2, "Catalog Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the subdirectories of the current or of a specified directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directoryPath/String parameter to specify the directory. If the directory is
/// HIPAR directoryPath/omitted, it queries the contents of the current directory.
/// HIPAR bufferSize/Size of output array.
/// HIPAR directoryCatalog/Returns the subdirectories of the current or of a specified directory.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryDirectoryCatalog(ViSession instrSession,
                                              ViString  directoryPath,
                                              ViInt32   bufferSize,
                                              ViChar    directoryCatalog[],
                                              ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    if (directoryPath)
    {
        (void)snprintf(param, RS_PARAM_BUF_SIZE, "\"%s\"", directoryPath);
        checkErr(RsCore_GetAttributeViStringWithQparam(instrSession, NULL, RSMXO_ATTR_HIDDEN_DIRECTORY_CATALOG, param, bufferSize, directoryCatalog, bytesRead));
    }
    else
    {
        checkErr(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_HIDDEN_DIRECTORY_CATALOG, bufferSize, directoryCatalog, bytesRead));
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures screenshot settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR showSetupDialog/If enabled, the currently open dialog box is included in the
/// HIPAR showSetupDialog/screenshot.
/// HIPAR whiteBackground/Inverts the background color, so you can picture waveforms with normal
/// HIPAR whiteBackground/waveform colors on white background.
/// HIPAR includeSignalBar/If enabled, the screenshot shows the signal bar below the diagram
/// HIPAR includeSignalBar/area.
ViStatus _VI_FUNC rsmxo_ConfigureScreenshotSettings(ViSession instrSession,
                                                    ViBoolean showSetupDialog,
                                                    ViBoolean whiteBackground,
                                                    ViBoolean includeSignalBar)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SCREENSHOT_SHOW_SETUP_DIALOG, showSetupDialog),
            2, "Show Setup Dialog");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SCREENSHOT_WHITE_BACKGROUND, whiteBackground),
            3, "White Background");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_SCREENSHOT_INCLUDE_SIGNAL_BAR, includeSignalBar),
            4, "Include Signal Bar");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the color settings for screenshots.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR reserved/This control is reserved.
/// HIPAR invertColor/Inverts the colors of the output, i.e. a dark waveform is shown on a
/// HIPAR invertColor/white background.
ViStatus _VI_FUNC rsmxo_ConfigureScreenshotColorSettings(ViSession instrSession,
                                                         ViInt32   reserved,
                                                         ViBoolean invertColor)
{
    ViStatus error = VI_SUCCESS;
             reserved;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, "", RSMXO_ATTR_SCREENSHOT_INVERT_COLOR, invertColor),
            3, "Invert Color");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the file path and format for output of the display image to
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR filePath/Selects the output medium: file or clipboard.
/// HIPAR fileExtension/Defines the file format for output of the display image to file.
ViStatus _VI_FUNC rsmxo_ConfigureScreenshotFilePath(ViSession instrSession,
                                                    ViString  filePath,
                                                    ViInt32   fileExtension)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, "", RSMXO_ATTR_SCREENSHOT_FILENAME, filePath),
            2, "File Path");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, "", RSMXO_ATTR_SCREENSHOT_FILE_EXTENSION, fileExtension),
            3, "File Extension");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts the immediate output of the display image.
/// HIFN  To get a correct screenshot of the diagrams, results, and dialog
/// HIFN  boxes, turn on the display using RSMXO_ATTR_REMOTE_DISPLAY_UPDATE_ENABLED.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_SaveScreenshot(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, "", RSMXO_ATTR_SCREENSHOT_SAVE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts the output of the next display image.
/// HIFN  If the screenshot is saved to a file, the file name used in the last
/// HIFN  saving process is automatically counted up to the next unused name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_SaveScreenshotNext(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, "", RSMXO_ATTR_SCREENSHOT_SAVE_NEXT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the waveform export settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the waveoform to be exported to file.
/// HIPAR mode/Defines the part of the waveform record that has to be stored.
ViStatus _VI_FUNC rsmxo_ConfigureWaveformExportSettings(ViSession instrSession,
                                                        ViInt32   source,
                                                        ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_SOURCE, source),
            2, "Source");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the start and end time values of the waveform section for export
/// HIFN  if RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Manual.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR start/Sets the start time value of the waveform section for export if
/// HIPAR start/RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Manual.
/// HIPAR stop/Sets the stop time value of the waveform section for export if
/// HIPAR stop/RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Manual.
ViStatus _VI_FUNC rsmxo_ConfigureWaveformExportManualRange(ViSession instrSession,
                                                           ViReal64  start,
                                                           ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_MANUAL_START, start),
            2, "Start");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_MANUAL_STOP, stop),
            3, "Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the gate for waveform record if
/// HIFN  RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR gate/Selects the gate for waveform record if
/// HIPAR gate/RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Gate.
ViStatus _VI_FUNC rsmxo_SelectWaveformExportGate(ViSession instrSession,
                                                 ViInt32   gate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_GATE, gate),
            2, "Gate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the cursor set to be used for limited data export if
/// HIFN  RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Cursor.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR cursorSet/Sets the cursor set to be used for limited data export if
/// HIPAR cursorSet/RSMXO_ATTR_WAVEFORM_EXPORT_MODE is set to Cursor.
ViStatus _VI_FUNC rsmxo_SelectWaveformExportCursorSet(ViSession instrSession,
                                                      ViInt32   cursorSet)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_CURSOR_SET, cursorSet),
            2, "Gate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the waveform to the file specified with
/// HIFN  RSMXO_ATTR_WAVEFORM_EXPORT_FILE_NAME.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR filePath/Sets the path, the filename and the file format of the export file.
ViStatus _VI_FUNC rsmxo_ConfigureWaveformFileName(ViSession instrSession,
                                                  ViString  filePath)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_FILE_NAME, filePath),
            2, "File Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the waveform to the file specified with
/// HIFN  RSMXO_ATTR_WAVEFORM_EXPORT_FILE_NAME.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_SaveWaveformToFile(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_SAVE_TO_FILE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Aborts a running waveform export, which was started with
/// HIFN  RSMXO_ATTR_WAVEFORM_EXPORT_SAVE_TO_FILE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_AbortWaveformSave(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_WAVEFORM_EXPORT_ABORT_SAVE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures included results in the export file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR includeCurrentMeasurement/Includes the current automatic measurement results in the export file.
/// HIPAR includeCursor/Includes the current cursor results in the export file.
ViStatus _VI_FUNC rsmxo_ConfigureResultsExportSettings(ViSession instrSession,
                                                       ViBoolean includeCurrentMeasurement,
                                                       ViBoolean includeCursor)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_INCLUDE_CURRENT_MEASUREMENT, includeCurrentMeasurement),
            2, "Include Current Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_INCLUDE_CURSOR, includeCursor),
            3, "Include Cursor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the path, the filename and the file format of the export file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Sets the path, the filename and the file format of the export file.
ViStatus _VI_FUNC rsmxo_ConfigureResultsExportFileName(ViSession instrSession,
                                                       ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_FILE_NAME, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the results to file. The target file is set
/// HIFN  RSMXO_ATTR_RESULTS_EXPORT_SAVE_TO_FILE. To select the results to be
/// HIFN  exported, use RSMXO_ATTR_RESULTS_EXPORT_INCLUDE_CURSOR and
/// HIFN  RSMXO_ATTR_RESULTS_EXPORT_INCLUDE_CURRENT_MEASUREMENT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ResultsExportSaveToFile(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_SAVE_TO_FILE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configure results export FRA.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR margin/If enabled, includes the margin results in the results export file of
/// HIPAR margin/the FRA.
/// HIPAR marker/If enabled, includes the marker results in the results export file of
/// HIPAR marker/the FRA.
/// HIPAR result/If enabled, includes the frequency response analysis results,
/// HIPAR result/including the frequency, gain, phase and amplitude, in the results
/// HIPAR result/export file of the FRA.
ViStatus _VI_FUNC rsmxo_ConfigureResultsExportFRA(ViSession instrSession,
                                                  ViBoolean margin,
                                                  ViBoolean marker,
                                                  ViBoolean result)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_FRA_MARGIN, margin),
            2, "Margin");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_FRA_MARKER, marker),
            3, "Marker");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_RESULTS_EXPORT_FRA_RESULT, result),
            4, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the waveform export source.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchWaveformDouble(ViSession instrSession,
                                            ViInt32   source,
                                            ViInt32   waveformArraySize,
                                            ViReal64  waveformData[],
                                            ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    switch (source)
    {
    case RSMXO_VAL_SOURCE_C1:
    case RSMXO_VAL_SOURCE_C2:
    case RSMXO_VAL_SOURCE_C3:
    case RSMXO_VAL_SOURCE_C4:
    case RSMXO_VAL_SOURCE_C5:
    case RSMXO_VAL_SOURCE_C6:
    case RSMXO_VAL_SOURCE_C7:
    case RSMXO_VAL_SOURCE_C8:
        checkErr(rsmxo_FetchChannelWaveform(instrSession, source, waveformArraySize, waveformData, returnedPoints));
        break;

    case RSMXO_VAL_SOURCE_M1:
    case RSMXO_VAL_SOURCE_M2:
    case RSMXO_VAL_SOURCE_M3:
    case RSMXO_VAL_SOURCE_M4:
    case RSMXO_VAL_SOURCE_M5:
        checkErr(rsmxo_FetchMathWaveform(instrSession, source - RSMXO_VAL_SOURCE_M1 + 1, waveformArraySize, waveformData, returnedPoints));
        break;

    case RSMXO_VAL_SOURCE_R1:
    case RSMXO_VAL_SOURCE_R2:
    case RSMXO_VAL_SOURCE_R3:
    case RSMXO_VAL_SOURCE_R4:
        checkErr(rsmxo_FetchReferenceWaveform(instrSession, source - RSMXO_VAL_SOURCE_R1 + 1, waveformArraySize, waveformData, returnedPoints));
        break;

    case RSMXO_VAL_SOURCE_SPECTRUM_AVERAGE1:
        checkErr(rsmxo_FetchSpectrumWaveform(instrSession, RSMXO_VAL_SPECTRUM_TRACE_TYPE_AVERAGE, waveformArraySize, waveformData, returnedPoints));
        break;

    case RSMXO_VAL_SOURCE_SPECTRUM_MIN_HOLD1:
        checkErr(rsmxo_FetchSpectrumWaveform(instrSession, RSMXO_VAL_SPECTRUM_TRACE_TYPE_MINIMUM, waveformArraySize, waveformData, returnedPoints));
        break;

    case RSMXO_VAL_SOURCE_SPECTRUM_MAX_HOLD1:
        checkErr(rsmxo_FetchSpectrumWaveform(instrSession, RSMXO_VAL_SPECTRUM_TRACE_TYPE_MAXIMUM, waveformArraySize, waveformData, returnedPoints));
        break;

    case RSMXO_VAL_SOURCE_SPECTRUM_NORM1:
        checkErr(rsmxo_FetchSpectrumWaveform(instrSession, RSMXO_VAL_SPECTRUM_TRACE_TYPE_NORMAL, waveformArraySize, waveformData, returnedPoints));
        break;

    default:
        error = RS_ERROR_INVALID_VALUE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this source. Call FetchWaveform to obtain the waveforms for other
/// HIFN  sources.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the waveform export source.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadWaveformDouble(ViSession instrSession,
                                           ViInt32   source,
                                           ViInt32   maximumTimeMs,
                                           ViInt32   waveformArraySize,
                                           ViReal64  waveformData[],
                                           ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchWaveformDouble(instrSession, source, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the waveform export source.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchWaveformInt(ViSession instrSession,
                                         ViInt32   source,
                                         ViInt32   waveformArraySize,
                                         ViInt32   waveformData[],
                                         ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    switch (source)
    {
    case RSMXO_VAL_SOURCE_D0:
    case RSMXO_VAL_SOURCE_D1:
    case RSMXO_VAL_SOURCE_D2:
    case RSMXO_VAL_SOURCE_D3:
    case RSMXO_VAL_SOURCE_D4:
    case RSMXO_VAL_SOURCE_D5:
    case RSMXO_VAL_SOURCE_D6:
    case RSMXO_VAL_SOURCE_D7:
    case RSMXO_VAL_SOURCE_D8:
    case RSMXO_VAL_SOURCE_D9:
    case RSMXO_VAL_SOURCE_D10:
    case RSMXO_VAL_SOURCE_D11:
    case RSMXO_VAL_SOURCE_D12:
    case RSMXO_VAL_SOURCE_D13:
    case RSMXO_VAL_SOURCE_D14:
    case RSMXO_VAL_SOURCE_D15:
        checkErr(rsmxo_FetchDigitalWaveform(instrSession, source - RSMXO_VAL_SOURCE_D0, waveformArraySize, waveformData, returnedPoints));
        break;

    default:
        error = RS_ERROR_INVALID_VALUE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this source. Call FetchWaveform to obtain the waveforms for other
/// HIFN  sources.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR source/Selects the waveform export source.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadWaveformInt(ViSession instrSession,
                                        ViInt32   source,
                                        ViInt32   maximumTimeMs,
                                        ViInt32   waveformArraySize,
                                        ViInt32   waveformData[],
                                        ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchWaveformInt(instrSession, source, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the status registers.
/// HIFN
/// HIFN     All PTRansition bits  are set to 1, i.e. all
/// HIFN     transitions from 0 to 1 are detected.
/// HIFN
/// HIFN     All NTRansition bits are set to 0, i.e. a transition
/// HIFN     from 1 to 0 in a CONDition bit is not detected.
/// HIFN
/// HIFN     All EVENt bits are set to 0.
/// HIFN
/// HIFN     The ENABle bits of STATus:OPERation
/// HIFN     and  STATus:QUEStionable are set to 0, i.e. all events in these
/// HIFN  registers are not passed
/// HIFN     on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_StatusRegisterReset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negativeClipping/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR negativeClipping/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelNegativeClippingEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negativeClipping)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_ENABLED, negativeClipping),
            3, "Negative Clipping");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative and positive transition filter if a
/// HIFN  negative/positive clipping value of a channel is violated.
/// HIFN
/// HIFN     If a bit is set, a transition from 1 to 0 in the condition part causes
/// HIFN  an entry to be made in the  corresponding bit of  the EVENt part of the
/// HIFN  register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negative/Sets the negative transition filter if a negative/positive clipping
/// HIPAR negative/value of a channel is violated.
/// HIPAR positive/Sets the positive transition filter if a negative/positive clipping
/// HIPAR positive/value of a channel is violated.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelNegativeClippingTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_NEGATIVE_TRANSITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the channel
/// HIFN  status, to check if a negative/positive clipping   value is violated.
/// HIFN
/// HIFN     Reading the registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if a negative/positive clipping   value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if a negative/positive clipping  channel violation has occurred since
/// HIPAR event/the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelNegativeClipping(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  condition,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_CONDITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_NEGATIVE_CLIPPING_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR positiveClipping/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR positiveClipping/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPositiveClippingEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean positiveClipping)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_ENABLED, positiveClipping),
            3, "Positive Clipping");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative and positive transition filter if a
/// HIFN  negative/positive clipping value of a channel is violated.
/// HIFN
/// HIFN     If a bit is set, a transition from 1 to 0 in the condition part causes
/// HIFN  an entry to be made in the  corresponding bit of  the EVENt part of the
/// HIFN  register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negative/Sets the negative transition filter if a negative/positive clipping
/// HIPAR negative/value of a channel is violated.
/// HIPAR positive/Sets the positive transition filter if a negative/positive clipping
/// HIPAR positive/value of a channel is violated.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPositiveClippingTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_NEGATIVE_TRANSITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the channel
/// HIFN  status, to check if a negative/positive clipping   value is violated.
/// HIFN
/// HIFN     Reading the registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if a negative/positive clipping   value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if a negative/positive clipping  channel violation has occurred since
/// HIPAR event/the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelPositiveClipping(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  condition,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_CONDITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_POSITIVE_CLIPPING_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR overload/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR overload/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelOverloadEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean overload)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_ENABLED, overload),
            3, "Overload");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative and positive transition filter if an overload for
/// HIFN  the 50  terminator has occurred.
/// HIFN
/// HIFN     If a bit is set, a transition from 1 to 0 in the condition part causes
/// HIFN  an entry to be made in the  corresponding bit of  the EVENt part of the
/// HIFN  register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negative/Sets the negative transition filter if an overload for the 50
/// HIPAR negative/terminator has occurred.
/// HIPAR positive/Sets the positive transition filter if an overload for the 50
/// HIPAR positive/terminator   has occurred.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelOverloadTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_NEGATIVE_TRANSITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the channel
/// HIFN  status, to check if an overload for the 50    terminator   has occurred
/// HIFN  since the last reading.
/// HIFN
/// HIFN     Reading an deletes its contents.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if an overload for the 50    terminator   has occurred.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if an overload for the 50    terminator   has occurred since the last
/// HIPAR event/reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelOverload(ViSession  instrSession,
                                                           ViInt32    channel,
                                                           ViInt32*   condition,
                                                           ViBoolean* event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_CONDITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_OVERLOAD_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the EVENt part of the channel status, to check
/// HIFN  if an overload has occurred since the last reading.
/// HIFN
/// HIFN     Reading an EVENt deletes its contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if an overload has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelWarnOverloadEvent(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_EVENT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_EVENT, event),
            3, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR overloadEnabled/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR overloadEnabled/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelWarnOverloadEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean overloadEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_ENABLED, overloadEnabled),
            3, "Overload Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative transition filter if an warn overload for the 50
/// HIFN  terminator has occurred.
/// HIFN
/// HIFN     If a bit is
/// HIFN     set, a transition from 1 to 0 in the condition part causes an entry to
/// HIFN  be made in the  corresponding bit of  the EVENt part of the register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negative/Sets the negative transition filter if an warn overload for the 50
/// HIPAR negative/terminator has occurred.
/// HIPAR positive/Sets the positive transition filter if an warn overload for the 50
/// HIPAR positive/terminator   has occurred.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelWarnOverloadTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_NEGATIVE_TRANSITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition part of the channel status, to
/// HIFN  check if a negative/positive warn overload  value is violated.
/// HIFN
/// HIFN     Reading the CONDition registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if a negative/positive warn overload  value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if an overload has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelWarnOverload(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  condition,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_CONDITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_WARN_OVERLOAD_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR enabled/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR enabled/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPPSEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the transition filter if an warn overload for the 50  terminator
/// HIFN  has occurred.
/// HIFN
/// HIFN     If a bit is
/// HIFN     set, a transition from 1 to 0 in the condition part causes an entry to
/// HIFN  be made in the  corresponding bit of  the EVENt part of the register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR negative/Sets the negative transition filter if an warn overload for the 50
/// HIPAR negative/terminator has occurred.
/// HIPAR positive/Sets the positive transition filter if an warn overload for the 50
/// HIPAR positive/terminator has occurred.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterChannelPPSTransition(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_NEGATIVE_TRANSITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the channel
/// HIFN  status, to check if a negative/positive temperature value is violated.
/// HIFN
/// HIFN     Reading the CONDition registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR condition/Returns the contents of the CONDition part of the channel status, to
/// HIPAR condition/check if a negative/positive temperature value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the channel status, to check
/// HIPAR event/if an overload has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterChannelPPS(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32*  condition,
                                                      ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_CONDITION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_CHANNEL_PPS_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR imprecise/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR imprecise/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementImpreciseEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean imprecise)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_ENABLED, imprecise),
            3, "Imprecise");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative and positive transition filter for imprecise
/// HIFN  measurements (the magnitude of the signal is too low to get reliable
/// HIFN  measurement results).
/// HIFN
/// HIFN     If a bit is set, a transition from 1 to 0 in the condition part causes
/// HIFN  an entry to be made in the  corresponding bit of  the EVENt part of the
/// HIFN  register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR negative/Sets the negative transition filter for imprecise measurements (the
/// HIPAR negative/magnitude of the signal is too low to get reliable measurement
/// HIPAR negative/results).
/// HIPAR positive/Sets the positive transition filter for imprecise measurements (the
/// HIPAR positive/magnitude of the signal is too low to get reliable measurement
/// HIPAR positive/results).
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementImpreciseTransition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_NEGATIVE_TRANSITION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the
/// HIFN  measurement status, to check if a limit value is imprecise (the
/// HIFN  magnitude of the signal is too low to get reliable measurement
/// HIFN  results).
/// HIFN
/// HIFN     Reading the registers does not delete the contents.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR condition/Returns the contents of the CONDition part of the measurement status,
/// HIPAR condition/to check if a limit value is imprecise (the magnitude of the signal is
/// HIPAR condition/too low to get reliable measurement results).
/// HIPAR event/Returns the contents of the EVENt part of the measurement status, to
/// HIPAR event/check if an imprecise measurement  has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterMeasurementImprecise(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViInt32*  condition,
                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_CONDITION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_IMPRECISE_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR limit/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR limit/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementLimitEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean limit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_ENABLED, limit),
            3, "Limit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative and positive transition filter if a limit value of a
/// HIFN  measurement is violated.
/// HIFN
/// HIFN     If a bit is set, a transition from 1 to 0 in the condition part causes
/// HIFN  an entry to be made in the  corresponding bit of  the EVENt part of the
/// HIFN  register.
/// HIFN
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR negative/Sets the negative transition filter if a limit value of a measurement
/// HIPAR negative/is violated.
/// HIPAR positive/Sets the positive transition filter if a limit value of a measurement
/// HIPAR positive/is violated.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementLimitTransition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_NEGATIVE_TRANSITION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the
/// HIFN  measurement status, to check if a limit value is violated.
/// HIFN
/// HIFN     Reading the registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR condition/Returns the contents of the CONDition part of the measurement status,
/// HIPAR condition/to check if a limit value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the measurement status, to
/// HIPAR event/check if a limit violation has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterMeasurementLimit(ViSession instrSession,
                                                            ViInt32   measurement,
                                                            ViInt32*  condition,
                                                            ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_CONDITION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_LIMIT_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR margin/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR margin/be reported.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementMarginEnabled(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean margin)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_ENABLED,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_ENABLED, margin),
            3, "Margin");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the negative and positive transition filter if a margin value of
/// HIFN  a measurement is violated.
/// HIFN
/// HIFN     If a bit is set, a transition from 1 to 0 in the condition part causes
/// HIFN  an entry to be made in the  corresponding bit of  the EVENt part of the
/// HIFN  register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR negative/Sets the negative transition filter if a margin value of a measurement
/// HIPAR negative/is violated.
/// HIPAR positive/Sets the positive transition filter if a margin value of a measurement
/// HIPAR positive/is violated.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterMeasurementMarginTransition(
                            ViSession instrSession,
                            ViInt32   measurement,
                            ViBoolean negative,
                            ViBoolean positive)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_NEGATIVE_TRANSITION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_NEGATIVE_TRANSITION, negative),
            3, "Negative");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_POSITIVE_TRANSITION, positive),
            4, "Positive");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the CONDition and EVENt part of the
/// HIFN  measurement status, to check if a margin value is violated.
/// HIFN
/// HIFN     Reading the registers does not delete the contents.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR measurement/Selects repeated capability Measurement.
/// HIPAR condition/Returns the contents of the CONDition part of the measurement status,
/// HIPAR condition/to check if a margin  value is violated.
/// HIPAR event/Returns the contents of the EVENt part of the measurement status, to
/// HIPAR event/check if a margin  violation has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterMeasurementMargin(ViSession instrSession,
                                                             ViInt32   measurement,
                                                             ViInt32*  condition,
                                                             ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  measurementCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Measurement", &measurementCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, 1, measurementCount),
            2, "Measurement");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_CONDITION,
            "Measurement", measurement - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Measurement");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_CONDITION, condition),
            3, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_STATUS_REGISTER_MEASUREMENT_MARGIN_EVENT, event),
            4, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported for  the summary bit in
/// HIFN     the status byte.
/// HIFN
/// HIFN     These events can be used for a service request.
/// HIFN     If a bit in the ENABle part is 1, and the corresponding EVENt bit is
/// HIFN  true, a positive
/// HIFN     transition occurs in the summary bit. This transition is reported to
/// HIFN  the next higher level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerAction/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR triggerAction/be reported for  the summary bit in
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerActionEnabled(
                            ViSession instrSession,
                            ViBoolean triggerAction)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_ENABLED, triggerAction),
            2, "Trigger Action");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the positive and negative positive filter.
/// HIFN
/// HIFN     If a bit is
/// HIFN     set, a transition from 1 to 0 in the condition part causes an entry to
/// HIFN  be made in the  corresponding bit of  the EVENt part of the register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR positive/Sets the negative positive filter.
/// HIPAR negative/Sets the negative transition filter.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerActionTransition(
                            ViSession instrSession,
                            ViInt32   positive,
                            ViInt32   negative)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_POSITIVE_TRANSITION, positive),
            2, "Positive");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_NEGATIVE_TRANSITION, negative),
            3, "Negative");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the condition and event parts of the status
/// HIFN  register to check for questionable instrument or measurement states.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Returns the contents of the CONDition part of the status register to
/// HIPAR condition/check for questionable instrument or measurement states. This
/// HIPAR event/Returns the contents of the EVENt part of the status register to check
/// HIPAR event/if an event has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterTriggerAction(ViSession instrSession,
                                                         ViInt32*  condition,
                                                         ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_CONDITION, condition),
            2, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_ACTION_EVENT, event),
            3, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ENABle part that allows true conditions in the EVENt part to
/// HIFN  be reported for  the summary bit in
/// HIFN     the status byte.
/// HIFN
/// HIFN     These events can be used for a service request.
/// HIFN     If a bit in the ENABle part is 1, and the corresponding EVENt bit is
/// HIFN  true, a positive
/// HIFN     transition occurs in the summary bit. This transition is reported to
/// HIFN  the next higher level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR triggerEdge/Sets the ENABle part that allows true conditions in the EVENt part to
/// HIPAR triggerEdge/be reported for  the summary bit in
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerEdgeEnabled(
                            ViSession instrSession,
                            ViBoolean triggerEdge)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_ENABLED, triggerEdge),
            2, "Trigger Edge");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the positive and negative transition filter.
/// HIFN
/// HIFN     If a bit is
/// HIFN     set, a transition from 0 to 1 in the condition part causes an entry to
/// HIFN  be made in the  corresponding bit of  the EVENt part of the register.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR positive/Sets the positive transition filter.
/// HIPAR negative/Sets the negative transition filter.
ViStatus _VI_FUNC rsmxo_ConfigureStatusRegisterTriggerEdgeTransition(
                            ViSession instrSession,
                            ViInt32   positive,
                            ViInt32   negative)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_POSITIVE_TRANSITION, positive),
            2, "Positive");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_NEGATIVE_TRANSITION, negative),
            3, "Negative");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of the condition and event part of the status
/// HIFN  register to check for questionable instrument or measurement states.
/// HIFN  This
/// HIFN     part contains information on the action currently being performed in
/// HIFN  the instrument.
/// HIFN
/// HIFN     Reading the CONDition registers does not delete the contents since it
/// HIFN  indicates the current hardware
/// HIFN     status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR condition/Returns the contents of the CONDition part of the status register to
/// HIPAR condition/check for questionable instrument or measurement states. This
/// HIPAR event/Returns the contents of the EVENt part of the status register to check
/// HIPAR event/if an event has occurred since the last reading.
ViStatus _VI_FUNC rsmxo_QueryStatusRegisterTriggerEdge(ViSession instrSession,
                                                       ViInt32*  condition,
                                                       ViInt32*  event)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_CONDITION, condition),
            2, "Condition");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_STATUS_REGISTER_TRIGGER_EDGE_EVENT, event),
            3, "Event");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the header of the specified channel waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchChannelWaveformHeader(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64* xStart,
                                                   ViReal64* xStop,
                                                   ViInt32*  recordLength,
                                                   ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  channelCount = 0;
    ViReal64 channelHeader[4] = {0, 0, 0, 0};
    ViInt32  numberOfReurnedValues = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, channelCount),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_CHANNEL_WAVEFORM_HEADER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_CHANNEL_WAVEFORM_HEADER, NULL, 4, channelHeader, &numberOfReurnedValues));

    if (numberOfReurnedValues == 4)
    {
        if (xStart != NULL)
            *xStart = channelHeader[0];
        if (xStop != NULL)
            *xStop = channelHeader[1];
        if (recordLength != NULL)
            *recordLength = (ViInt32)floor(channelHeader[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        if (valuesPerSample != NULL)
            *valuesPerSample = channelHeader[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a previously acquired waveform for this channel. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchChannelWaveform(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   waveformArraySize,
                                             ViReal64  waveformData[],
                                             ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  channelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Channel", &channelCount);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;CHAN%ld:DATA?", channel);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this channel. Call FetchWaveform to obtain the waveforms for other
/// HIFN  channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Selects repeated capability Channel.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadChannelWaveform(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   maximumTimeMs,
                                            ViInt32   waveformArraySize,
                                            ViReal64  waveformData[],
                                            ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchChannelWaveform(instrSession, channel, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the header of the specified math waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchMathWaveformHeader(ViSession instrSession,
                                                ViInt32   math,
                                                ViReal64* xStart,
                                                ViReal64* xStop,
                                                ViInt32*  recordLength,
                                                ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  mathCount = 0;
    ViReal64 mathHeader[4] = {0, 0, 0, 0};
    ViInt32  numberOfReturnedValues = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_MATH_WAVEFORM_HEADER,
            "Math", math - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Math");

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_MATH_WAVEFORM_HEADER, NULL, 4, mathHeader, &numberOfReturnedValues));

    if (numberOfReturnedValues == 4)
    {
        if (xStart != NULL)
            *xStart = mathHeader[0];
        if (xStop != NULL)
            *xStop = mathHeader[1];
        if (recordLength != NULL)
            *recordLength = (ViInt32)floor(mathHeader[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        if (valuesPerSample != NULL)
            *valuesPerSample = mathHeader[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each math waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchMathWaveform(ViSession instrSession,
                                          ViInt32   math,
                                          ViInt32   waveformArraySize,
                                          ViReal64  waveformData[],
                                          ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  mathCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Math", &mathCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, math, 1, mathCount),
            2, "Math");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;CALC:MATH%ld:DATA:VAL?", math);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this channel. Call FetchWaveform to obtain the waveforms for other
/// HIFN  math waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR math/Selects repeated capability Math.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadMathWaveform(ViSession instrSession,
                                         ViInt32   math,
                                         ViInt32   maximumTimeMs,
                                         ViInt32   waveformArraySize,
                                         ViReal64  waveformData[],
                                         ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchMathWaveform(instrSession, math, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the header of the specified digital waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchDigitalWaveformHeader(ViSession instrSession,
                                                   ViInt32   digitalChannel,
                                                   ViReal64* xStart,
                                                   ViReal64* xStop,
                                                   ViInt32*  recordLength,
                                                   ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;
    ViReal64 digitalHeader[4] = {0, 0, 0, 0};
    ViInt32  numberOfReturnedValues = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel , 0, digitalChannelCount - 1),
                2, "Digital Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_DIGITAL_WAVEFORM_HEADER,
            "DigitalChannel", digitalChannel , RS_REPCAP_BUF_SIZE, repCap),
            2, "Digital Channel");

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_DIGITAL_WAVEFORM_HEADER, NULL, 4, digitalHeader, &numberOfReturnedValues));

    if (numberOfReturnedValues == 4)
    {
        *xStart = digitalHeader[0];
        *xStop = digitalHeader[1];
        *recordLength = (ViInt32)floor(digitalHeader[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        *valuesPerSample = digitalHeader[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each digital waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchDigitalWaveform(ViSession instrSession,
                                             ViInt32   digitalChannel,
                                             ViInt32   waveformArraySize,
                                             ViInt32   waveformData[],
                                             ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  digitalChannelCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DigitalChannel", &digitalChannelCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, digitalChannel, 0, digitalChannelCount - 1),
                2, "Digital Channel");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;DIG%ld:DATA?", digitalChannel);
    checkErr(RsCore_QueryIntegerArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this channel. Call FetchWaveform to obtain the waveforms for other
/// HIFN  digital channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR digitalChannel/Selects repeated capability DigitalChannel.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadDigitalWaveform(ViSession instrSession,
                                            ViInt32   digitalChannel,
                                            ViInt32   maximumTimeMs,
                                            ViInt32   waveformArraySize,
                                            ViInt32   waveformData[],
                                            ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchDigitalWaveform(instrSession, digitalChannel, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the header data of the indicated bus.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchLogicHeader(ViSession instrSession,
                                         ViInt32   logic,
                                         ViReal64* xStart,
                                         ViReal64* xStop,
                                         ViInt32*  recordLength,
                                         ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  logicCount = 0;
    ViReal64 logicHeader[4] = {0, 0, 0, 0};
    ViInt32  numberOfReturnedValues = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_LOGIC_BUS_HEADER,
            "Logic", logic - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Logic");

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_LOGIC_BUS_HEADER, NULL, 4, logicHeader, &numberOfReturnedValues));

    if (numberOfReturnedValues == 4)
    {
        if (xStart != NULL)
            *xStart = logicHeader[0];
        if (xStop != NULL)
            *xStop = logicHeader[1];
        if (recordLength != NULL)
            *recordLength = (ViInt32)floor(logicHeader[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        if (valuesPerSample != NULL)
            *valuesPerSample = logicHeader[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each logic.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchLogicWaveform(ViSession instrSession,
                                           ViInt32   logic,
                                           ViInt32   waveformArraySize,
                                           ViInt32   waveformData[],
                                           ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  logicCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "Logic", &logicCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, logic, 1, logicCount),
            2, "Logic");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;PBUS%ld:DATA?", logic);
    checkErr(RsCore_QueryIntegerArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this channel. Call FetchWaveform to obtain the waveforms for other
/// HIFN  logic.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logic/Selects repeated capability Logic.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadLogicWaveform(ViSession instrSession,
                                          ViInt32   logic,
                                          ViInt32   maximumTimeMs,
                                          ViInt32   waveformArraySize,
                                          ViInt32   waveformData[],
                                          ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchLogicWaveform(instrSession, logic, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the header of the specified spectrum waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace type to export to waveform.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchSpectrumWaveformHeader(ViSession instrSession,
                                                    ViInt32   trace,
                                                    ViReal64* xStart,
                                                    ViReal64* xStop,
                                                    ViInt32*  recordLength,
                                                    ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViReal64 header[4] = {0, 0, 0, 0};
    ViInt32  numberOfReturnedValues = 0;
    ViAttr   attr = 0;

    checkErr(RsCore_LockSession(instrSession));

    switch (trace)
    {
    case RSMXO_VAL_SPECTRUM_TRACE_TYPE_AVERAGE:
        attr = RSMXO_ATTR_SPECTRUM_AVERAGE_WAVEFORM_HEADER;
        break;

    case RSMXO_VAL_SPECTRUM_TRACE_TYPE_MAXIMUM:
        attr = RSMXO_ATTR_SPECTRUM_MAXIMUM_WAVEFORM_HEADER;
        break;

    case RSMXO_VAL_SPECTRUM_TRACE_TYPE_MINIMUM:
        attr = RSMXO_ATTR_SPECTRUM_MINIMUM_WAVEFORM_HEADER;
        break;

    default:
        attr = RSMXO_ATTR_SPECTRUM_NORMAL_WAVEFORM_HEADER;
        break;
    }

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, NULL, attr, NULL, 4, header, &numberOfReturnedValues));

    if (numberOfReturnedValues == 4)
    {
        if (xStart != NULL)
            *xStart = header[0];
        if (xStop != NULL)
            *xStop = header[1];
        if (recordLength != NULL)
            *recordLength = (ViInt32)floor(header[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        if (valuesPerSample != NULL)
            *valuesPerSample = header[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each spectrum waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace type to export to waveform.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchSpectrumWaveform(ViSession instrSession,
                                              ViInt32   trace,
                                              ViInt32   waveformArraySize,
                                              ViReal64  waveformData[],
                                              ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    switch (trace)
    {
    case RSMXO_VAL_SPECTRUM_TRACE_TYPE_AVERAGE:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;CALC:SPEC:WAV:AVER:DATA?");
        break;

    case RSMXO_VAL_SPECTRUM_TRACE_TYPE_MAXIMUM:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;CALC:SPEC:WAV:MAX:DATA?");
        break;

    case RSMXO_VAL_SPECTRUM_TRACE_TYPE_MINIMUM:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;CALC:SPEC:WAV:MIN:DATA?");
        break;

    default:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;CALC:SPEC:WAV:AVER:DATA?");
        break;
    }

    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this channel. Call FetchWaveform to obtain the waveforms for other
/// HIFN  spectrum traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace type to export to waveform.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadSpectrumWaveform(ViSession instrSession,
                                             ViInt32   trace,
                                             ViInt32   maximumTimeMs,
                                             ViInt32   waveformArraySize,
                                             ViReal64  waveformData[],
                                             ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchSpectrumWaveform(instrSession, trace, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Initiates an acquisition on all enabled channels, waits (up to maximumTime)
/// HIFN  for the acquisition to complete, and returns the data of the indicated track
/// HIFN  waveform for transmission from the instrument to the controlling computer.
/// HIFN  The data can be used in MATLAB, for example.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR trace/Selects the trace type to export to waveform.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadMeasurementTrackData(ViSession instrSession,
                                                 ViInt32   measurement,
                                                 ViInt32   maximumTimeMs,
                                                 ViInt32   waveformArraySize,
                                                 ViReal64  waveformData[],
                                                 ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchMeasurementTrackData(instrSession, measurement, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the signal type of the source of the reference waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR bufferSize/Size of output array.
/// HIPAR waveformDataSource/Returns the signal type of the source of the reference waveform.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryReferenceWaveformDataSource(ViSession instrSession,
                                                         ViInt32   referenceWaveform,
                                                         ViInt32   bufferSize,
                                                         ViChar    waveformDataSource[],
                                                         ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_DATA_SOURCE,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_REFERENCE_WAVEFORM_DATA_SOURCE, bufferSize, waveformDataSource, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns information on the reference waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR xStart/Returns the X start value, the acquisition time before trigger in
/// HIPAR xStart/seconds.
/// HIPAR xStop/Returns the x stop value, the time after trigger in seconds.
/// HIPAR recordLength/Returns the record length of the waveform in Samples.
/// HIPAR valuesPerSample/Returns the number of values per sample interval.
ViStatus _VI_FUNC rsmxo_FetchReferenceWaveformHeader(ViSession instrSession,
                                                     ViInt32   referenceWaveform,
                                                     ViReal64* xStart,
                                                     ViReal64* xStop,
                                                     ViInt32*  recordLength,
                                                     ViReal64* valuesPerSample)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;
    ViReal64 header[4] = {0, 0, 0, 0};
    ViInt32  numberOfReturnedValues = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_REFERENCE_WAVEFORM_HEADER,
            "ReferenceWaveform", referenceWaveform - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Reference Waveform");

    checkErr(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, repCap, RSMXO_ATTR_REFERENCE_WAVEFORM_HEADER, NULL, 4, header, &numberOfReturnedValues));

    if (numberOfReturnedValues == 4)
    {
        if (xStart != NULL)
            *xStart = header[0];
        if (xStop != NULL)
            *xStop = header[1];
        if (recordLength != NULL)
            *recordLength = (ViInt32)floor(header[2]); // NOLINT(clang-diagnostic-bad-function-cast)
        if (valuesPerSample != NULL)
            *valuesPerSample = header[3];
    }
    else
    {
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a previously acquired waveform for this source. The
/// HIFN  acquisition must be made previously to calling this. Call this
/// HIFN  separately for each reference waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_FetchReferenceWaveform(ViSession instrSession,
                                               ViInt32   referenceWaveform,
                                               ViInt32   waveformArraySize,
                                               ViReal64  waveformData[],
                                               ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  referenceWaveformCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "ReferenceWaveform", &referenceWaveformCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, referenceWaveform, 1, referenceWaveformCount),
            2, "Reference Waveform");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FORM REAL,32;REFC%ld:DATA?", referenceWaveform);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, waveformArraySize, waveformData, returnedPoints));

Error:
    RsCore_Write(instrSession, "FORM ASCII");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an acquisition on all enabled channels, waits (up to
/// HIFN  maximumTimeMs) for the acquisition to complete, and returns the waveform
/// HIFN  for this channel. Call FetchWaveform to obtain the waveforms for other
/// HIFN  reference waveforms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceWaveform/Selects repeated capability ReferenceWaveform.
/// HIPAR maximumTimeMs/Specifies the maximum time the end-user allows for this method to
/// HIPAR maximumTimeMs/complete. PrecisionTimeSpan.Zero is used for immediate, and
/// HIPAR maximumTimeMs/PrecisionTimeSpan.MaxValue is used for infinite.
/// HIPAR waveformArraySize/Pass the number of elements in the Waveform Array parameter.
/// HIPAR waveformData/Returns the waveform that the oscilloscope acquires.
/// HIPAR returnedPoints/Indicates the number of points the function places in the Waveform
/// HIPAR returnedPoints/Array parameter.
ViStatus _VI_FUNC rsmxo_ReadReferenceWaveform(ViSession instrSession,
                                              ViInt32   referenceWaveform,
                                              ViInt32   maximumTimeMs,
                                              ViInt32   waveformArraySize,
                                              ViReal64  waveformData[],
                                              ViInt32*  returnedPoints)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_RunSingleAcquisition(instrSession, maximumTimeMs));

    checkErr(rsmxo_FetchReferenceWaveform(instrSession, referenceWaveform, waveformArraySize, waveformData, returnedPoints));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}


/// HIFN  The query returns the device name that is currently defined. The
/// HIFN  device name is required when configuring a network.
/// HIFN
/// HIFN     The setting command changes the device name. The change takes effect
/// HIFN  after the next reboot of the device.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deviceName/The query returns the device name that is currently defined. The
/// HIPAR deviceName/device name is required when configuring a network.
ViStatus _VI_FUNC rsmxo_ConfigureSystemHostName(ViSession instrSession,
                                                ViString  deviceName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_SYSTEM_NETWORK_HOSTNAME, deviceName),
            2, "Device Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the date of the internal calendar.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR year/Year to set on the instrument.
/// HIPAR month/Month to set on the instrument.
/// HIPAR day/Day to set on the instrument.
ViStatus _VI_FUNC rsmxo_ConfigureSystemDate(ViSession instrSession,
                                            ViInt32   year,
                                            ViInt32   month,
                                            ViInt32   day)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, year, 2012, 2099),
            2, "Year");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, month, 1, 12),
            3, "Month");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, day, 1, 31),
            4, "Day");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%ld,%ld,%ld", year, month, day);

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_HIDDEN_SYSTEM_DATE, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the date of the internal calendar.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR year/Year set on the instrument.
/// HIPAR month/Month set on the instrument.
/// HIPAR day/Day set on the instrument.
ViStatus _VI_FUNC rsmxo_QuerySystemDate(ViSession instrSession,
                                        ViInt32*  year,
                                        ViInt32*  month,
                                        ViInt32*  day)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  instrumentResponse[3];
    ViInt32  returnedPoints = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeViStringAsViInt32ArrayToUserBuffer(instrSession, NULL, RSMXO_ATTR_HIDDEN_SYSTEM_DATE, NULL, 3, instrumentResponse, &returnedPoints));

    if (returnedPoints == 3)
    {
        *year = instrumentResponse[0];
        *month = instrumentResponse[1];
        *day = instrumentResponse[2];
    }
    else
        error = RS_ERROR_UNEXPECTED_RESPONSE;

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the current time of the clock.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hours/Sets hour.
/// HIPAR minutes/Sets minutes.
/// HIPAR seconds/Sets seconds.
ViStatus _VI_FUNC rsmxo_ConfigureSystemTime(ViSession instrSession,
                                            ViInt32   hours,
                                            ViInt32   minutes,
                                            ViInt32   seconds)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, hours, 0, 24),
            2, "Hours");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, minutes, 0, 59),
            3, "Minutes");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, seconds, 0, 59),
            4, "Seconds");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%ld,%ld,%ld", hours, minutes, seconds);

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_HIDDEN_SYSTEM_TIME, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the current time of the clock.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hour/Hours value
/// HIPAR minutes/Minutes value
/// HIPAR seconds/Seconds value
ViStatus _VI_FUNC rsmxo_QuerySystemTime(ViSession instrSession,
                                        ViInt32*  hour,
                                        ViInt32*  minutes,
                                        ViInt32*  seconds)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  instrumentResponse[3];
    ViInt32  returnedPoints = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeViStringAsViInt32ArrayToUserBuffer(instrSession, NULL, RSMXO_ATTR_HIDDEN_SYSTEM_TIME, NULL, 3, instrumentResponse, &returnedPoints));

    if (returnedPoints == 3)
    {
        *hour = instrumentResponse[0];
        *minutes = instrumentResponse[1];
        *seconds = instrumentResponse[2];
    }
    else
        error = RS_ERROR_UNEXPECTED_RESPONSE;

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the data type that is used for transmission of data from
/// HIFN  analog channels, math and reference waveforms, and some measurement
/// HIFN  results from the instrument to the controlling computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR transferDataFormat/Selects the data type that is used for transmission of data from
/// HIPAR transferDataFormat/analog channels, math and reference waveforms, and some measurement
/// HIPAR transferDataFormat/results from the instrument to the controlling computer.
ViStatus _VI_FUNC rsmxo_ConfigureTransferDataFormat(ViSession instrSession,
                                                    ViInt32   transferDataFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_REMOTE_TRANSFER_DATA_FORMAT, transferDataFormat),
            2, "Transfer Data Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the number format for remote bit pattern queries on serial
/// HIFN  protocols.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bitpatternFormat/Sets the number format for remote bit pattern queries on serial
/// HIPAR bitpatternFormat/protocols.
ViStatus _VI_FUNC rsmxo_ConfigureBitpatternFormat(ViSession instrSession,
                                                  ViInt32   bitpatternFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_REMOTE_BITPATTERN_FORMAT, bitpatternFormat),
            2, "Bitpattern Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures display settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayUpdate/Defines whether the display is updated while the instrument is in the
/// HIPAR displayUpdate/remote state. If the display is switched off, the normal GUI is
/// HIPAR displayUpdate/replaced by a static image while the instrument is in the remote state.
/// HIPAR displayUpdate/Switching off the display can speed up the measurement. This is the
/// HIPAR displayUpdate/recommended state.
/// HIPAR displayMessage/Enables and disables the display of an additional text in remote
/// HIPAR displayMessage/control.
/// HIPAR message/Defines an additional text that is displayed during remote control
/// HIPAR message/operation.
ViStatus _VI_FUNC rsmxo_ConfigureDisplaySettings(ViSession instrSession,
                                                 ViBoolean displayUpdate,
                                                 ViBoolean displayMessage,
                                                 ViString  message)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_REMOTE_DISPLAY_UPDATE_ENABLED, displayUpdate),
            2, "Display Update");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_REMOTE_DISPLAY_MESSAGE_ENABLED, displayMessage),
            3, "Display Message");

    if (message != NULL)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_REMOTE_DISPLAY_MESSAGE, message),
                4, "Message");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a comma-separated list of valid signal names. The signale
/// HIFN  names are needed in other to use other color attributes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR signalNames/Returns a comma-separated list of valid signal names. The signale
/// HIPAR signalNames/names are needed in other to use other color controls.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QuerySignalNameCatalog(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    signalNames[],
                                               ViInt32*  bytesRead)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_GetAttributeViStringWithRealLen(instrSession, NULL, RSMXO_ATTR_COLORS_SIGNAL_NAME_CATALOG, bufferSize, signalNames, bytesRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the selected waveform is displayed according to its
/// HIFN  assigned color table.If disabled, the selected color is displayed, and
/// HIFN  the intensity of the signal color varies according to the cumulative
/// HIFN  occurrence of the values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR signalName/Selects a signal name to apply the setting to.
/// HIPAR enabled/Enables or disables the color table use.
ViStatus _VI_FUNC rsmxo_UseColorTable(ViSession instrSession,
                                      ViString  signalName,
                                      ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,%s", signalName, enabled ? "ON" : "OFF");

    viCheckParm(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_COLORS_USE_COLOR_TABLE, RS_VAL_DIRECT_USER_CALL, param),
                3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries if color table is used for the selected signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR signalName/Selects a signal name to apply the setting to.
/// HIPAR enabled/Enables or disables the color table use.
ViStatus _VI_FUNC rsmxo_QueryColorTableUse(ViSession  instrSession,
                                           ViString   signalName,
                                           ViBoolean* enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   instrumentResponse[RS_MAX_SHORT_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, NULL, RSMXO_ATTR_HIDDEN_COLORS_USE_COLOR_TABLE, signalName, RS_MAX_MESSAGE_BUF_SIZE, instrumentResponse, NULL));

    *enabled = RsCore_Convert_String_To_Boolean(instrumentResponse);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Assigns a color table to the source waveform instead of a dedicated
/// HIFN  color.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR signalName/Selects a signal name to apply the setting to.
/// HIPAR colorTable/Assigns a color table to the source waveform instead of a dedicated
/// HIPAR colorTable/color. Color tables define the color of the waveform pixels depending
/// HIPAR colorTable/on the cumulative occurrence of the associated values.
ViStatus _VI_FUNC rsmxo_AssignColorTable(ViSession instrSession,
                                         ViString  signalName,
                                         ViInt32   colorTable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar*  p2colorTableCmd;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsMxo_rngColorTable, colorTable, &p2colorTableCmd),
                3, "Color Table");

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,\"%s\"", signalName, p2colorTableCmd);

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_COLORS_ASSIGNED_COLOR_TABLE, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the color table assigned to the source waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR signalName/Selects a signal name to apply the setting to.
ViStatus _VI_FUNC rsmxo_QueryAssignedColorTable(ViSession instrSession,
                                                ViString  signalName,
                                                ViInt32*  colorTable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   response[RS_MAX_SHORT_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, NULL, RSMXO_ATTR_HIDDEN_COLORS_ASSIGNED_COLOR_TABLE, signalName, RS_MAX_SHORT_MESSAGE_BUF_SIZE, response, NULL));

    viCheckParm(RsCore_FindRangeTableDiscreteNumericValue(instrSession, &RsMxo_rngColorTable, response, colorTable),
                3, "Color Table");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the color of the selected waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR signalName/Selects a signal name to apply the setting to.
/// HIPAR color/Decimal value of the ARGB color. Use the color dialog box on the
/// HIPAR color/instrument to get the hex value of the color, and convert the hex value
/// HIPAR color/to a decimal value.
ViStatus _VI_FUNC rsmxo_SelectSignalColor(ViSession instrSession,
                                          ViString  signalName,
                                          ViInt32   color)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    (void)snprintf(param, RS_PARAM_BUF_SIZE, "%s,%ld", signalName, color);

    checkErr(RsCore_SetAttributeViRawString(instrSession, NULL, RSMXO_ATTR_HIDDEN_COLORS_SELECT_COLOR, RS_VAL_DIRECT_USER_CALL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the decimal value of the color selected for the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR signalName/Selects a signal name to apply the setting to.
/// HIPAR color/Decimal value of the ARGB color. Use the color dialog box on the
/// HIPAR color/instrument to get the hex value of the color, and convert the hex value
/// HIPAR color/to a decimal value.
ViStatus _VI_FUNC rsmxo_QuerySelectedSignalColor(ViSession instrSession,
                                                 ViString  signalName,
                                                 ViInt32*  color)
{
    ViStatus error = VI_SUCCESS;
    ViChar   instrumentResponse[RS_MAX_SHORT_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, NULL, RSMXO_ATTR_HIDDEN_COLORS_SELECT_COLOR, signalName, RS_MAX_SHORT_MESSAGE_BUF_SIZE, instrumentResponse, NULL));

    *color = RsCore_Convert_String_To_ViInt32(instrumentResponse);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures grid appearance.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR showGrid/If selected, a grid is displayed in the diagram area. A grid helps you
/// HIPAR showGrid/associate a specific data point to its exact value on the x- or y-axis.
/// HIPAR showLabels/If selected, labels mark values on the x- and y-axes in specified
/// HIPAR showLabels/intervals in the diagram.
/// HIPAR keepYGridFixed/If enabled, the horizontal grid lines remain in their position when
/// HIPAR keepYGridFixed/the position of the curve is changed. Only the values at the grid lines
/// HIPAR keepYGridFixed/are adapted.Fixed horizontal grid lines correspond to the behavior of
/// HIPAR keepYGridFixed/traditional oscilloscopes.
/// HIPAR showFineGridScale/If selected, the crosshair is displayed as a ruler with scale markers.
/// HIPAR showFineGridScale/If disabled, the crosshair is shown as dashed lines.
/// HIPAR showCrosshair/If selected, a crosshair is displayed in the diagram area. A crosshair
/// HIPAR showCrosshair/allows you to select a specific data point by its co-ordinates.
ViStatus _VI_FUNC rsmxo_ConfigureGridAppearance(ViSession instrSession,
                                                ViBoolean showGrid,
                                                ViBoolean showLabels,
                                                ViBoolean showFineGridScale,
                                                ViBoolean showCrosshair,
                                                ViBoolean keepYGridFixed)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_GRID_SHOW, showGrid),
            2, "Show Grid");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_GRID_SHOW_LABELS, showLabels),
            3, "Show Labels");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_GRID_SHOW_FINE_GRID_SCALE, showFineGridScale),
            4, "Show Fine Grid Scale");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_GRID_SHOW_CROSSHAIR, showCrosshair),
            5, "Show Crosshair");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_GRID_KEEP_Y_GRID_FIXED, keepYGridFixed),
            6, "Keep Y Grid Fixed");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the selected smartgrid node.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR node/Selects a value for the node repeated capability.
/// HIPAR enabled/Enables or disables the smartgrid.
ViStatus _VI_FUNC rsmxo_EnableSmartGridNode(ViSession instrSession,
                                            ViInt32   layout,
                                            ViInt32   node,
                                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_ENABLED,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_NODE, node),
            3, "Node");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_SMART_GRID_NODE_ENABLED, enabled),
            4, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns count value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR count/Returns count value.
/// HIPAR node/Selects a value for the node repeated capability.
ViStatus _VI_FUNC rsmxo_QuerySmartGridNodeCount(ViSession instrSession,
                                                ViInt32   layout,
                                                ViInt32   node,
                                                ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_ENABLED,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_NODE, node),
            3, "Node");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_SMART_GRID_NODE_COUNT, count),
            4, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a new SmartGrid configuration and sets it active.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR enabled/Creates a new SmartGrid configuration and sets it active.
/// HIPAR label/Defines a name for the specified layout (SmartGrid configuration).
ViStatus _VI_FUNC rsmxo_AddSmartGridLayout(ViSession instrSession,
                                           ViInt32   layout,
                                           ViBoolean enabled,
                                           ViString  label)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_LAYOUT_ENABLED,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_SMART_GRID_LAYOUT_ENABLED, enabled),
            3, "Enabled");

    if (enabled)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_SMART_GRID_LAYOUT_LABEL, label),
                4, "Label");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of available layouts, i.e. SmartGrid
/// HIFN  configurations. By default, they named Diagram Set on the display.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layoutCount/Returns the number of available layouts, i.e. SmartGrid
/// HIPAR layoutCount/configurations. By default, they named Diagram Set on the display.
ViStatus _VI_FUNC rsmxo_QuerySmartGridLayoutCount(ViSession instrSession,
                                                  ViInt32*  layoutCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_LAYOUT_COUNT, layoutCount),
            2, "Layout Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets and queries the active SmartGrid configuration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR active/Sets and queries the active SmartGrid configuration.
ViStatus _VI_FUNC rsmxo_ConfigureSmartGridLayoutActive(ViSession instrSession,
                                                       ViInt32   active)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_LAYOUT_ACTIVE, active),
            2, "Active");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets an element ID.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR node/Selects a value for the node repeated capability.
/// HIPAR child/Selects repeated capability SmartgridChild.
/// HIPAR content/Selects a value for the contents repeated capability.
/// HIPAR id/Sets an element ID.
ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeID(ViSession instrSession,
                                                 ViInt32   layout,
                                                 ViInt32   node,
                                                 ViInt32   child,
                                                 ViInt32   content,
                                                 ViInt32   id)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCapSecond[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViInt32  childrenCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_ID,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SmartgridChild", &childrenCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, child, 1, childrenCount),
            4, "Child");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_ID, "SmartgridChild", child - 1, RS_REPCAP_BUF_SIZE, repCapSecond),
                4, "Child");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapSecond, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_NODE, node),
            3, "Node");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_CONTENTS, content),
            5, "Content");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_SMART_GRID_NODE_ID, id),
            6, "ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the type of a selected Smart Grid element.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR node/Selects a value for the node repeated capability.
/// HIPAR child/Selects repeated capability SmartgridChild.
/// HIPAR content/Selects a value for the contents repeated capability.
/// HIPAR smartGridType/Selects the type of a selected Smart Grid element.
ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeType(ViSession instrSession,
                                                   ViInt32   layout,
                                                   ViInt32   node,
                                                   ViInt32   child,
                                                   ViInt32   content,
                                                   ViInt32   smartGridType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCapSecond[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViInt32  childrenCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_TYPE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "SmartgridChild", &childrenCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, child, 1, childrenCount),
            4, "Child");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_TYPE, "SmartgridChild", child - 1, RS_REPCAP_BUF_SIZE, repCapSecond),
                4, "Child");

    checkErr(RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCapSecond, NULL));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_NODE, node),
            3, "Node");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_CONTENTS, content),
            5, "Content");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_SMART_GRID_NODE_TYPE, smartGridType),
            6, "Smart Grid Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the ratio between Smart Grid elements on the screen.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR node/Selects a value for the node repeated capability.
/// HIPAR splitRatio/Sets the ratio between Smart Grid elements on the screen.
ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeSplitRatio(ViSession instrSession,
                                                         ViInt32   layout,
                                                         ViInt32   node,
                                                         ViReal64  splitRatio)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_SPLIT_RATIO,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_NODE, node),
            3, "Node");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, repCap, RSMXO_ATTR_SMART_GRID_NODE_SPLIT_RATIO, splitRatio),
            4, "Split Ratio");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the split type between specified Smart Grid elements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR node/Selects a value for the node repeated capability.
/// HIPAR splitType/Selects the split type between specified Smart Grid elements.
ViStatus _VI_FUNC rsmxo_ConfigureSmartGridNodeSplitType(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   node,
                                                        ViInt32   splitType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_NODE_SPLIT_TYPE,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_SMART_GRID_SELECTED_NODE, node),
            3, "Node");

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_SMART_GRID_NODE_SPLIT_TYPE, splitType),
            4, "Split Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates and displays a specified diagram in a specified layout.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     RSMXO_ATTR_SMART_GRID_DIAGRAM_ENABLED
/// HIFN     RSMXO_ATTR_SMART_GRID_DIAGRAM_LABEL
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     LAYout<m>:DIAGram<n>[:ENABle]
/// HIFN     LAYout<m>:DIAGram<n>:LABel
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR diagram/Selects repeated capability DiagramRC.
/// HIPAR enabled/Creates and displays a specified diagram in a specified layout. OFF
/// HIPAR enabled/deletes the diagram.
/// HIPAR label/Defines a name for the specified diagram in a specified layout.
ViStatus _VI_FUNC rsmxo_AddSmartGridDiagram(ViSession instrSession,
                                            ViInt32   layout,
                                            ViInt32   diagram,
                                            ViBoolean enabled,
                                            ViString  label)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   layoutRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   diagramRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViInt32  diagramCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_DIAGRAM_ENABLED, "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, layoutRepCap),
                2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DiagramRC", &diagramCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, diagram, 1, diagramCount),
            3, "Diagram");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_DIAGRAM_ENABLED, "DiagramRC", diagram - 1, RS_REPCAP_BUF_SIZE, diagramRepCap),
                3, "Diagram");

    (void)snprintf(repCap, RS_REPCAP_BUF_SIZE, "%s,%s", layoutRepCap, diagramRepCap);

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, repCap, RSMXO_ATTR_SMART_GRID_DIAGRAM_ENABLED, enabled),
            4, "Enabled");

    if (enabled)
    {
        viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_SMART_GRID_DIAGRAM_LABEL, label),
                5, "Label");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the number of diagrams in a specified layout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR diagramCount/Returns the number of diagrams in a specified layout.
ViStatus _VI_FUNC rsmxo_QuerySmartGridDiagramCount(ViSession instrSession,
                                                   ViInt32   layout,
                                                   ViInt32*  diagramCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_DIAGRAM_COUNT,
            "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Layout");

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, repCap, RSMXO_ATTR_SMART_GRID_DIAGRAM_COUNT, diagramCount),
            3, "Diagram Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Assigns the waveforms to a diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layout/Selects repeated capability LayoutSet.
/// HIPAR diagram/Selects repeated capability DiagramRC.
/// HIPAR source/Assigns the waveforms to a diagram.
ViStatus _VI_FUNC rsmxo_ConfigureSmartGridDiagramSource(ViSession instrSession,
                                                        ViInt32   layout,
                                                        ViInt32   diagram,
                                                        ViString  source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   layoutRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   diagramRepCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  layoutCount = 0;
    ViInt32  diagramCount = 0;

    checkErr(RsCore_LockSession(instrSession));

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "LayoutSet", &layoutCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layout, 1, layoutCount),
            2, "Layout");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_DIAGRAM_SOURCE, "LayoutSet", layout - 1, RS_REPCAP_BUF_SIZE, layoutRepCap),
                2, "Layout");

    (void)RsCore_GetRepCapIdItemsCount(instrSession, "DiagramRC", &diagramCount);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, diagram, 1, diagramCount),
            3, "Diagram");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSMXO_ATTR_SMART_GRID_DIAGRAM_SOURCE, "DiagramRC", diagram - 1, RS_REPCAP_BUF_SIZE, diagramRepCap),
                3, "Diagram");

    (void)snprintf(repCap, RS_REPCAP_BUF_SIZE, "%s,%s", layoutRepCap, diagramRepCap);

    viCheckParm(rsmxo_SetAttributeViString(instrSession, repCap, RSMXO_ATTR_SMART_GRID_DIAGRAM_SOURCE, source),
            4, "Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures display settings for signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR style/Selects the style in which the waveform is displayed.
/// HIPAR intensity/The intensity determines the strength of the waveform line in the
/// HIPAR intensity/diagram. Enter a percentage between 0 (not visible) and 100% (strong).
/// HIPAR intensity/The default value is 50%.
ViStatus _VI_FUNC rsmxo_ConfigureDisplaySignalSettings(ViSession instrSession,
                                                       ViInt32   style,
                                                       ViReal64  intensity)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_DISPLAY_SIGNAL_STYLE, style),
            2, "Style");

    viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_DISPLAY_SIGNAL_INTENSITY, intensity),
            3, "Intensity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures persistence display settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/If enabled, each new data point in the diagram area remains on the
/// HIPAR enable/screen for the duration defined using
/// HIPAR enable/RSMXO_ATTR_DISPLAY_PERSISTENCE_TIME, or as long as
/// HIPAR enable/RSMXO_ATTR_DISPLAY_PERSISTENCE_INFINITE is enabled.
/// HIPAR infinitePersistence/If infinite persistence is enabled, each new waveform point remains on
/// HIPAR infinitePersistence/the screen until this option is disabled. Use infinite persistence to
/// HIPAR infinitePersistence/display rare events in the signal.
/// HIPAR time/Sets a time factor that controls how long the waveforms points fade
/// HIPAR time/away from the display.  Thus, the R&SMXO4 emulates the persistence of
/// HIPAR time/analog phosphor screens.
ViStatus _VI_FUNC rsmxo_ConfigureDisplayPersistenceSettings(ViSession instrSession,
                                                            ViBoolean enable,
                                                            ViBoolean infinitePersistence,
                                                            ViReal64  time)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_DISPLAY_PERSISTENCE_ENABLED, enable),
            2, "Enable");

    if (enable == VI_TRUE)
    {
        viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_DISPLAY_PERSISTENCE_INFINITE, infinitePersistence),
                3, "Infinite Persistence");

        if (infinitePersistence == VI_FALSE)
        {
            viCheckParm(rsmxo_SetAttributeViReal64(instrSession, NULL, RSMXO_ATTR_DISPLAY_PERSISTENCE_TIME, time),
                    4, "Time");
        }
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the background luminosity of the touchscreen.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR backlightBrightness/Sets the background luminosity of the touchscreen.
ViStatus _VI_FUNC rsmxo_ConfigureDisplayBacklightBrightness(ViSession instrSession,
                                                            ViInt32   backlightBrightness)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_DISPLAY_BACKLIGHT_BRIGHTNESS, backlightBrightness),
            2, "Backlight Brightness");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects a time, after which the monitor brightness is reduced, if the
/// HIFN  instrument was inactive. Remote control of the instrument is also
/// HIFN  considered as an activity.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dimmAfter/Selects a time, after which the monitor brightness is reduced, if the
/// HIPAR dimmAfter/instrument was inactive. Remote control of the instrument is also
/// HIPAR dimmAfter/considered as an activity.
ViStatus _VI_FUNC rsmxo_ConfigureDisplayBacklightDimmOnUserInactivity(
                            ViSession instrSession,
                            ViInt32   dimmAfter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_DISPLAY_BACKLIGHT_DIMM_ON_USER_INACTIVITY, dimmAfter),
            2, "Dimm After");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes all measurement results including all waveforms and
/// HIFN  statistics.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_DisplayClearResults(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_DISPLAY_CLEAR_RESULTS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Resets the display, removing persistent all waveform points.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ResetDisplayPersistenceSettings(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_DISPLAY_PERSISTENCE_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If enabled, the instrument powers up automatically when it is
/// HIFN  connected to the mains voltage.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoPowerUp/If enabled, the instrument powers up automatically when it is
/// HIPAR autoPowerUp/connected to the mains voltage.
ViStatus _VI_FUNC rsmxo_EnableAutoPowerUp(ViSession instrSession,
                                          ViBoolean autoPowerUp)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_AUTO_POWER_UP_ENABLED, autoPowerUp),
            2, "Auto Power Up");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN Executes an internal self-alignment of the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR maximumTimeMs/Specifies the maximum time in milliseconds for this method to complete.
/// HIPAR maximumTimeMs/Value 0 means current OPC timeout (rsmxo_SetOPCTimeout).
/// HIPAR maximumTimeMs/After that, the function ends with timeout error.
ViStatus _VI_FUNC rsmxo_ExecuteAlignment(ViSession instrSession,
                                         ViInt32   maximumTimeMs)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  oldTimeout = -1;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_GetOPCTimeout(instrSession, &oldTimeout));

    if (maximumTimeMs > 0)
    {
        checkErr(rsmxo_SetOPCTimeout(instrSession, maximumTimeMs));
    }

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_EXECUTE_ALIGNMENT, NULL));

Error:
    if (oldTimeout > 0)
        rsmxo_SetOPCTimeout(instrSession, oldTimeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the date of the last selfalignment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR date/Returns the date of the last selfalignment.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryAlignmentDate(ViSession instrSession,
                                           ViChar    date[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViString(instrSession, NULL, RSMXO_ATTR_ALIGNMENT_DATE,
            RS_MAX_SHORT_MESSAGE_BUF_SIZE, date),
            2, "Date");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the time of the last selfalignment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR time/Returns the time of the last selfalignment.
/// HIPAR bytesRead/Returns the number of bytes read from instrument.
ViStatus _VI_FUNC rsmxo_QueryAlignmentTime(ViSession instrSession,
                                           ViChar    time[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViString(instrSession, NULL, RSMXO_ATTR_ALIGNMENT_TIME,
            RS_MAX_SHORT_MESSAGE_BUF_SIZE, time),
            2, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the result of the last selfalignment and the current alignment
/// HIFN  status. In remote mode, *CAL? provides more detailed information.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR result/Returns the result of the last selfalignment and the current alignment
/// HIPAR result/status. In remote mode, *CAL? provides more detailed information.
ViStatus _VI_FUNC rsmxo_QueryAlignmentResult(ViSession instrSession,
                                             ViInt32*  result)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_GetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_ALIGNMENT_RESULT, result),
            2, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the list separator symbol from a list. Available are
/// HIFN  semicolon, comma, space, tab and colon.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR delimiter/Selects the list separator symbol from a list. Available are
/// HIPAR delimiter/semicolon, comma, space, tab and colon.
ViStatus _VI_FUNC rsmxo_ConfigureCSVDelimiter(ViSession instrSession,
                                              ViInt32   delimiter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_CSV_DELIMITER, delimiter),
            2, "Delimiter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the automatic saving of the waveform.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autosave/Enables the automatic saving of the waveform. You can set the autosave
/// HIPAR autosave/interval with RSMXO_ATTR_AUTONAMING_AUTOSAVE_INTERVAL.
/// HIPAR interval/Defines the time  interval for the automatic saving of the waveform,
/// HIPAR interval/if RSMXO_ATTR_AUTONAMING_AUTOSAVE_ENABLE is set to ON.
ViStatus _VI_FUNC rsmxo_ConfigureAutosaveSettings(ViSession instrSession,
                                                  ViBoolean autosave,
                                                  ViInt32   interval)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_AUTONAMING_AUTOSAVE_ENABLE, autosave),
            2, "Auto Save");

    if (autosave)
    {
        viCheckParm(rsmxo_SetAttributeViInt32(instrSession, NULL, RSMXO_ATTR_AUTONAMING_AUTOSAVE_INTERVAL, interval),
                3, "Interval");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Includes or excludes the prefix/ date/time /index in the file name
/// HIFN  pattern for automatic file name generation. This name is used as the
/// HIFN  default file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR userText/If enabled, inserts the specified user text after the prefix.
/// HIPAR prefix/Includes or excludes the prefix in the file name pattern for automatic
/// HIPAR prefix/file name generation. This name is used as the default file name.
/// HIPAR date/time/Includes or excludes the date/time in the file name pattern for
/// HIPAR date/time/automatic file name generation. This name is used as the default file
/// HIPAR date/time/name.
/// HIPAR index/Includes or excludes the index in the file name pattern for automatic
/// HIPAR index/file name generation. This name is used as the default file name.
ViStatus _VI_FUNC rsmxo_ConfigureAutonamingPattern(ViSession instrSession,
                                                   ViBoolean userText,
                                                   ViBoolean prefix,
                                                   ViBoolean dateTime,
                                                   ViBoolean index)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_AUTONAMING_USER_TEXT_ENABLED, userText),
            2, "User Text");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_AUTONAMING_PREFIX, prefix),
            3, "Prefix");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_AUTONAMING_DATE_TIME, dateTime),
            4, "Date/Time");

    viCheckParm(rsmxo_SetAttributeViBoolean(instrSession, NULL, RSMXO_ATTR_AUTONAMING_INDEX, index),
            5, "Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a text, that can be included in the autonaming pattern.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR userText/Defines a text, that can be included in the autonaming pattern.
ViStatus _VI_FUNC rsmxo_ConfigureAutonamingUserText(ViSession instrSession,
                                                    ViString  userText)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_AUTONAMING_USER_TEXT, userText),
            2, "User Text");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the path where data and settings files will be stored.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Sets the path where data and settings files will be stored.
ViStatus _VI_FUNC rsmxo_ConfigureDefaultPathForAllFileOperations(
                            ViSession instrSession,
                            ViString  path)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_AUTONAMING_DEFAULT_PATH_FOR_ALL_FILE_OPERATIONS, path),
            2, "Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the path for file operations to the factory default path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ResetPath(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_AUTONAMING_RESET_PATH, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets all autonaming settings to the default value, including the
/// HIFN  path.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ResetAllAutonamingSettings(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_SetAttributeViString(instrSession, NULL, RSMXO_ATTR_AUTONAMING_RESET_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns true, if the instrument has completed the measurement/acquisition.
/// HIFN Please note, that this only works in the single acquisition mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR isMeasurementComplete/Defines timeout in milliseconds.
ViStatus _VI_FUNC rsmxo_IsMeasurementComplete(ViSession  instrSession,
                                              ViBoolean* isMeasurementComplete)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  val = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViInt32(instrSession, "STAT:OPER:COND?", &val));
    *isMeasurementComplete = (val & 0x10) == 0;

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Waits until the instrument has completed the measurement/acquisition.
/// HIFN Please note, that this only works in the single acquisition mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR timeout/Defines timeout in milliseconds.
ViStatus _VI_FUNC rsmxo_WaitForMeasurementComplete(ViSession instrSession,
                                                   ViInt32   timeout)
{
    ViStatus  error = VI_SUCCESS;
    ViBoolean measurement_complete = VI_FALSE;
    clock_t   startTime = clock();
    ViReal64  elapsedTime;

    // ReSharper disable once CppEqualOperandsInBinaryExpression
    ViReal64 msDivider = (ViReal64)CLOCKS_PER_SEC / (ViReal64)1000.0;


    checkErr(RsCore_LockSession(instrSession));

    do
    {
        checkErr(rsmxo_IsMeasurementComplete(instrSession, &measurement_complete));

        elapsedTime = ((double)clock() - (double)startTime) / msDivider; // NOLINT(clang-diagnostic-bad-function-cast)
        if (elapsedTime > timeout)
            return VI_ERROR_TMO;

        if (elapsedTime < 10.0)
        {
            // Do it as fast as possible
        }
        else if (elapsedTime < 100.0)
            Sleep(1);
        else if (elapsedTime < 1000.0)
            Sleep(5);
        else if (elapsedTime < 5000.0)
            Sleep(10);
        else if (elapsedTime < 10000.0)
            Sleep(50);
        else if (elapsedTime < 20000.0)
            Sleep(100);
        else if (elapsedTime < 30000.0)
            Sleep(500);
        else
            Sleep(1000);
    }
    while (!measurement_complete);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns true, if the instrument is in the ARMED state: that means,
/// HIFN it is ready to react on a trigger event. Please note, this only
/// HIFN works in the single acquisition mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR isMeasurementComplete/Defines timeout in milliseconds.
ViStatus _VI_FUNC rsmxo_IsWaitingForTrigger(ViSession  instrSession,
                                            ViBoolean* isMeasurementComplete)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  val = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViInt32(instrSession, "STAT:OPER:COND?", &val));
    *isMeasurementComplete = (val & 0x30) == 0x30;

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Waits until the instrument is in the ARMED state: that means,
/// HIFN it is ready to react on a trigger event. Please note, that this
/// HIFN only works in the single acquisition mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR timeout/Defines timeout in milliseconds.
ViStatus _VI_FUNC rsmxo_WaitForWaitingForTrigger(ViSession instrSession,
                                                 ViInt32   timeout)
{
    ViStatus  error = VI_SUCCESS;
    ViBoolean measurement_complete = VI_FALSE;
    clock_t   startTime = clock();
    ViReal64  elapsedTime;

    // ReSharper disable once CppEqualOperandsInBinaryExpression
    ViReal64 msDivider = (ViReal64)CLOCKS_PER_SEC / (ViReal64)1000.0;


    checkErr(RsCore_LockSession(instrSession));

    do
    {
        checkErr(rsmxo_IsWaitingForTrigger(instrSession, &measurement_complete));

        elapsedTime = ((double)clock() - (double)startTime) / msDivider; // NOLINT(clang-diagnostic-bad-function-cast)
        if (elapsedTime > timeout)
            return VI_ERROR_TMO;

        if (elapsedTime < 10.0)
        {
            // As fast as possible
        }
        else if (elapsedTime < 100.0)
            Sleep(1);
        else if (elapsedTime < 1000.0)
            Sleep(5);
        else if (elapsedTime < 5000.0)
            Sleep(10);
        else if (elapsedTime < 10000.0)
            Sleep(50);
        else if (elapsedTime < 20000.0)
            Sleep(100);
        else if (elapsedTime < 30000.0)
            Sleep(500);
        else
            Sleep(1000);
    }
    while (!measurement_complete);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN This function resets the instrument to a known state and sends initialization commands to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
ViStatus _VI_FUNC rsmxo_reset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  opc;

    checkErr(RsCore_LockSession(instrSession));

    if (RsCore_Simulating(instrSession) == VI_FALSE)
    {
        checkErr(rsmxo_ClearStatus(instrSession));
        checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
        checkErr(rsmxo_QueryOPC(instrSession, &opc));
    }

    checkErr(rsmxo_DefaultInstrSetup(instrSession));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN This function returns the driver and instrument revisions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR driverRev/Returns the instrument driver software revision numbers in the form of a string.
/// HIPAR instrRev/Returns the instrument firmware revision numbers in the form of a string.
ViStatus _VI_FUNC rsmxo_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Driver Revision");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION,
        0, 256, instrumentDriverRevision));
    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION,
        0, 256, firmwareRevision));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function reads an error code and a message from the
/// HIFN instrument's error queue.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR errCode/Returns the error code read from the instrument's error queue.
/// HIPAR errMessage/Returns the error message string read from the instrument's error message queue.
ViStatus _VI_FUNC rsmxo_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function converts a status code returned by an instrument driver function into a user-readable string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR errorCode/Pass the Status parameter that is returned from any of the instrument driver functions.
/// HIPAR errorMessage/Returns the user-readable message string that corresponds to the status code you specify.
ViStatus _VI_FUNC rsmxo_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[])
{
    return rsmxo_utility_error_message(instrSession, errorCode, errorMessage);
}

/// HIFN Queries the error/event queue for all unread items and removes them from the queue. The response is a comma separated
/// HIFN list of error number and a short description of the error in FIFO order.
/// HIFN Positive error numbers are instrument-dependent. Negative error numbers are reserved by the SCPI standard.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Description parameter.
/// HIPAR bufferSize/If the error description is longer, it is truncated and properly 0-terminated.
/// HIPAR errors/Returns the error list in FIFO order.
ViStatus _VI_FUNC rsmxo_ErrorList(ViSession instrSession,
                                  ViInt32   bufferSize,
                                  ViChar    errors[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_GetAttributeViString(instrSession, NULL, RSMXO_ATTR_SYSTEM_ERROR_LIST, bufferSize, errors));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rsmxo_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    rsSession->optionChecking = optionChecking;
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN This function sets OPC timeout value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR timeout/Timeout value
ViStatus _VI_FUNC rsmxo_SetOPCTimeout(ViSession instrSession,
                                      ViInt32   timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, timeout));

Error:
    return error;
}

/// HIFN This function gets OPC timeout value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR timeout/Timeout value
ViStatus _VI_FUNC rsmxo_GetOPCTimeout(ViSession instrSession,
                                      ViInt32*  timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, timeout));

Error:
    return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR VISATimeout/This control sets the timeout value.
ViStatus _VI_FUNC rsmxo_SetVISATimeout(ViSession instrSession,
                                       ViInt32   VISATimeout)
{
    return RsCore_SetVisaTimeout(instrSession, VISATimeout);
}

/// HIFN This function returns the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR VISATimeout/This control gets the timeout value.
ViStatus _VI_FUNC rsmxo_GetVISATimeout(ViSession instrSession,
                                       ViInt32*  VISATimeout)
{
    return RsCore_GetVisaTimeout(instrSession, (ViUInt32*)VISATimeout);
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ClearStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ClearStatus(instrSession));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR IDQueryResponse/Returns the ID Query response string.
ViStatus _VI_FUNC rsmxo_IDQueryResponse(ViSession instrSession,
                                        ViChar    IDQueryResponse[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_QueryViString(instrSession, "*IDN?", 256, IDQueryResponse));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops further command processing until all commands sent before
/// HIFN  *WAI have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsmxo_ProcessAllPreviousCommands(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_WriteInstrData(instrSession, "*WAI"));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR OPC/Queries the OPC.
ViStatus _VI_FUNC rsmxo_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsmxo_QueryViInt32(instrSession, "*OPC?", OPC));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Switches OPC-synchronization ON/OFF for writes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Switches OPC-synchronization ON/OFF for writes.
ViStatus _VI_FUNC rsmxo_OPCSyncWriteEnable(ViSession instrSession,
                                           ViBoolean enable)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->opcSyncAttrWrites = enable;

Error:
    return error;
}

/// HIFN  Switches OPC-synchronization ON/OFF for queries.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Switches OPC-synchronization ON/OFF for queries.
ViStatus _VI_FUNC rsmxo_OPCSyncQueryEnable(ViSession instrSession,
                                           ViBoolean enable)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->opcSyncAttrQueries = enable;

Error:
    return error;
}

/// HIFN  Sets the mechanism which is used for OPC-synchronised queries (valid 
/// HIFN  for read attributes and all OPC-synchronised queries):
/// HIFN     Default value: 'useEsb' = true, 'clsBefore' = true, 'useMav' = false
/// HIFN     
/// HIFN     Scenario A: useEsb = true:
/// HIFN     The query command is appended by the ';*OPC', and the wait loop ends 
/// HIFN  if the ESB bit signals that the command was completed, or the ERRQ (bit 
/// HIFN  2) signals an error.
/// HIFN         - clsBefore has no effect and is always set to true.
/// HIFN         - set the 'useMav' to true, to enable the opc-wait loop 
/// HIFN  sucessfully finish if the MAV bit signals, that the response is 
/// HIFN  available, even if the ESB bit is still 0.
/// HIFN     
/// HIFN     Scenario B: useEsb = false:
/// HIFN     The query command is not appended by the ';*OPC', and the wait loop 
/// HIFN  ends if the MAV bit signals that the message is available, or the ERRQ 
/// HIFN  (bit 2) signals an error.
/// HIFN         - clsBefore causes sending query *STB? before sending the command 
/// HIFN  to clear the error queue and output buffers.
/// HIFN         - useMav has no effect, and is always set to true.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or 
/// HIPAR instrSession/rsmxo_InitWithOptions function.The handle identifies a particular 
/// HIPAR instrSession/instrument session.
/// HIPAR useESB/Switches queries OPC-synchronization to use the Event Status Bit.
/// HIPAR clsBefore/Switches queries OPC-synchronization to use call the Clear Before 
/// HIPAR clsBefore/Read procedure before sending the query.
/// HIPAR useMAV/Switches queries OPC-synchronization to react on Message Available bit (MAV)
ViStatus _VI_FUNC rsmxo_SetOpcSyncQueryMechanism(ViSession instrSession,
    ViBoolean useEsb, ViBoolean clsBefore, ViBoolean useMav)
{
    return RsCore_SetOpcSyncQueryMechanism(instrSession, useEsb, clsBefore, useMav);
}

/// HIFN This function retrieves and then clears the error information
/// HIFN for the session or the current execution thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR errorCode/Returns the error code for the session or execution thread.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Description parameter.
/// HIPAR description/Returns the error description for the session or execution thread. If there is no description, the function returns an empty string.
ViStatus _VI_FUNC rsmxo_GetError(ViSession instrSession,
                                 ViStatus* errorCode,
                                 ViInt32   bufferSize,
                                 ViChar    description[])
{
    ViStatus error = VI_SUCCESS;

    // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
    (void)(RsCore_LockSession(instrSession));

    // Test for nulls and acquire error data
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

    checkErr(
        RsCore_GetErrorCompleteDescription(instrSession, &rsmxo_utility_error_message, errorCode, bufferSize, description));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function clears the error code and error description for
/// HIFN the session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
ViStatus _VI_FUNC rsmxo_ClearError(ViSession instrSession)
{
    return RsCore_ClearErrorInfo(instrSession);
}

/// HIFN This function writes a user-specified string to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
ViStatus _VI_FUNC rsmxo_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer)
{
    return RsCore_Write(instrSession, writeBuffer);
}

/// HIFN This function queries the ViBoolean value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViBoolean value.
ViStatus _VI_FUNC rsmxo_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");
    checkErr(RsCore_QueryViBoolean(instrSession, command, value));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViInt32 value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViInt32 value.
ViStatus _VI_FUNC rsmxo_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");
    checkErr(RsCore_QueryViInt32(instrSession, command, value));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViReal64 value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR value/Returns the ViReal64 value.
ViStatus _VI_FUNC rsmxo_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");
    checkErr(RsCore_QueryViReal64(instrSession, command, value));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function queries the ViString value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR command/The query to be sent to the instrument.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Value parameter.
/// HIPAR value/Returns the string value.
ViStatus _VI_FUNC rsmxo_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[])
{
    ViStatus error = VI_SUCCESS;
    ViChar*  extBuf = NULL;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, command, &extBuf));
    RsCore_CopyToUserBufferAsciiData(value, bufferSize, extBuf);

Error:
    if (extBuf) free(extBuf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sends a command to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for an instrument operation that can
/// HIFN take a long time to complete, e.g. self-alignment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsmxo_WriteCommandWithOPCSync(ViSession instrSession,
                                                ViString  writeBuffer,
                                                ViInt32   timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_WriteWithOpc(instrSession, writeBuffer, timeout));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function is used to read data from the instrument and write
 /// HIFN it to a user specified file on the host computer.
 /// HIRET Returns the status code of this operation.
 /// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
 /// HIPAR instrSession/function to select the desired instrument driver session.
 /// HIPAR source/This control selects file for the data transfer from instrument
 /// HIPAR source/to control computer.
 /// HIPAR destination/This control defines destination file to which the data transfer
 /// HIPAR destination/from instrument to control computer applies.
ViStatus _VI_FUNC rsmxo_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  source,
                                                 ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", source);
    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN This function is used to read data from the host computer and
/// HIFN write it to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control
/// HIPAR source/computer to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from control computer to instrument applies.
ViStatus _VI_FUNC rsmxo_WriteFromFileToInstrument(ViSession instrSession,
                                                  ViString  source,
                                                  ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
    checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
    checkErr(rsmxo_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

// HIFN This function closes the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
ViStatus _VI_FUNC rsmxo_close(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ViClose(instrSession));

Error:
    (void)RsCore_Dispose(instrSession);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rsmxo_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rsmxo_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
    return error;
}

/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rsmxo_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->multiThreadLocking = multiThreadLocking;

Error:
    return error;
}

/// HIFN  This function sets the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsmxo_SetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt32   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt32(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViInt64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsmxo_SetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt64   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt64(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsmxo_SetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViReal64  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViReal64(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsmxo_SetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViString  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViStringOrRawString(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsmxo_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  repeatedCapability,
                                              ViAttr    attributeId,
                                              ViBoolean attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViBoolean(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViInt32 variable.
ViStatus _VI_FUNC rsmxo_GetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt32*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt32(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViInt64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViInt64 variable.
ViStatus _VI_FUNC rsmxo_GetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapability,
                                            ViAttr    attributeId,
                                            ViInt64*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViInt64(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViReal64 variable.
ViStatus _VI_FUNC rsmxo_GetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViReal64(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufSize/Attribute Value parameter.
/// HIPAR value/The buffer in which the function returns the current value of the
/// HIPAR value/attribute. The buffer must be of type ViChar and have at least as many
/// HIPAR value/bytes as indicated in the Buffer Size parameter.
ViStatus _VI_FUNC rsmxo_GetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapability,
                                             ViAttr    attributeId,
                                             ViInt32   bufferSize,
                                             ViChar    value[])
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringOrRawString(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, bufferSize,
                                                   value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViBoolean variable.
ViStatus _VI_FUNC rsmxo_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   repeatedCapability,
                                              ViAttr     attributeId,
                                              ViBoolean* value)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViBoolean(instrSession, repeatedCapability, attributeId, RS_VAL_DIRECT_USER_CALL, value);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Attribute Value parameter.
/// HIPAR attributeValue/The buffer in which the function returns the current value of the
/// HIPAR attributeValue/attribute.  The buffer must be of type ViChar and have at least as many
/// HIPAR attributeValue/bytes as indicated in the Buffer Size parameter.
/// HIPAR responseLength/The length in bytes of the response read from the instrument. If
/// HIPAR responseLength/Response Length > allocated Buffer Size, some data from the instrument
/// HIPAR responseLength/was lost; resize your buffer to at least Response Length and call again
/// HIPAR responseLength/to capture the missing data from the instrument.
ViStatus _VI_FUNC rsmxo_GetAttributeViStringWithRealLen(ViSession instrSession,
                                                        ViString  repeatedCapability,
                                                        ViAttr    attributeId,
                                                        ViInt32   bufferSize,
                                                        ViChar    attributeValue[],
                                                        ViInt32*  responseLength)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringWithRealLen(instrSession, repeatedCapability, attributeId,
                                                   RS_VAL_DIRECT_USER_CALL, bufferSize, attributeValue, responseLength);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the value of a RawString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/Attribute Value parameter.
/// HIPAR attributeValue/The buffer in which the function returns the current value of the
/// HIPAR attributeValue/attribute.  The buffer must be of type ViChar and have at least as many
/// HIPAR attributeValue/bytes as indicated in the Buffer Size parameter.
/// HIPAR repeatedCapability/If the attribute requires repeated capabilities to be specified, this
/// HIPAR repeatedCapability/parameter specifies one or more comma-separated repeated capability
/// HIPAR repeatedCapability/identifiers on which to set the value of the attribute. If the
/// HIPAR repeatedCapability/attribute does not contain any repeated capabilities, then pass NULL or
/// HIPAR repeatedCapability/an empty string.
/// HIPAR responseLength/The length in bytes of the response read from the instrument. If
/// HIPAR responseLength/Response Length > allocated Buffer Size, some data from the instrument
/// HIPAR responseLength/was lost; resize your buffer to at least Response Length and call again
/// HIPAR responseLength/to capture the missing data from the instrument.
ViStatus _VI_FUNC rsmxo_GetAttributeRawStringWithRealLen(ViSession instrSession,
                                                         ViString  repeatedCapability,
                                                         ViAttr    attributeId,
                                                         ViInt32   bufferSize,
                                                         ViChar    attributeValue[],
                                                         ViInt32*  responseLength)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViRawStringWithRealLen(instrSession, repeatedCapability, attributeId,
                                                      RS_VAL_DIRECT_USER_CALL, bufferSize, attributeValue, responseLength);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the repeated capability id(s) that belongs
/// HIFN to the attribute you specify. More then one id is listed in
/// HIFN comma separated string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id(s) parameter.
/// HIPAR repeatedCapabilityIds/The buffer in which the function returns the repeated capability id(s) belonging to the attribute.
ViStatus _VI_FUNC rsmxo_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeId,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, bufferSize, 1),
                3, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeId, bufferSize, repeatedCapabilityIds));

Error:
    return error;
}

/// HIFN This function returns the repeated capability name(s) that
/// HIFN belongs to the attribute and single repeated capability id you
/// HIFN may specify. More then one name is listed in comma separated
/// HIFN string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repeatedCapabilityId/If the attribute applies to a repeated capability such as a trace, this parameter defines the Id of the repeated capability on which to query repeated capability id name(s).
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id Name(s) parameter.
/// HIPAR repeatedCapabilityIdNames/The buffer in which the function returns the repeated capability id name(s) belonging to the attribute.
ViStatus _VI_FUNC rsmxo_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, bufferSize, 1),
                4, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeId,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
    return error;
}

/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeId
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rsmxo_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeId,
                                               ViString  repCapNameId,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 *------------------- End Instrument Driver Source Code ---------------------*
 *****************************************************************************/
